Method: Aws::Route53Resolver::Types::PutResolverQueryLogConfigPolicyRequest#resolver_query_log_config_policy

Defined in:
lib/aws-sdk-route53resolver/types.rb

#resolver_query_log_config_policyString

An Identity and Access Management policy statement that lists the query logging configurations that you want to share with another Amazon Web Services account and the operations that you want the account to be able to perform. You can specify the following operations in the Actions section of the statement:

  • route53resolver:AssociateResolverQueryLogConfig

  • route53resolver:DisassociateResolverQueryLogConfig

  • route53resolver:ListResolverQueryLogConfigs

In the Resource section of the statement, you specify the ARNs for the query logging configurations that you want to share with the account that you specified in Arn.

Returns:

  • (String)


4019
4020
4021
4022
4023
4024
# File 'lib/aws-sdk-route53resolver/types.rb', line 4019

class PutResolverQueryLogConfigPolicyRequest < Struct.new(
  :arn,
  :resolver_query_log_config_policy)
  SENSITIVE = []
  include Aws::Structure
end