Class: Aws::Route53Resolver::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Route53Resolver::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-route53resolver/client.rb,
sig/client.rbs
Overview
An API client for Route53Resolver. To construct a client, you need to configure a :region and :credentials.
client = Aws::Route53Resolver::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateFirewallRuleGroupResponseSuccess, _AssociateResolverEndpointIpAddressResponseSuccess, _AssociateResolverQueryLogConfigResponseSuccess, _AssociateResolverRuleResponseSuccess, _BatchCreateFirewallRuleResponseSuccess, _BatchDeleteFirewallRuleResponseSuccess, _BatchUpdateFirewallRuleResponseSuccess, _CreateFirewallDomainListResponseSuccess, _CreateFirewallRuleGroupResponseSuccess, _CreateFirewallRuleResponseSuccess, _CreateOutpostResolverResponseSuccess, _CreateResolverEndpointResponseSuccess, _CreateResolverQueryLogConfigResponseSuccess, _CreateResolverRuleResponseSuccess, _DeleteFirewallDomainListResponseSuccess, _DeleteFirewallRuleGroupResponseSuccess, _DeleteFirewallRuleResponseSuccess, _DeleteOutpostResolverResponseSuccess, _DeleteResolverEndpointResponseSuccess, _DeleteResolverQueryLogConfigResponseSuccess, _DeleteResolverRuleResponseSuccess, _DisassociateFirewallRuleGroupResponseSuccess, _DisassociateResolverEndpointIpAddressResponseSuccess, _DisassociateResolverQueryLogConfigResponseSuccess, _DisassociateResolverRuleResponseSuccess, _GetFirewallConfigResponseSuccess, _GetFirewallDomainListResponseSuccess, _GetFirewallRuleGroupAssociationResponseSuccess, _GetFirewallRuleGroupPolicyResponseSuccess, _GetFirewallRuleGroupResponseSuccess, _GetOutpostResolverResponseSuccess, _GetResolverConfigResponseSuccess, _GetResolverDnssecConfigResponseSuccess, _GetResolverEndpointResponseSuccess, _GetResolverQueryLogConfigAssociationResponseSuccess, _GetResolverQueryLogConfigPolicyResponseSuccess, _GetResolverQueryLogConfigResponseSuccess, _GetResolverRuleAssociationResponseSuccess, _GetResolverRulePolicyResponseSuccess, _GetResolverRuleResponseSuccess, _ImportFirewallDomainsResponseSuccess, _ListFirewallConfigsResponseSuccess, _ListFirewallDomainListsResponseSuccess, _ListFirewallDomainsResponseSuccess, _ListFirewallRuleGroupAssociationsResponseSuccess, _ListFirewallRuleGroupsResponseSuccess, _ListFirewallRuleTypesResponseSuccess, _ListFirewallRulesResponseSuccess, _ListOutpostResolversResponseSuccess, _ListResolverConfigsResponseSuccess, _ListResolverDnssecConfigsResponseSuccess, _ListResolverEndpointIpAddressesResponseSuccess, _ListResolverEndpointsResponseSuccess, _ListResolverQueryLogConfigAssociationsResponseSuccess, _ListResolverQueryLogConfigsResponseSuccess, _ListResolverRuleAssociationsResponseSuccess, _ListResolverRulesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutFirewallRuleGroupPolicyResponseSuccess, _PutResolverQueryLogConfigPolicyResponseSuccess, _PutResolverRulePolicyResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateFirewallConfigResponseSuccess, _UpdateFirewallDomainsResponseSuccess, _UpdateFirewallRuleGroupAssociationResponseSuccess, _UpdateFirewallRuleResponseSuccess, _UpdateOutpostResolverResponseSuccess, _UpdateResolverConfigResponseSuccess, _UpdateResolverDnssecConfigResponseSuccess, _UpdateResolverEndpointResponseSuccess, _UpdateResolverRuleResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_firewall_rule_group(params = {}) ⇒ Types::AssociateFirewallRuleGroupResponse
Associates a FirewallRuleGroup with a VPC, to provide DNS filtering for the VPC.
-
#associate_resolver_endpoint_ip_address(params = {}) ⇒ Types::AssociateResolverEndpointIpAddressResponse
Adds IP addresses to an inbound or an outbound Resolver endpoint.
-
#associate_resolver_query_log_config(params = {}) ⇒ Types::AssociateResolverQueryLogConfigResponse
Associates an Amazon VPC with a specified query logging configuration.
-
#associate_resolver_rule(params = {}) ⇒ Types::AssociateResolverRuleResponse
Associates a Resolver rule with a VPC.
-
#batch_create_firewall_rule(params = {}) ⇒ Types::BatchCreateFirewallRuleResponse
Creates multiple DNS Firewall rules in the specified rule group.
-
#batch_delete_firewall_rule(params = {}) ⇒ Types::BatchDeleteFirewallRuleResponse
Deletes multiple DNS Firewall rules from the specified rule group.
-
#batch_update_firewall_rule(params = {}) ⇒ Types::BatchUpdateFirewallRuleResponse
Updates multiple DNS Firewall rules in the specified rule group.
-
#create_firewall_domain_list(params = {}) ⇒ Types::CreateFirewallDomainListResponse
Creates an empty firewall domain list for use in DNS Firewall rules.
-
#create_firewall_rule(params = {}) ⇒ Types::CreateFirewallRuleResponse
Creates a single DNS Firewall rule in the specified rule group.
-
#create_firewall_rule_group(params = {}) ⇒ Types::CreateFirewallRuleGroupResponse
Creates an empty DNS Firewall rule group for filtering DNS network traffic in a VPC.
-
#create_outpost_resolver(params = {}) ⇒ Types::CreateOutpostResolverResponse
Creates a Route 53 Resolver on an Outpost.
-
#create_resolver_endpoint(params = {}) ⇒ Types::CreateResolverEndpointResponse
Creates a Resolver endpoint.
-
#create_resolver_query_log_config(params = {}) ⇒ Types::CreateResolverQueryLogConfigResponse
Creates a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs.
-
#create_resolver_rule(params = {}) ⇒ Types::CreateResolverRuleResponse
For DNS queries that originate in your VPCs, specifies which Resolver endpoint the queries pass through, one domain name that you want to forward to your network, and the IP addresses of the DNS resolvers in your network.
-
#delete_firewall_domain_list(params = {}) ⇒ Types::DeleteFirewallDomainListResponse
Deletes the specified domain list.
-
#delete_firewall_rule(params = {}) ⇒ Types::DeleteFirewallRuleResponse
Deletes the specified firewall rule.
-
#delete_firewall_rule_group(params = {}) ⇒ Types::DeleteFirewallRuleGroupResponse
Deletes the specified firewall rule group.
-
#delete_outpost_resolver(params = {}) ⇒ Types::DeleteOutpostResolverResponse
Deletes a Resolver on the Outpost.
-
#delete_resolver_endpoint(params = {}) ⇒ Types::DeleteResolverEndpointResponse
Deletes a Resolver endpoint.
-
#delete_resolver_query_log_config(params = {}) ⇒ Types::DeleteResolverQueryLogConfigResponse
Deletes a query logging configuration.
-
#delete_resolver_rule(params = {}) ⇒ Types::DeleteResolverRuleResponse
Deletes a Resolver rule.
-
#disassociate_firewall_rule_group(params = {}) ⇒ Types::DisassociateFirewallRuleGroupResponse
Disassociates a FirewallRuleGroup from a VPC, to remove DNS filtering from the VPC.
-
#disassociate_resolver_endpoint_ip_address(params = {}) ⇒ Types::DisassociateResolverEndpointIpAddressResponse
Removes IP addresses from an inbound or an outbound Resolver endpoint.
-
#disassociate_resolver_query_log_config(params = {}) ⇒ Types::DisassociateResolverQueryLogConfigResponse
Disassociates a VPC from a query logging configuration.
-
#disassociate_resolver_rule(params = {}) ⇒ Types::DisassociateResolverRuleResponse
Removes the association between a specified Resolver rule and a specified VPC.
-
#get_firewall_config(params = {}) ⇒ Types::GetFirewallConfigResponse
Retrieves the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
-
#get_firewall_domain_list(params = {}) ⇒ Types::GetFirewallDomainListResponse
Retrieves the specified firewall domain list.
-
#get_firewall_rule_group(params = {}) ⇒ Types::GetFirewallRuleGroupResponse
Retrieves the specified firewall rule group.
-
#get_firewall_rule_group_association(params = {}) ⇒ Types::GetFirewallRuleGroupAssociationResponse
Retrieves a firewall rule group association, which enables DNS filtering for a VPC with one rule group.
-
#get_firewall_rule_group_policy(params = {}) ⇒ Types::GetFirewallRuleGroupPolicyResponse
Returns the Identity and Access Management (Amazon Web Services IAM) policy for sharing the specified rule group.
-
#get_outpost_resolver(params = {}) ⇒ Types::GetOutpostResolverResponse
Gets information about a specified Resolver on the Outpost, such as its instance count and type, name, and the current status of the Resolver.
-
#get_resolver_config(params = {}) ⇒ Types::GetResolverConfigResponse
Retrieves the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
-
#get_resolver_dnssec_config(params = {}) ⇒ Types::GetResolverDnssecConfigResponse
Gets DNSSEC validation information for a specified resource.
-
#get_resolver_endpoint(params = {}) ⇒ Types::GetResolverEndpointResponse
Gets information about a specified Resolver endpoint, such as whether it's an inbound or an outbound Resolver endpoint, and the current status of the endpoint.
-
#get_resolver_query_log_config(params = {}) ⇒ Types::GetResolverQueryLogConfigResponse
Gets information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to.
-
#get_resolver_query_log_config_association(params = {}) ⇒ Types::GetResolverQueryLogConfigAssociationResponse
Gets information about a specified association between a Resolver query logging configuration and an Amazon VPC.
-
#get_resolver_query_log_config_policy(params = {}) ⇒ Types::GetResolverQueryLogConfigPolicyResponse
Gets information about a query logging policy.
-
#get_resolver_rule(params = {}) ⇒ Types::GetResolverRuleResponse
Gets information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the ID of the outbound Resolver endpoint that the rule is associated with.
-
#get_resolver_rule_association(params = {}) ⇒ Types::GetResolverRuleAssociationResponse
Gets information about an association between a specified Resolver rule and a VPC.
-
#get_resolver_rule_policy(params = {}) ⇒ Types::GetResolverRulePolicyResponse
Gets information about the Resolver rule policy for a specified rule.
-
#import_firewall_domains(params = {}) ⇒ Types::ImportFirewallDomainsResponse
Imports domain names from a file into a domain list, for use in a DNS firewall rule group.
-
#list_firewall_configs(params = {}) ⇒ Types::ListFirewallConfigsResponse
Retrieves the firewall configurations that you have defined.
-
#list_firewall_domain_lists(params = {}) ⇒ Types::ListFirewallDomainListsResponse
Retrieves the firewall domain lists that you have defined.
-
#list_firewall_domains(params = {}) ⇒ Types::ListFirewallDomainsResponse
Retrieves the domains that you have defined for the specified firewall domain list.
-
#list_firewall_rule_group_associations(params = {}) ⇒ Types::ListFirewallRuleGroupAssociationsResponse
Retrieves the firewall rule group associations that you have defined.
-
#list_firewall_rule_groups(params = {}) ⇒ Types::ListFirewallRuleGroupsResponse
Retrieves the minimal high-level information for the rule groups that you have defined.
-
#list_firewall_rule_types(params = {}) ⇒ Types::ListFirewallRuleTypesResponse
Retrieves the rule-type variants that can be used in the
FirewallRuleTypefield of CreateFirewallRule and UpdateFirewallRule. -
#list_firewall_rules(params = {}) ⇒ Types::ListFirewallRulesResponse
Retrieves the firewall rules that you have defined for the specified firewall rule group.
-
#list_outpost_resolvers(params = {}) ⇒ Types::ListOutpostResolversResponse
Lists all the Resolvers on Outposts that were created using the current Amazon Web Services account.
-
#list_resolver_configs(params = {}) ⇒ Types::ListResolverConfigsResponse
Retrieves the Resolver configurations that you have defined.
-
#list_resolver_dnssec_configs(params = {}) ⇒ Types::ListResolverDnssecConfigsResponse
Lists the configurations for DNSSEC validation that are associated with the current Amazon Web Services account.
-
#list_resolver_endpoint_ip_addresses(params = {}) ⇒ Types::ListResolverEndpointIpAddressesResponse
Gets the IP addresses for a specified Resolver endpoint.
-
#list_resolver_endpoints(params = {}) ⇒ Types::ListResolverEndpointsResponse
Lists all the Resolver endpoints that were created using the current Amazon Web Services account.
-
#list_resolver_query_log_config_associations(params = {}) ⇒ Types::ListResolverQueryLogConfigAssociationsResponse
Lists information about associations between Amazon VPCs and query logging configurations.
-
#list_resolver_query_log_configs(params = {}) ⇒ Types::ListResolverQueryLogConfigsResponse
Lists information about the specified query logging configurations.
-
#list_resolver_rule_associations(params = {}) ⇒ Types::ListResolverRuleAssociationsResponse
Lists the associations that were created between Resolver rules and VPCs using the current Amazon Web Services account.
-
#list_resolver_rules(params = {}) ⇒ Types::ListResolverRulesResponse
Lists the Resolver rules that were created using the current Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
-
#put_firewall_rule_group_policy(params = {}) ⇒ Types::PutFirewallRuleGroupPolicyResponse
Attaches an Identity and Access Management (Amazon Web Services IAM) policy for sharing the rule group.
-
#put_resolver_query_log_config_policy(params = {}) ⇒ Types::PutResolverQueryLogConfigPolicyResponse
Specifies an Amazon Web Services account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.
-
#put_resolver_rule_policy(params = {}) ⇒ Types::PutResolverRulePolicyResponse
Specifies an Amazon Web Services rule that you want to share with another account, the account that you want to share the rule with, and the operations that you want the account to be able to perform on the rule.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
-
#update_firewall_config(params = {}) ⇒ Types::UpdateFirewallConfigResponse
Updates the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
-
#update_firewall_domains(params = {}) ⇒ Types::UpdateFirewallDomainsResponse
Updates the firewall domain list from an array of domain specifications.
-
#update_firewall_rule(params = {}) ⇒ Types::UpdateFirewallRuleResponse
Updates the specified firewall rule.
-
#update_firewall_rule_group_association(params = {}) ⇒ Types::UpdateFirewallRuleGroupAssociationResponse
Changes the association of a FirewallRuleGroup with a VPC.
-
#update_outpost_resolver(params = {}) ⇒ Types::UpdateOutpostResolverResponse
You can use
UpdateOutpostResolverto update the instance count, type, or name of a Resolver on an Outpost. -
#update_resolver_config(params = {}) ⇒ Types::UpdateResolverConfigResponse
Updates the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
-
#update_resolver_dnssec_config(params = {}) ⇒ Types::UpdateResolverDnssecConfigResponse
Updates an existing DNSSEC validation configuration.
-
#update_resolver_endpoint(params = {}) ⇒ Types::UpdateResolverEndpointResponse
Updates the name, or endpoint type for an inbound or an outbound Resolver endpoint.
-
#update_resolver_rule(params = {}) ⇒ Types::UpdateResolverRuleResponse
Updates settings for a specified Resolver rule.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5634 5635 5636 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5634 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5637 5638 5639 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5637 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_firewall_rule_group(params = {}) ⇒ Types::AssociateFirewallRuleGroupResponse
Associates a FirewallRuleGroup with a VPC, to provide DNS filtering for the VPC.
If the rule group contains any rule configured with the
PartnerThreatProtection rule type, the calling account must hold an
active AWS Marketplace subscription to the named partner. If the
subscription is missing, the association request is rejected.
87 |
# File 'sig/client.rbs', line 87
def associate_firewall_rule_group: (
|
#associate_resolver_endpoint_ip_address(params = {}) ⇒ Types::AssociateResolverEndpointIpAddressResponse
Adds IP addresses to an inbound or an outbound Resolver endpoint. If
you want to add more than one IP address, submit one
AssociateResolverEndpointIpAddress request for each IP address.
To remove an IP address from an endpoint, see DisassociateResolverEndpointIpAddress.
108 |
# File 'sig/client.rbs', line 108
def associate_resolver_endpoint_ip_address: (
|
#associate_resolver_query_log_config(params = {}) ⇒ Types::AssociateResolverQueryLogConfigResponse
Associates an Amazon VPC with a specified query logging configuration.
Route 53 Resolver logs DNS queries that originate in all of the Amazon
VPCs that are associated with a specified query logging configuration.
To associate more than one VPC with a configuration, submit one
AssociateResolverQueryLogConfig request for each VPC.
To remove a VPC from a query logging configuration, see DisassociateResolverQueryLogConfig.
124 |
# File 'sig/client.rbs', line 124
def associate_resolver_query_log_config: (
|
#associate_resolver_rule(params = {}) ⇒ Types::AssociateResolverRuleResponse
Associates a Resolver rule with a VPC. When you associate a rule with a VPC, Resolver forwards all DNS queries for the domain name that is specified in the rule and that originate in the VPC. The queries are forwarded to the IP addresses for the DNS resolvers that are specified in the rule. For more information about rules, see CreateResolverRule.
135 |
# File 'sig/client.rbs', line 135
def associate_resolver_rule: (
|
#batch_create_firewall_rule(params = {}) ⇒ Types::BatchCreateFirewallRuleResponse
Creates multiple DNS Firewall rules in the specified rule group.
148 |
# File 'sig/client.rbs', line 148
def batch_create_firewall_rule: (
|
#batch_delete_firewall_rule(params = {}) ⇒ Types::BatchDeleteFirewallRuleResponse
Deletes multiple DNS Firewall rules from the specified rule group.
177 |
# File 'sig/client.rbs', line 177
def batch_delete_firewall_rule: (
|
#batch_update_firewall_rule(params = {}) ⇒ Types::BatchUpdateFirewallRuleResponse
Updates multiple DNS Firewall rules in the specified rule group.
195 |
# File 'sig/client.rbs', line 195
def batch_update_firewall_rule: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5607 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Route53Resolver') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-route53resolver' context[:gem_version] = '1.102.0' Seahorse::Client::Request.new(handlers, context) end |
#create_firewall_domain_list(params = {}) ⇒ Types::CreateFirewallDomainListResponse
Creates an empty firewall domain list for use in DNS Firewall rules. You can populate the domains for the new list with a file, using ImportFirewallDomains, or with domain strings, using UpdateFirewallDomains.
223 |
# File 'sig/client.rbs', line 223
def create_firewall_domain_list: (
|
#create_firewall_rule(params = {}) ⇒ Types::CreateFirewallRuleResponse
Creates a single DNS Firewall rule in the specified rule group. The rule can use any one of the following match sources, and the chosen source must be supplied through the matching request field — they are mutually exclusive:
-
FirewallDomainListId— match a customer-managed or AWS-managed domain list. -
DnsThreatProtection— match a built-in DNS Firewall Advanced threat detector (DGA,DNS_TUNNELING, orDICTIONARY_DGA). -
FirewallRuleType— match one of the rule-type variants returned by ListFirewallRuleTypes:FirewallAdvancedContentCategory,FirewallAdvancedThreatCategory,DnsThreatProtection, orPartnerThreatProtection. ThePartnerThreatProtectionvariant requires an active AWS Marketplace subscription to the named partner product.
For rules that require asynchronous provisioning (today, the
PartnerThreatProtection rule type), the rule's Status begins at
CREATING and transitions to COMPLETE once the rule is provisioned
and the marketplace entitlement is verified. If provisioning fails,
Status becomes CREATION_FAILED and StatusMessage contains a
human-readable reason; the rule is then immutable and must be removed
with DeleteFirewallRule.
240 |
# File 'sig/client.rbs', line 240
def create_firewall_rule: (
|
#create_firewall_rule_group(params = {}) ⇒ Types::CreateFirewallRuleGroupResponse
Creates an empty DNS Firewall rule group for filtering DNS network traffic in a VPC. You can add rules to the new rule group by calling CreateFirewallRule.
264 |
# File 'sig/client.rbs', line 264
def create_firewall_rule_group: (
|
#create_outpost_resolver(params = {}) ⇒ Types::CreateOutpostResolverResponse
Creates a Route 53 Resolver on an Outpost.
281 |
# File 'sig/client.rbs', line 281
def create_outpost_resolver: (
|
#create_resolver_endpoint(params = {}) ⇒ Types::CreateResolverEndpointResponse
Creates a Resolver endpoint. There are two types of Resolver endpoints, inbound and outbound:
-
An inbound Resolver endpoint forwards DNS queries to the DNS service for a VPC from your network.
-
An outbound Resolver endpoint forwards DNS queries from the DNS service for a VPC to your network.
301 |
# File 'sig/client.rbs', line 301
def create_resolver_endpoint: (
|
#create_resolver_query_log_config(params = {}) ⇒ Types::CreateResolverQueryLogConfigResponse
Creates a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs. Resolver can log queries only for VPCs that are in the same Region as the query logging configuration.
To specify which VPCs you want to log queries for, you use
AssociateResolverQueryLogConfig. For more information, see
AssociateResolverQueryLogConfig.
You can optionally use Resource Access Manager (RAM) to share a query logging configuration with other Amazon Web Services accounts. The other accounts can then associate VPCs with the configuration. The query logs that Resolver creates for a configuration include all DNS queries that originate in all VPCs that are associated with the configuration.
335 |
# File 'sig/client.rbs', line 335
def create_resolver_query_log_config: (
|
#create_resolver_rule(params = {}) ⇒ Types::CreateResolverRuleResponse
For DNS queries that originate in your VPCs, specifies which Resolver endpoint the queries pass through, one domain name that you want to forward to your network, and the IP addresses of the DNS resolvers in your network.
353 |
# File 'sig/client.rbs', line 353
def create_resolver_rule: (
|
#delete_firewall_domain_list(params = {}) ⇒ Types::DeleteFirewallDomainListResponse
Deletes the specified domain list.
383 |
# File 'sig/client.rbs', line 383
def delete_firewall_domain_list: (
|
#delete_firewall_rule(params = {}) ⇒ Types::DeleteFirewallRuleResponse
Deletes the specified firewall rule. Identify the rule using either
FirewallDomainListId (for domain-list and DNS Firewall Advanced
rules) or FirewallThreatProtectionId (for partner-managed and DNS
Firewall Advanced rules) — together with FirewallRuleGroupId.
DeleteFirewallRule is the only operation that succeeds against a
rule whose Status is CREATION_FAILED.
393 |
# File 'sig/client.rbs', line 393
def delete_firewall_rule: (
|
#delete_firewall_rule_group(params = {}) ⇒ Types::DeleteFirewallRuleGroupResponse
Deletes the specified firewall rule group.
406 |
# File 'sig/client.rbs', line 406
def delete_firewall_rule_group: (
|
#delete_outpost_resolver(params = {}) ⇒ Types::DeleteOutpostResolverResponse
Deletes a Resolver on the Outpost.
416 |
# File 'sig/client.rbs', line 416
def delete_outpost_resolver: (
|
#delete_resolver_endpoint(params = {}) ⇒ Types::DeleteResolverEndpointResponse
Deletes a Resolver endpoint. The effect of deleting a Resolver endpoint depends on whether it's an inbound or an outbound Resolver endpoint:
-
Inbound: DNS queries from your network are no longer routed to the DNS service for the specified VPC.
-
Outbound: DNS queries from a VPC are no longer routed to your network.
426 |
# File 'sig/client.rbs', line 426
def delete_resolver_endpoint: (
|
#delete_resolver_query_log_config(params = {}) ⇒ Types::DeleteResolverQueryLogConfigResponse
Deletes a query logging configuration. When you delete a configuration, Resolver stops logging DNS queries for all of the Amazon VPCs that are associated with the configuration. This also applies if the query logging configuration is shared with other Amazon Web Services accounts, and the other accounts have associated VPCs with the shared configuration.
Before you can delete a query logging configuration, you must first disassociate all VPCs from the configuration. See DisassociateResolverQueryLogConfig.
If you used Resource Access Manager (RAM) to share a query logging configuration with other accounts, you must stop sharing the configuration before you can delete a configuration. The accounts that you shared the configuration with can first disassociate VPCs that they associated with the configuration, but that's not necessary. If you stop sharing the configuration, those VPCs are automatically disassociated from the configuration.
436 |
# File 'sig/client.rbs', line 436
def delete_resolver_query_log_config: (
|
#delete_resolver_rule(params = {}) ⇒ Types::DeleteResolverRuleResponse
Deletes a Resolver rule. Before you can delete a Resolver rule, you must disassociate it from all the VPCs that you associated the Resolver rule with. For more information, see DisassociateResolverRule.
446 |
# File 'sig/client.rbs', line 446
def delete_resolver_rule: (
|
#disassociate_firewall_rule_group(params = {}) ⇒ Types::DisassociateFirewallRuleGroupResponse
Disassociates a FirewallRuleGroup from a VPC, to remove DNS filtering from the VPC.
456 |
# File 'sig/client.rbs', line 456
def disassociate_firewall_rule_group: (
|
#disassociate_resolver_endpoint_ip_address(params = {}) ⇒ Types::DisassociateResolverEndpointIpAddressResponse
Removes IP addresses from an inbound or an outbound Resolver endpoint.
If you want to remove more than one IP address, submit one
DisassociateResolverEndpointIpAddress request for each IP address.
To add an IP address to an endpoint, see AssociateResolverEndpointIpAddress.
466 |
# File 'sig/client.rbs', line 466
def disassociate_resolver_endpoint_ip_address: (
|
#disassociate_resolver_query_log_config(params = {}) ⇒ Types::DisassociateResolverQueryLogConfigResponse
Disassociates a VPC from a query logging configuration.
-
The accounts that you shared the configuration with can disassociate VPCs from the configuration.
-
You can stop sharing the configuration.
482 |
# File 'sig/client.rbs', line 482
def disassociate_resolver_query_log_config: (
|
#disassociate_resolver_rule(params = {}) ⇒ Types::DisassociateResolverRuleResponse
Removes the association between a specified Resolver rule and a specified VPC.
If you disassociate a Resolver rule from a VPC, Resolver stops forwarding DNS queries for the domain name that you specified in the Resolver rule.
493 |
# File 'sig/client.rbs', line 493
def disassociate_resolver_rule: (
|
#get_firewall_config(params = {}) ⇒ Types::GetFirewallConfigResponse
Retrieves the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
504 |
# File 'sig/client.rbs', line 504
def get_firewall_config: (
|
#get_firewall_domain_list(params = {}) ⇒ Types::GetFirewallDomainListResponse
Retrieves the specified firewall domain list.
514 |
# File 'sig/client.rbs', line 514
def get_firewall_domain_list: (
|
#get_firewall_rule_group(params = {}) ⇒ Types::GetFirewallRuleGroupResponse
Retrieves the specified firewall rule group.
524 |
# File 'sig/client.rbs', line 524
def get_firewall_rule_group: (
|
#get_firewall_rule_group_association(params = {}) ⇒ Types::GetFirewallRuleGroupAssociationResponse
Retrieves a firewall rule group association, which enables DNS filtering for a VPC with one rule group. A VPC can have more than one firewall rule group association, and a rule group can be associated with more than one VPC.
534 |
# File 'sig/client.rbs', line 534
def get_firewall_rule_group_association: (
|
#get_firewall_rule_group_policy(params = {}) ⇒ Types::GetFirewallRuleGroupPolicyResponse
Returns the Identity and Access Management (Amazon Web Services IAM) policy for sharing the specified rule group. You can use the policy to share the rule group using Resource Access Manager (RAM).
544 |
# File 'sig/client.rbs', line 544
def get_firewall_rule_group_policy: (
|
#get_outpost_resolver(params = {}) ⇒ Types::GetOutpostResolverResponse
Gets information about a specified Resolver on the Outpost, such as its instance count and type, name, and the current status of the Resolver.
554 |
# File 'sig/client.rbs', line 554
def get_outpost_resolver: (
|
#get_resolver_config(params = {}) ⇒ Types::GetResolverConfigResponse
Retrieves the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
564 |
# File 'sig/client.rbs', line 564
def get_resolver_config: (
|
#get_resolver_dnssec_config(params = {}) ⇒ Types::GetResolverDnssecConfigResponse
Gets DNSSEC validation information for a specified resource.
574 |
# File 'sig/client.rbs', line 574
def get_resolver_dnssec_config: (
|
#get_resolver_endpoint(params = {}) ⇒ Types::GetResolverEndpointResponse
Gets information about a specified Resolver endpoint, such as whether it's an inbound or an outbound Resolver endpoint, and the current status of the endpoint.
584 |
# File 'sig/client.rbs', line 584
def get_resolver_endpoint: (
|
#get_resolver_query_log_config(params = {}) ⇒ Types::GetResolverQueryLogConfigResponse
Gets information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to.
594 |
# File 'sig/client.rbs', line 594
def get_resolver_query_log_config: (
|
#get_resolver_query_log_config_association(params = {}) ⇒ Types::GetResolverQueryLogConfigAssociationResponse
Gets information about a specified association between a Resolver query logging configuration and an Amazon VPC. When you associate a VPC with a query logging configuration, Resolver logs DNS queries that originate in that VPC.
604 |
# File 'sig/client.rbs', line 604
def get_resolver_query_log_config_association: (
|
#get_resolver_query_log_config_policy(params = {}) ⇒ Types::GetResolverQueryLogConfigPolicyResponse
Gets information about a query logging policy. A query logging policy specifies the Resolver query logging operations and resources that you want to allow another Amazon Web Services account to be able to use.
614 |
# File 'sig/client.rbs', line 614
def get_resolver_query_log_config_policy: (
|
#get_resolver_rule(params = {}) ⇒ Types::GetResolverRuleResponse
Gets information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the ID of the outbound Resolver endpoint that the rule is associated with.
624 |
# File 'sig/client.rbs', line 624
def get_resolver_rule: (
|
#get_resolver_rule_association(params = {}) ⇒ Types::GetResolverRuleAssociationResponse
Gets information about an association between a specified Resolver rule and a VPC. You associate a Resolver rule and a VPC using AssociateResolverRule.
634 |
# File 'sig/client.rbs', line 634
def get_resolver_rule_association: (
|
#get_resolver_rule_policy(params = {}) ⇒ Types::GetResolverRulePolicyResponse
Gets information about the Resolver rule policy for a specified rule. A Resolver rule policy includes the rule that you want to share with another account, the account that you want to share the rule with, and the Resolver operations that you want to allow the account to use.
644 |
# File 'sig/client.rbs', line 644
def get_resolver_rule_policy: (
|
#import_firewall_domains(params = {}) ⇒ Types::ImportFirewallDomainsResponse
Imports domain names from a file into a domain list, for use in a DNS firewall rule group.
Each domain specification in your domain list must satisfy the following requirements:
-
It can optionally start with
*(asterisk). -
With the exception of the optional starting asterisk, it must only contain the following characters:
A-Z,a-z,0-9,-(hyphen). -
It must be from 1-255 characters in length.
657 |
# File 'sig/client.rbs', line 657
def import_firewall_domains: (
|
#list_firewall_configs(params = {}) ⇒ Types::ListFirewallConfigsResponse
Retrieves the firewall configurations that you have defined. DNS Firewall uses the configurations to manage firewall behavior for your VPCs.
A single call might return only a partial list of the configurations.
For information, see MaxResults.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
670 |
# File 'sig/client.rbs', line 670
def list_firewall_configs: (
|
#list_firewall_domain_lists(params = {}) ⇒ Types::ListFirewallDomainListsResponse
Retrieves the firewall domain lists that you have defined. For each firewall domain list, you can retrieve the domains that are defined for a list by calling ListFirewallDomains.
A single call to this list operation might return only a partial list
of the domain lists. For information, see MaxResults.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
682 |
# File 'sig/client.rbs', line 682
def list_firewall_domain_lists: (
|
#list_firewall_domains(params = {}) ⇒ Types::ListFirewallDomainsResponse
Retrieves the domains that you have defined for the specified firewall domain list.
A single call might return only a partial list of the domains. For
information, see MaxResults.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
694 |
# File 'sig/client.rbs', line 694
def list_firewall_domains: (
|
#list_firewall_rule_group_associations(params = {}) ⇒ Types::ListFirewallRuleGroupAssociationsResponse
Retrieves the firewall rule group associations that you have defined. Each association enables DNS filtering for a VPC with one rule group.
A single call might return only a partial list of the associations.
For information, see MaxResults.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
707 |
# File 'sig/client.rbs', line 707
def list_firewall_rule_group_associations: (
|
#list_firewall_rule_groups(params = {}) ⇒ Types::ListFirewallRuleGroupsResponse
Retrieves the minimal high-level information for the rule groups that you have defined.
A single call might return only a partial list of the rule groups. For
information, see MaxResults.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
723 |
# File 'sig/client.rbs', line 723
def list_firewall_rule_groups: (
|
#list_firewall_rule_types(params = {}) ⇒ Types::ListFirewallRuleTypesResponse
Retrieves the rule-type variants that can be used in the
FirewallRuleType field of CreateFirewallRule and UpdateFirewallRule.
Each returned FirewallRuleTypeDefinition identifies one variant +
value combination — for example, FirewallAdvancedContentCategory +
VIOLENCE_AND_HATE_SPEECH, or PartnerThreatProtection + a
partner-managed feed.
The supported RuleType filter values are
FirewallAdvancedContentCategory, FirewallAdvancedThreatCategory,
DnsThreatProtection, and PartnerThreatProtection. When a returned
definition's variant requires an external subscription (currently
only PartnerThreatProtection), the response also includes a
SubscriptionInfo identifying the AWS Marketplace product that backs
it; absence of SubscriptionInfo means the variant is fully managed
by AWS and requires no separate subscription.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
735 |
# File 'sig/client.rbs', line 735
def list_firewall_rule_types: (
|
#list_firewall_rules(params = {}) ⇒ Types::ListFirewallRulesResponse
Retrieves the firewall rules that you have defined for the specified firewall rule group. DNS Firewall uses the rules in a rule group to filter DNS network traffic for a VPC.
A single call might return only a partial list of the rules. For
information, see MaxResults.
For rules that require asynchronous provisioning, the response
includes Status (see FirewallRuleStatus) and, on failure,
StatusMessage with the reason.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
748 |
# File 'sig/client.rbs', line 748
def list_firewall_rules: (
|
#list_outpost_resolvers(params = {}) ⇒ Types::ListOutpostResolversResponse
Lists all the Resolvers on Outposts that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
763 |
# File 'sig/client.rbs', line 763
def list_outpost_resolvers: (
|
#list_resolver_configs(params = {}) ⇒ Types::ListResolverConfigsResponse
Retrieves the Resolver configurations that you have defined. Route 53 Resolver uses the configurations to manage DNS resolution behavior for your VPCs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
776 |
# File 'sig/client.rbs', line 776
def list_resolver_configs: (
|
#list_resolver_dnssec_configs(params = {}) ⇒ Types::ListResolverDnssecConfigsResponse
Lists the configurations for DNSSEC validation that are associated with the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
788 |
# File 'sig/client.rbs', line 788
def list_resolver_dnssec_configs: (
|
#list_resolver_endpoint_ip_addresses(params = {}) ⇒ Types::ListResolverEndpointIpAddressesResponse
Gets the IP addresses for a specified Resolver endpoint.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
807 |
# File 'sig/client.rbs', line 807
def list_resolver_endpoint_ip_addresses: (
|
#list_resolver_endpoints(params = {}) ⇒ Types::ListResolverEndpointsResponse
Lists all the Resolver endpoints that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
821 |
# File 'sig/client.rbs', line 821
def list_resolver_endpoints: (
|
#list_resolver_query_log_config_associations(params = {}) ⇒ Types::ListResolverQueryLogConfigAssociationsResponse
Lists information about associations between Amazon VPCs and query logging configurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
841 |
# File 'sig/client.rbs', line 841
def list_resolver_query_log_config_associations: (
|
#list_resolver_query_log_configs(params = {}) ⇒ Types::ListResolverQueryLogConfigsResponse
Lists information about the specified query logging configurations. Each configuration defines where you want Resolver to save DNS query logs and specifies the VPCs that you want to log queries for.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
863 |
# File 'sig/client.rbs', line 863
def list_resolver_query_log_configs: (
|
#list_resolver_rule_associations(params = {}) ⇒ Types::ListResolverRuleAssociationsResponse
Lists the associations that were created between Resolver rules and VPCs using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
884 |
# File 'sig/client.rbs', line 884
def list_resolver_rule_associations: (
|
#list_resolver_rules(params = {}) ⇒ Types::ListResolverRulesResponse
Lists the Resolver rules that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
903 |
# File 'sig/client.rbs', line 903
def list_resolver_rules: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
921 |
# File 'sig/client.rbs', line 921
def list_tags_for_resource: (
|
#put_firewall_rule_group_policy(params = {}) ⇒ Types::PutFirewallRuleGroupPolicyResponse
Attaches an Identity and Access Management (Amazon Web Services IAM) policy for sharing the rule group. You can use the policy to share the rule group using Resource Access Manager (RAM).
933 |
# File 'sig/client.rbs', line 933
def put_firewall_rule_group_policy: (
|
#put_resolver_query_log_config_policy(params = {}) ⇒ Types::PutResolverQueryLogConfigPolicyResponse
Specifies an Amazon Web Services account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.
944 |
# File 'sig/client.rbs', line 944
def put_resolver_query_log_config_policy: (
|
#put_resolver_rule_policy(params = {}) ⇒ Types::PutResolverRulePolicyResponse
Specifies an Amazon Web Services rule that you want to share with another account, the account that you want to share the rule with, and the operations that you want the account to be able to perform on the rule.
955 |
# File 'sig/client.rbs', line 955
def put_resolver_rule_policy: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
965 |
# File 'sig/client.rbs', line 965
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
980 |
# File 'sig/client.rbs', line 980
def untag_resource: (
|
#update_firewall_config(params = {}) ⇒ Types::UpdateFirewallConfigResponse
Updates the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
991 |
# File 'sig/client.rbs', line 991
def update_firewall_config: (
|
#update_firewall_domains(params = {}) ⇒ Types::UpdateFirewallDomainsResponse
Updates the firewall domain list from an array of domain specifications.
1005 |
# File 'sig/client.rbs', line 1005
def update_firewall_domains: (
|
#update_firewall_rule(params = {}) ⇒ Types::UpdateFirewallRuleResponse
Updates the specified firewall rule. The rule's FirewallRuleType,
FirewallDomainListId, and top-level DnsThreatProtection match
source cannot be changed after creation. Rules whose Status is
CREATING or CREATION_FAILED cannot be updated; remove a failed
rule with DeleteFirewallRule.
1017 |
# File 'sig/client.rbs', line 1017
def update_firewall_rule: (
|
#update_firewall_rule_group_association(params = {}) ⇒ Types::UpdateFirewallRuleGroupAssociationResponse
Changes the association of a FirewallRuleGroup with a VPC. The association enables DNS filtering for the VPC.
1041 |
# File 'sig/client.rbs', line 1041
def update_firewall_rule_group_association: (
|
#update_outpost_resolver(params = {}) ⇒ Types::UpdateOutpostResolverResponse
You can use UpdateOutpostResolver to update the instance count,
type, or name of a Resolver on an Outpost.
1054 |
# File 'sig/client.rbs', line 1054
def update_outpost_resolver: (
|
#update_resolver_config(params = {}) ⇒ Types::UpdateResolverConfigResponse
Updates the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
1067 |
# File 'sig/client.rbs', line 1067
def update_resolver_config: (
|
#update_resolver_dnssec_config(params = {}) ⇒ Types::UpdateResolverDnssecConfigResponse
Updates an existing DNSSEC validation configuration. If there is no existing DNSSEC validation configuration, one is created.
1078 |
# File 'sig/client.rbs', line 1078
def update_resolver_dnssec_config: (
|
#update_resolver_endpoint(params = {}) ⇒ Types::UpdateResolverEndpointResponse
Updates the name, or endpoint type for an inbound or an outbound Resolver endpoint. You can only update between IPV4 and DUALSTACK, IPV6 endpoint type can't be updated to other type.
1089 |
# File 'sig/client.rbs', line 1089
def update_resolver_endpoint: (
|
#update_resolver_rule(params = {}) ⇒ Types::UpdateResolverRuleResponse
Updates settings for a specified Resolver rule. ResolverRuleId is
required, and all other parameters are optional. If you don't specify
a parameter, it retains its current value.
1112 |
# File 'sig/client.rbs', line 1112
def update_resolver_rule: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5627 5628 5629 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5627 def waiter_names [] end |