Class: Aws::Route53Resolver::Types::DeleteFirewallRuleEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::DeleteFirewallRuleEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
The details for deleting a single firewall rule in a batch operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_domain_list_id ⇒ String
The ID of the domain list that’s used in the rule.
-
#firewall_rule_group_id ⇒ String
The unique identifier of the firewall rule group for the rule.
-
#firewall_threat_protection_id ⇒ String
The ID of the DNS Firewall Advanced rule.
-
#qtype ⇒ String
The DNS query type that the rule evaluates.
Instance Attribute Details
#firewall_domain_list_id ⇒ String
The ID of the domain list that’s used in the rule.
1372 1373 1374 1375 1376 1377 1378 1379 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 1372 class DeleteFirewallRuleEntry < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :qtype) SENSITIVE = [] include Aws::Structure end |
#firewall_rule_group_id ⇒ String
The unique identifier of the firewall rule group for the rule.
1372 1373 1374 1375 1376 1377 1378 1379 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 1372 class DeleteFirewallRuleEntry < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :qtype) SENSITIVE = [] include Aws::Structure end |
#firewall_threat_protection_id ⇒ String
The ID of the DNS Firewall Advanced rule.
1372 1373 1374 1375 1376 1377 1378 1379 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 1372 class DeleteFirewallRuleEntry < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :qtype) SENSITIVE = [] include Aws::Structure end |
#qtype ⇒ String
The DNS query type that the rule evaluates.
1372 1373 1374 1375 1376 1377 1378 1379 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 1372 class DeleteFirewallRuleEntry < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :qtype) SENSITIVE = [] include Aws::Structure end |