Class: Aws::Route53Resolver::Types::FirewallDomainListMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Minimal high-level information for a firewall domain list. The action ListFirewallDomainLists returns an array of these objects.

To retrieve full information for a firewall domain list, call GetFirewallDomainList and ListFirewallDomains.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the firewall domain list metadata.

Returns:

  • (String)


2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218

class FirewallDomainListMetadata < Struct.new(
  :id,
  :arn,
  :name,
  :creator_request_id,
  :managed_owner_name,
  :managed_list_type,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#categoryString

The category of the domain list.

Returns:

  • (String)


2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218

class FirewallDomainListMetadata < Struct.new(
  :id,
  :arn,
  :name,
  :creator_request_id,
  :managed_owner_name,
  :managed_list_type,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#creator_request_idString

A unique string defined by you to identify the request. This allows you to retry failed requests without the risk of running the operation twice. This can be any unique string, for example, a timestamp.

Returns:

  • (String)


2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218

class FirewallDomainListMetadata < Struct.new(
  :id,
  :arn,
  :name,
  :creator_request_id,
  :managed_owner_name,
  :managed_list_type,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the domain list.

Returns:

  • (String)


2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218

class FirewallDomainListMetadata < Struct.new(
  :id,
  :arn,
  :name,
  :creator_request_id,
  :managed_owner_name,
  :managed_list_type,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#managed_list_typeString

The type of the managed domain list, for example THREAT.

Returns:

  • (String)


2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218

class FirewallDomainListMetadata < Struct.new(
  :id,
  :arn,
  :name,
  :creator_request_id,
  :managed_owner_name,
  :managed_list_type,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#managed_owner_nameString

The owner of the list, used only for lists that are not managed by you. For example, the managed domain list AWSManagedDomainsMalwareDomainList has the managed owner name Route 53 Resolver DNS Firewall.

Returns:

  • (String)


2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218

class FirewallDomainListMetadata < Struct.new(
  :id,
  :arn,
  :name,
  :creator_request_id,
  :managed_owner_name,
  :managed_list_type,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the domain list.

Returns:

  • (String)


2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218

class FirewallDomainListMetadata < Struct.new(
  :id,
  :arn,
  :name,
  :creator_request_id,
  :managed_owner_name,
  :managed_list_type,
  :category)
  SENSITIVE = []
  include Aws::Structure
end