Class: Aws::Route53Resolver::Types::FirewallRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::FirewallRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
A single firewall rule in a rule group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule’s domain list, or a threat in a DNS Firewall Advanced rule:.
-
#block_override_dns_type ⇒ String
The DNS record’s type.
-
#block_override_domain ⇒ String
The custom DNS record to send back in response to the query.
-
#block_override_ttl ⇒ Integer
The recommended amount of time, in seconds, for the DNS resolver or web browser to cache the provided override record.
-
#block_response ⇒ String
The way that you want DNS Firewall to block the request.
-
#confidence_threshold ⇒ String
The confidence threshold for DNS Firewall Advanced.
-
#creation_time ⇒ String
The date and time that the rule was created, in Unix time format and Coordinated Universal Time (UTC).
-
#creator_request_id ⇒ String
A unique string defined by you to identify the request.
-
#dns_threat_protection ⇒ String
The type of the DNS Firewall Advanced rule.
-
#firewall_domain_list_id ⇒ String
The ID of the domain list that’s used in the rule.
-
#firewall_domain_redirection_action ⇒ String
How you want the the rule to evaluate DNS redirection in the DNS redirection chain, such as CNAME or DNAME.
-
#firewall_rule_group_id ⇒ String
The unique identifier of the Firewall rule group of the rule.
-
#firewall_rule_type ⇒ Types::FirewallRuleType
The rule type configuration for the firewall rule.
-
#firewall_threat_protection_id ⇒ String
ID of the DNS Firewall Advanced rule.
-
#modification_time ⇒ String
The date and time that the rule was last modified, in Unix time format and Coordinated Universal Time (UTC).
-
#name ⇒ String
The name of the rule.
-
#priority ⇒ Integer
The priority of the rule in the rule group.
-
#qtype ⇒ String
The DNS query type you want the rule to evaluate.
-
#status ⇒ String
The lifecycle state of the firewall rule.
-
#status_message ⇒ String
An additional message about the rule’s lifecycle state.
Instance Attribute Details
#action ⇒ String
The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule’s domain list, or a threat in a DNS Firewall Advanced rule:
-
‘ALLOW` - Permit the request to go through. Not available for DNS Firewall Advanced rules.
-
‘ALERT` - Permit the request to go through but send an alert to the logs.
-
‘BLOCK` - Disallow the request. If this is specified, additional handling details are provided in the rule’s ‘BlockResponse` setting.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#block_override_dns_type ⇒ String
The DNS record’s type. This determines the format of the record value that you provided in ‘BlockOverrideDomain`. Used for the rule action `BLOCK` with a `BlockResponse` setting of `OVERRIDE`.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#block_override_domain ⇒ String
The custom DNS record to send back in response to the query. Used for the rule action ‘BLOCK` with a `BlockResponse` setting of `OVERRIDE`.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#block_override_ttl ⇒ Integer
The recommended amount of time, in seconds, for the DNS resolver or web browser to cache the provided override record. Used for the rule action ‘BLOCK` with a `BlockResponse` setting of `OVERRIDE`.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#block_response ⇒ String
The way that you want DNS Firewall to block the request. Used for the rule action setting ‘BLOCK`.
-
‘NODATA` - Respond indicating that the query was successful, but no response is available for it.
-
‘NXDOMAIN` - Respond indicating that the domain name that’s in the query doesn’t exist.
-
‘OVERRIDE` - Provide a custom override in the response. This option requires custom handling details in the rule’s ‘BlockOverride*` settings.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#confidence_threshold ⇒ String
The confidence threshold for DNS Firewall Advanced. You must provide this value when you create a DNS Firewall Advanced rule. The confidence level values mean:
-
‘LOW`: Provides the highest detection rate for threats, but also increases false positives.
-
‘MEDIUM`: Provides a balance between detecting threats and false positives.
-
‘HIGH`: Detects only the most well corroborated threats with a low rate of false positives.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ String
The date and time that the rule was created, in Unix time format and Coordinated Universal Time (UTC).
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#creator_request_id ⇒ String
A unique string defined by you to identify the request. This allows you to retry failed requests without the risk of executing the operation twice. This can be any unique string, for example, a timestamp.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#dns_threat_protection ⇒ String
The type of the DNS Firewall Advanced rule. Valid values are:
-
‘DGA`: Domain generation algorithms detection. DGAs are used by attackers to generate a large number of domains to launch malware attacks.
-
‘DNS_TUNNELING`: DNS tunneling detection. DNS tunneling is used by attackers to exfiltrate data from the client by using the DNS tunnel without making a network connection to the client.
-
‘DICTIONARY_DGA`: Dictionary-based domain generation algorithms detection. Dictionary DGAs use wordlists to generate domains that appear more legitimate, making them harder to detect than traditional DGAs.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#firewall_domain_list_id ⇒ String
The ID of the domain list that’s used in the rule.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#firewall_domain_redirection_action ⇒ String
How you want the the rule to evaluate DNS redirection in the DNS redirection chain, such as CNAME or DNAME.
‘INSPECT_REDIRECTION_DOMAIN`: (Default) inspects all domains in the redirection chain. The individual domains in the redirection chain must be added to the domain list.
‘TRUST_REDIRECTION_DOMAIN`: Inspects only the first domain in the redirection chain. You don’t need to add the subsequent domains in the domain in the redirection list to the domain list.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#firewall_rule_group_id ⇒ String
The unique identifier of the Firewall rule group of the rule.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#firewall_rule_type ⇒ Types::FirewallRuleType
The rule type configuration for the firewall rule. This is a tagged union — exactly one of its members will be populated. Possible members are:
-
‘FirewallAdvancedContentCategory` — an AWS-managed content category (for example, `VIOLENCE_AND_HATE_SPEECH`).
-
‘FirewallAdvancedThreatCategory` — an AWS-managed advanced threat category (for example, `PHISHING`).
-
‘DnsThreatProtection` — a built-in DNS Firewall Advanced threat detector (`DGA`, `DNS_TUNNELING`, or `DICTIONARY_DGA`).
-
‘PartnerThreatProtection` — a third-party threat feed delivered through AWS Marketplace.
To enumerate the values supported in your account, call ListFirewallRuleTypes.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#firewall_threat_protection_id ⇒ String
ID of the DNS Firewall Advanced rule.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#modification_time ⇒ String
The date and time that the rule was last modified, in Unix time format and Coordinated Universal Time (UTC).
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The priority of the rule in the rule group. This value must be unique within the rule group. DNS Firewall processes the rules in a rule group by order of priority, starting from the lowest setting.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#qtype ⇒ String
The DNS query type you want the rule to evaluate. Allowed values are;
-
A: Returns an IPv4 address.
-
AAAA: Returns an Ipv6 address.
-
CAA: Restricts CAs that can create SSL/TLS certifications for the domain.
-
CNAME: Returns another domain name.
-
DS: Record that identifies the DNSSEC signing key of a delegated zone.
-
MX: Specifies mail servers.
-
NAPTR: Regular-expression-based rewriting of domain names.
-
NS: Authoritative name servers.
-
PTR: Maps an IP address to a domain name.
-
SOA: Start of authority record for the zone.
-
SPF: Lists the servers authorized to send emails from a domain.
-
SRV: Application specific values that identify servers.
-
TXT: Verifies email senders and application-specific values.
-
A query type you define by using the DNS type ID, for example 28 for AAAA. The values must be defined as TYPENUMBER, where the NUMBER can be 1-65534, for example, TYPE28. For more information, see [List of DNS record types].
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The lifecycle state of the firewall rule. Possible values:
-
‘CREATING` — DNS Firewall is provisioning the rule. Rules created with the `PartnerThreatProtection` rule type begin in this state while DNS Firewall verifies the calling account’s AWS Marketplace entitlement.
-
‘COMPLETE` — The rule is provisioned and enforcing matches.
-
‘CREATION_FAILED` — Provisioning failed. `StatusMessage` contains a human-readable reason. A rule in this state is immutable: UpdateFirewallRule rejects the request, and the rule must be removed with DeleteFirewallRule.
For rules that do not require asynchronous provisioning, this field may be absent.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
An additional message about the rule’s lifecycle state. Populated when ‘Status` is `CREATION_FAILED` to describe why provisioning failed.
2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2455 class FirewallRule < Struct.new( :firewall_rule_group_id, :firewall_domain_list_id, :firewall_threat_protection_id, :name, :priority, :action, :block_response, :block_override_domain, :block_override_dns_type, :block_override_ttl, :creator_request_id, :creation_time, :modification_time, :firewall_domain_redirection_action, :qtype, :dns_threat_protection, :confidence_threshold, :firewall_rule_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |