Class: Aws::Route53Resolver::Types::FirewallRuleGroupAssociation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

An association between a firewall rule group and a VPC, which enables DNS filtering for the VPC.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the firewall rule group association.

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeString

The date and time that the association was created, in Unix time format and Coordinated Universal Time (UTC).

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#creator_request_idString

A unique string defined by you to identify the request. This allows you to retry failed requests without the risk of running the operation twice. This can be any unique string, for example, a timestamp.

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_rule_group_idString

The unique identifier of the firewall rule group.

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier for the association.

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#managed_owner_nameString

The owner of the association, used only for associations that are not managed by you. If you use Firewall Manager to manage your DNS Firewalls, then this reports Firewall Manager as the managed owner.

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#modification_timeString

The date and time that the association was last modified, in Unix time format and Coordinated Universal Time (UTC).

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#mutation_protectionString

If enabled, this setting disallows modification or removal of the association, to help prevent against accidentally altering DNS firewall protections.

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the association.

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#priorityInteger

The setting that determines the processing order of the rule group among the rule groups that are associated with a single VPC. DNS Firewall filters VPC traffic starting from rule group with the lowest numeric priority setting.

Returns:

  • (Integer)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the association.

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

Additional information about the status of the response, if available.

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The unique identifier of the VPC that is associated with the rule group.

Returns:

  • (String)


2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/aws-sdk-route53resolver/types.rb', line 2033

class FirewallRuleGroupAssociation < Struct.new(
  :id,
  :arn,
  :firewall_rule_group_id,
  :vpc_id,
  :name,
  :priority,
  :mutation_protection,
  :managed_owner_name,
  :status,
  :status_message,
  :creator_request_id,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end