Class: Aws::Route53Resolver::Types::FirewallRuleGroupMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::FirewallRuleGroupMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Minimal high-level information for a firewall rule group. The action ListFirewallRuleGroups returns an array of these objects.
To retrieve full information for a firewall rule group, call GetFirewallRuleGroup and ListFirewallRules.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN (Amazon Resource Name) of the rule group.
-
#creator_request_id ⇒ String
A unique string defined by you to identify the request.
-
#id ⇒ String
The ID of the rule group.
-
#name ⇒ String
The name of the rule group.
-
#owner_id ⇒ String
The Amazon Web Services account ID for the account that created the rule group.
-
#share_status ⇒ String
Whether the rule group is shared with other Amazon Web Services accounts, or was shared with the current account by another Amazon Web Services account.
Instance Attribute Details
#arn ⇒ String
The ARN (Amazon Resource Name) of the rule group.
2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2091 class FirewallRuleGroupMetadata < Struct.new( :id, :arn, :name, :owner_id, :creator_request_id, :share_status) SENSITIVE = [] include Aws::Structure end |
#creator_request_id ⇒ String
A unique string defined by you to identify the request. This allows you to retry failed requests without the risk of running the operation twice. This can be any unique string, for example, a timestamp.
2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2091 class FirewallRuleGroupMetadata < Struct.new( :id, :arn, :name, :owner_id, :creator_request_id, :share_status) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the rule group.
2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2091 class FirewallRuleGroupMetadata < Struct.new( :id, :arn, :name, :owner_id, :creator_request_id, :share_status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule group.
2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2091 class FirewallRuleGroupMetadata < Struct.new( :id, :arn, :name, :owner_id, :creator_request_id, :share_status) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The Amazon Web Services account ID for the account that created the rule group. When a rule group is shared with your account, this is the account that has shared the rule group with you.
2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2091 class FirewallRuleGroupMetadata < Struct.new( :id, :arn, :name, :owner_id, :creator_request_id, :share_status) SENSITIVE = [] include Aws::Structure end |
#share_status ⇒ String
Whether the rule group is shared with other Amazon Web Services accounts, or was shared with the current account by another Amazon Web Services account. Sharing is configured through Resource Access Manager (RAM).
2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2091 class FirewallRuleGroupMetadata < Struct.new( :id, :arn, :name, :owner_id, :creator_request_id, :share_status) SENSITIVE = [] include Aws::Structure end |