Class: Aws::Route53Resolver::Types::GetResolverQueryLogConfigPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::GetResolverQueryLogConfigPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the query logging configuration that you want to get the query logging policy for.
Instance Attribute Details
#arn ⇒ String
The ARN of the query logging configuration that you want to get the query logging policy for.
2362 2363 2364 2365 2366 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2362 class GetResolverQueryLogConfigPolicyRequest < Struct.new( :arn) SENSITIVE = [] include Aws::Structure end |