Class: Aws::Route53Resolver::Types::GetResolverRuleAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::GetResolverRuleAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resolver_rule_association_id ⇒ String
The ID of the Resolver rule association that you want to get information about.
Instance Attribute Details
#resolver_rule_association_id ⇒ String
The ID of the Resolver rule association that you want to get information about.
3102 3103 3104 3105 3106 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3102 class GetResolverRuleAssociationRequest < Struct.new( :resolver_rule_association_id) SENSITIVE = [] include Aws::Structure end |