Class: Aws::Route53Resolver::Types::ImportFirewallDomainsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ImportFirewallDomainsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_file_url ⇒ String
The fully qualified URL or URI of the file stored in Amazon Simple Storage Service (Amazon S3) that contains the list of domains to import.
-
#firewall_domain_list_id ⇒ String
The ID of the domain list that you want to modify with the import operation.
-
#operation ⇒ String
What you want DNS Firewall to do with the domains that are listed in the file.
Instance Attribute Details
#domain_file_url ⇒ String
The fully qualified URL or URI of the file stored in Amazon Simple Storage Service (Amazon S3) that contains the list of domains to import.
The file must be in an S3 bucket that’s in the same Region as your DNS Firewall. The file must be a text file and must contain a single domain per line.
2477 2478 2479 2480 2481 2482 2483 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2477 class ImportFirewallDomainsRequest < Struct.new( :firewall_domain_list_id, :operation, :domain_file_url) SENSITIVE = [] include Aws::Structure end |
#firewall_domain_list_id ⇒ String
The ID of the domain list that you want to modify with the import operation.
2477 2478 2479 2480 2481 2482 2483 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2477 class ImportFirewallDomainsRequest < Struct.new( :firewall_domain_list_id, :operation, :domain_file_url) SENSITIVE = [] include Aws::Structure end |
#operation ⇒ String
What you want DNS Firewall to do with the domains that are listed in the file. This must be set to REPLACE, which updates the domain list to exactly match the list in the file.
2477 2478 2479 2480 2481 2482 2483 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2477 class ImportFirewallDomainsRequest < Struct.new( :firewall_domain_list_id, :operation, :domain_file_url) SENSITIVE = [] include Aws::Structure end |