Class: Aws::Route53Resolver::Types::IpAddressResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

In the response to a [GetResolverEndpoint] request, information about the IP addresses that the Resolver endpoint uses for DNS queries.

[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverEndpoint.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeString

The date and time that the IP address was created, in Unix time format and Coordinated Universal Time (UTC).



2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
# File 'lib/aws-sdk-route53resolver/types.rb', line 2673

class IpAddressResponse < Struct.new(
  :ip_id,
  :subnet_id,
  :ip,
  :ipv_6,
  :status,
  :status_message,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#ipString

One IPv4 address that the Resolver endpoint uses for DNS queries.



2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
# File 'lib/aws-sdk-route53resolver/types.rb', line 2673

class IpAddressResponse < Struct.new(
  :ip_id,
  :subnet_id,
  :ip,
  :ipv_6,
  :status,
  :status_message,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#ip_idString

The ID of one IP address.



2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
# File 'lib/aws-sdk-route53resolver/types.rb', line 2673

class IpAddressResponse < Struct.new(
  :ip_id,
  :subnet_id,
  :ip,
  :ipv_6,
  :status,
  :status_message,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6String

One IPv6 address that the Resolver endpoint uses for DNS queries.



2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
# File 'lib/aws-sdk-route53resolver/types.rb', line 2673

class IpAddressResponse < Struct.new(
  :ip_id,
  :subnet_id,
  :ip,
  :ipv_6,
  :status,
  :status_message,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#modification_timeString

The date and time that the IP address was last modified, in Unix time format and Coordinated Universal Time (UTC).



2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
# File 'lib/aws-sdk-route53resolver/types.rb', line 2673

class IpAddressResponse < Struct.new(
  :ip_id,
  :subnet_id,
  :ip,
  :ipv_6,
  :status,
  :status_message,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

A status code that gives the current status of the request.



2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
# File 'lib/aws-sdk-route53resolver/types.rb', line 2673

class IpAddressResponse < Struct.new(
  :ip_id,
  :subnet_id,
  :ip,
  :ipv_6,
  :status,
  :status_message,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A message that provides additional information about the status of the request.



2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
# File 'lib/aws-sdk-route53resolver/types.rb', line 2673

class IpAddressResponse < Struct.new(
  :ip_id,
  :subnet_id,
  :ip,
  :ipv_6,
  :status,
  :status_message,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of one subnet.



2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
# File 'lib/aws-sdk-route53resolver/types.rb', line 2673

class IpAddressResponse < Struct.new(
  :ip_id,
  :subnet_id,
  :ip,
  :ipv_6,
  :status,
  :status_message,
  :creation_time,
  :modification_time)
  SENSITIVE = []
  include Aws::Structure
end