Class: Aws::Route53Resolver::Types::ListFirewallDomainsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListFirewallDomainsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domains ⇒ Array<String>
A list of the domains in the firewall domain list.
-
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response.
Instance Attribute Details
#domains ⇒ Array<String>
A list of the domains in the firewall domain list.
This might be a partial list of the domains that you’ve defined in the domain list. For information, see MaxResults.
2899 2900 2901 2902 2903 2904 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2899 class ListFirewallDomainsResponse < Struct.new( :next_token, :domains) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response. To retrieve the next batch of objects, provide this token in your next request.
2899 2900 2901 2902 2903 2904 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2899 class ListFirewallDomainsResponse < Struct.new( :next_token, :domains) SENSITIVE = [] include Aws::Structure end |