Class: Aws::Route53Resolver::Types::ListFirewallRuleGroupAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListFirewallRuleGroupAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_rule_group_id ⇒ String
The unique identifier of the firewall rule group that you want to retrieve the associations for.
-
#max_results ⇒ Integer
The maximum number of objects that you want Resolver to return for this request.
-
#next_token ⇒ String
For the first call to this list request, omit this value.
-
#priority ⇒ Integer
The setting that determines the processing order of the rule group among the rule groups that are associated with a single VPC.
-
#status ⇒ String
The association
Statussetting that you want DNS Firewall to filter on for the list. -
#vpc_id ⇒ String
The unique identifier of the VPC that you want to retrieve the associations for.
Instance Attribute Details
#firewall_rule_group_id ⇒ String
The unique identifier of the firewall rule group that you want to retrieve the associations for. Leave this blank to retrieve associations for any rule group.
2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2953 class ListFirewallRuleGroupAssociationsRequest < Struct.new( :firewall_rule_group_id, :vpc_id, :priority, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of objects that you want Resolver to return for this request. If more objects are available, in the response, Resolver provides a NextToken value that you can use in a subsequent call to get the next batch of objects.
If you don’t specify a value for MaxResults, Resolver returns up to 100 objects.
2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2953 class ListFirewallRuleGroupAssociationsRequest < Struct.new( :firewall_rule_group_id, :vpc_id, :priority, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
For the first call to this list request, omit this value.
When you request a list of objects, Resolver returns at most the number of objects specified in MaxResults. If more objects are available for retrieval, Resolver returns a NextToken value in the response. To retrieve the next batch of objects, use the token that was returned for the prior request in your next request.
2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2953 class ListFirewallRuleGroupAssociationsRequest < Struct.new( :firewall_rule_group_id, :vpc_id, :priority, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The setting that determines the processing order of the rule group among the rule groups that are associated with a single VPC. DNS Firewall filters VPC traffic starting from the rule group with the lowest numeric priority setting.
2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2953 class ListFirewallRuleGroupAssociationsRequest < Struct.new( :firewall_rule_group_id, :vpc_id, :priority, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The association Status setting that you want DNS Firewall to filter on for the list. If you don’t specify this, then DNS Firewall returns all associations, regardless of status.
2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2953 class ListFirewallRuleGroupAssociationsRequest < Struct.new( :firewall_rule_group_id, :vpc_id, :priority, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The unique identifier of the VPC that you want to retrieve the associations for. Leave this blank to retrieve associations for any VPC.
2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2953 class ListFirewallRuleGroupAssociationsRequest < Struct.new( :firewall_rule_group_id, :vpc_id, :priority, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |