Class: Aws::Route53Resolver::Types::ListFirewallRuleGroupAssociationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#firewall_rule_group_associationsArray<Types::FirewallRuleGroupAssociation>

A list of your firewall rule group associations.

This might be a partial list of the associations that you have defined. For information, see MaxResults.



3697
3698
3699
3700
3701
3702
# File 'lib/aws-sdk-route53resolver/types.rb', line 3697

class ListFirewallRuleGroupAssociationsResponse < Struct.new(
  :next_token,
  :firewall_rule_group_associations)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If objects are still available for retrieval, Resolver returns this token in the response. To retrieve the next batch of objects, provide this token in your next request.

Returns:

  • (String)


3697
3698
3699
3700
3701
3702
# File 'lib/aws-sdk-route53resolver/types.rb', line 3697

class ListFirewallRuleGroupAssociationsResponse < Struct.new(
  :next_token,
  :firewall_rule_group_associations)
  SENSITIVE = []
  include Aws::Structure
end