Class: Aws::Route53Resolver::Types::ListFirewallRuleGroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListFirewallRuleGroupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_rule_groups ⇒ Array<Types::FirewallRuleGroupMetadata>
A list of your firewall rule groups.
-
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response.
Instance Attribute Details
#firewall_rule_groups ⇒ Array<Types::FirewallRuleGroupMetadata>
A list of your firewall rule groups.
This might be a partial list of the rule groups that you have defined. For information, see MaxResults.
3030 3031 3032 3033 3034 3035 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3030 class ListFirewallRuleGroupsResponse < Struct.new( :next_token, :firewall_rule_groups) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response. To retrieve the next batch of objects, provide this token in your next request.
3030 3031 3032 3033 3034 3035 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3030 class ListFirewallRuleGroupsResponse < Struct.new( :next_token, :firewall_rule_groups) SENSITIVE = [] include Aws::Structure end |