Class: Aws::Route53Resolver::Types::ListFirewallRuleTypesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of objects that you want Resolver to return for this request. If more objects are available, in the response, Resolver provides a NextToken value that you can use in a subsequent call to get the next batch of objects.

Returns:

  • (Integer)


3781
3782
3783
3784
3785
3786
3787
# File 'lib/aws-sdk-route53resolver/types.rb', line 3781

class ListFirewallRuleTypesRequest < Struct.new(
  :rule_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

For the first call to this list request, omit this value. When you request a list of objects, Resolver returns at most the number of objects specified in MaxResults. If more objects are available for retrieval, Resolver provides a NextToken value in the response. To retrieve the next batch of objects, use the token that was returned for the prior request in your next request.

Returns:

  • (String)


3781
3782
3783
3784
3785
3786
3787
# File 'lib/aws-sdk-route53resolver/types.rb', line 3781

class ListFirewallRuleTypesRequest < Struct.new(
  :rule_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#rule_typeString

An optional filter that restricts the response to a single FirewallRuleType variant. Supported values: FirewallAdvancedContentCategory, FirewallAdvancedThreatCategory, DnsThreatProtection, and PartnerThreatProtection. If omitted, definitions across all variants are returned.

Returns:

  • (String)


3781
3782
3783
3784
3785
3786
3787
# File 'lib/aws-sdk-route53resolver/types.rb', line 3781

class ListFirewallRuleTypesRequest < Struct.new(
  :rule_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end