Class: Aws::Route53Resolver::Types::ListFirewallRulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListFirewallRulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
Optional additional filter for the rules to retrieve.
-
#firewall_rule_group_id ⇒ String
The unique identifier of the firewall rule group that you want to retrieve the rules for.
-
#max_results ⇒ Integer
The maximum number of objects that you want Resolver to return for this request.
-
#next_token ⇒ String
For the first call to this list request, omit this value.
-
#priority ⇒ Integer
Optional additional filter for the rules to retrieve.
Instance Attribute Details
#action ⇒ String
Optional additional filter for the rules to retrieve.
The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list, or a threat in a DNS Firewall Advanced rule:
-
ALLOW- Permit the request to go through. Not availabe for DNS Firewall Advanced rules. -
ALERT- Permit the request to go through but send an alert to the logs. -
BLOCK- Disallow the request. If this is specified, additional handling details are provided in the rule'sBlockResponsesetting.
3861 3862 3863 3864 3865 3866 3867 3868 3869 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3861 class ListFirewallRulesRequest < Struct.new( :firewall_rule_group_id, :priority, :action, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#firewall_rule_group_id ⇒ String
The unique identifier of the firewall rule group that you want to retrieve the rules for.
3861 3862 3863 3864 3865 3866 3867 3868 3869 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3861 class ListFirewallRulesRequest < Struct.new( :firewall_rule_group_id, :priority, :action, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of objects that you want Resolver to return for
this request. If more objects are available, in the response,
Resolver provides a NextToken value that you can use in a
subsequent call to get the next batch of objects.
If you don't specify a value for MaxResults, Resolver returns up
to 100 objects.
3861 3862 3863 3864 3865 3866 3867 3868 3869 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3861 class ListFirewallRulesRequest < Struct.new( :firewall_rule_group_id, :priority, :action, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
For the first call to this list request, omit this value.
When you request a list of objects, Resolver returns at most the
number of objects specified in MaxResults. If more objects are
available for retrieval, Resolver returns a NextToken value in the
response. To retrieve the next batch of objects, use the token that
was returned for the prior request in your next request.
3861 3862 3863 3864 3865 3866 3867 3868 3869 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3861 class ListFirewallRulesRequest < Struct.new( :firewall_rule_group_id, :priority, :action, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
Optional additional filter for the rules to retrieve.
The setting that determines the processing order of the rules in a rule group. DNS Firewall processes the rules in a rule group by order of priority, starting from the lowest setting.
3861 3862 3863 3864 3865 3866 3867 3868 3869 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3861 class ListFirewallRulesRequest < Struct.new( :firewall_rule_group_id, :priority, :action, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |