Class: Aws::Route53Resolver::Types::ListFirewallRulesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListFirewallRulesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_rules ⇒ Array<Types::FirewallRule>
A list of the rules that you have defined.
-
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response.
Instance Attribute Details
#firewall_rules ⇒ Array<Types::FirewallRule>
A list of the rules that you have defined.
This might be a partial list of the firewall rules that you’ve defined. For information, see MaxResults.
3115 3116 3117 3118 3119 3120 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3115 class ListFirewallRulesResponse < Struct.new( :next_token, :firewall_rules) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response. To retrieve the next batch of objects, provide this token in your next request.
3115 3116 3117 3118 3119 3120 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3115 class ListFirewallRulesResponse < Struct.new( :next_token, :firewall_rules) SENSITIVE = [] include Aws::Structure end |