Class: Aws::Route53Resolver::Types::ListResolverConfigsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If a response includes the last of the Resolver configurations that are associated with the current Amazon Web Services account, NextToken doesn't appear in the response.

If a response doesn't include the last of the configurations, you can get more configurations by submitting another ListResolverConfigs request. Get the value of NextToken that Amazon Route 53 returned in the previous response and include it in NextToken in the next request.

Returns:

  • (String)


3988
3989
3990
3991
3992
3993
# File 'lib/aws-sdk-route53resolver/types.rb', line 3988

class ListResolverConfigsResponse < Struct.new(
  :next_token,
  :resolver_configs)
  SENSITIVE = []
  include Aws::Structure
end

#resolver_configsArray<Types::ResolverConfig>

An array that contains one ResolverConfigs element for each Resolver configuration that is associated with the current Amazon Web Services account.

Returns:



3988
3989
3990
3991
3992
3993
# File 'lib/aws-sdk-route53resolver/types.rb', line 3988

class ListResolverConfigsResponse < Struct.new(
  :next_token,
  :resolver_configs)
  SENSITIVE = []
  include Aws::Structure
end