Class: Aws::Route53Resolver::Types::ListResolverDnssecConfigsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::Filter>

An optional specification to return a subset of objects.

Returns:



4020
4021
4022
4023
4024
4025
4026
# File 'lib/aws-sdk-route53resolver/types.rb', line 4020

class ListResolverDnssecConfigsRequest < Struct.new(
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Optional: An integer that specifies the maximum number of DNSSEC configuration results that you want Amazon Route 53 to return. If you don't specify a value for MaxResults, Route 53 returns up to 100 configuration per page.

Returns:

  • (Integer)


4020
4021
4022
4023
4024
4025
4026
# File 'lib/aws-sdk-route53resolver/types.rb', line 4020

class ListResolverDnssecConfigsRequest < Struct.new(
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

(Optional) If the current Amazon Web Services account has more than MaxResults DNSSEC configurations, use NextToken to get the second and subsequent pages of results.

For the first ListResolverDnssecConfigs request, omit this value.

For the second and subsequent requests, get the value of NextToken from the previous response and specify that value for NextToken in the request.

Returns:

  • (String)


4020
4021
4022
4023
4024
4025
4026
# File 'lib/aws-sdk-route53resolver/types.rb', line 4020

class ListResolverDnssecConfigsRequest < Struct.new(
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end