Class: Aws::Route53Resolver::Types::ListResolverDnssecConfigsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListResolverDnssecConfigsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If a response includes the last of the DNSSEC configurations that are associated with the current Amazon Web Services account,
NextTokendoesn't appear in the response. -
#resolver_dnssec_configs ⇒ Array<Types::ResolverDnssecConfig>
An array that contains one [ResolverDnssecConfig][1] element for each configuration for DNSSEC validation that is associated with the current Amazon Web Services account.
Instance Attribute Details
#next_token ⇒ String
If a response includes the last of the DNSSEC configurations that
are associated with the current Amazon Web Services account,
NextToken doesn't appear in the response.
If a response doesn't include the last of the configurations, you
can get more configurations by submitting another
ListResolverDnssecConfigs request. Get the value of NextToken
that Amazon Route 53 returned in the previous response and include
it in NextToken in the next request.
4057 4058 4059 4060 4061 4062 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4057 class ListResolverDnssecConfigsResponse < Struct.new( :next_token, :resolver_dnssec_configs) SENSITIVE = [] include Aws::Structure end |
#resolver_dnssec_configs ⇒ Array<Types::ResolverDnssecConfig>
An array that contains one ResolverDnssecConfig element for each configuration for DNSSEC validation that is associated with the current Amazon Web Services account. It doesn't contain disabled DNSSEC configurations for the resource.
4057 4058 4059 4060 4061 4062 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4057 class ListResolverDnssecConfigsResponse < Struct.new( :next_token, :resolver_dnssec_configs) SENSITIVE = [] include Aws::Structure end |