Class: Aws::Route53Resolver::Types::ListResolverEndpointIpAddressesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListResolverEndpointIpAddressesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of IP addresses that you want to return in the response to a
ListResolverEndpointIpAddressesrequest. -
#next_token ⇒ String
For the first
ListResolverEndpointIpAddressesrequest, omit this value. -
#resolver_endpoint_id ⇒ String
The ID of the Resolver endpoint that you want to get IP addresses for.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of IP addresses that you want to return in the response to a ListResolverEndpointIpAddresses request. If you don’t specify a value for MaxResults, Resolver returns up to 100 IP addresses.
3317 3318 3319 3320 3321 3322 3323 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3317 class ListResolverEndpointIpAddressesRequest < Struct.new( :resolver_endpoint_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
For the first ListResolverEndpointIpAddresses request, omit this value.
If the specified Resolver endpoint has more than MaxResults IP addresses, you can submit another ListResolverEndpointIpAddresses request to get the next group of IP addresses. In the next request, specify the value of NextToken from the previous response.
3317 3318 3319 3320 3321 3322 3323 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3317 class ListResolverEndpointIpAddressesRequest < Struct.new( :resolver_endpoint_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#resolver_endpoint_id ⇒ String
The ID of the Resolver endpoint that you want to get IP addresses for.
3317 3318 3319 3320 3321 3322 3323 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3317 class ListResolverEndpointIpAddressesRequest < Struct.new( :resolver_endpoint_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |