Class: Aws::Route53Resolver::Types::ListResolverEndpointIpAddressesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListResolverEndpointIpAddressesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ip_addresses ⇒ Array<Types::IpAddressResponse>
Information about the IP addresses in your VPC that DNS queries originate from (for outbound endpoints) or that you forward DNS queries to (for inbound endpoints).
-
#max_results ⇒ Integer
The value that you specified for
MaxResultsin the request. -
#next_token ⇒ String
If the specified endpoint has more than
MaxResultsIP addresses, you can submit anotherListResolverEndpointIpAddressesrequest to get the next group of IP addresses.
Instance Attribute Details
#ip_addresses ⇒ Array<Types::IpAddressResponse>
Information about the IP addresses in your VPC that DNS queries originate from (for outbound endpoints) or that you forward DNS queries to (for inbound endpoints).
3344 3345 3346 3347 3348 3349 3350 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3344 class ListResolverEndpointIpAddressesResponse < Struct.new( :next_token, :max_results, :ip_addresses) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The value that you specified for MaxResults in the request.
3344 3345 3346 3347 3348 3349 3350 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3344 class ListResolverEndpointIpAddressesResponse < Struct.new( :next_token, :max_results, :ip_addresses) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the specified endpoint has more than MaxResults IP addresses, you can submit another ListResolverEndpointIpAddresses request to get the next group of IP addresses. In the next request, specify the value of NextToken from the previous response.
3344 3345 3346 3347 3348 3349 3350 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3344 class ListResolverEndpointIpAddressesResponse < Struct.new( :next_token, :max_results, :ip_addresses) SENSITIVE = [] include Aws::Structure end |