Class: Aws::Route53Resolver::Types::ListResolverEndpointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListResolverEndpointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
An optional specification to return a subset of Resolver endpoints, such as all inbound Resolver endpoints.
-
#max_results ⇒ Integer
The maximum number of Resolver endpoints that you want to return in the response to a
ListResolverEndpointsrequest. -
#next_token ⇒ String
For the first
ListResolverEndpointsrequest, omit this value.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
An optional specification to return a subset of Resolver endpoints, such as all inbound Resolver endpoints.
ListResolverEndpoints request
and specify the NextToken parameter, you must use the same values
for Filters, if any, as in the previous request.
4152 4153 4154 4155 4156 4157 4158 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4152 class ListResolverEndpointsRequest < Struct.new( :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of Resolver endpoints that you want to return in
the response to a ListResolverEndpoints request. If you don't
specify a value for MaxResults, Resolver returns up to 100
Resolver endpoints.
4152 4153 4154 4155 4156 4157 4158 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4152 class ListResolverEndpointsRequest < Struct.new( :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
For the first ListResolverEndpoints request, omit this value.
If you have more than MaxResults Resolver endpoints, you can
submit another ListResolverEndpoints request to get the next group
of Resolver endpoints. In the next request, specify the value of
NextToken from the previous response.
4152 4153 4154 4155 4156 4157 4158 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4152 class ListResolverEndpointsRequest < Struct.new( :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |