Class: Aws::Route53Resolver::Types::ListResolverEndpointsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The value that you specified for MaxResults in the request.

Returns:

  • (Integer)


4178
4179
4180
4181
4182
4183
4184
# File 'lib/aws-sdk-route53resolver/types.rb', line 4178

class ListResolverEndpointsResponse < Struct.new(
  :next_token,
  :max_results,
  :resolver_endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If more than MaxResults IP addresses match the specified criteria, you can submit another ListResolverEndpoint request to get the next group of results. In the next request, specify the value of NextToken from the previous response.

Returns:

  • (String)


4178
4179
4180
4181
4182
4183
4184
# File 'lib/aws-sdk-route53resolver/types.rb', line 4178

class ListResolverEndpointsResponse < Struct.new(
  :next_token,
  :max_results,
  :resolver_endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#resolver_endpointsArray<Types::ResolverEndpoint>

The Resolver endpoints that were created by using the current Amazon Web Services account, and that match the specified filters, if any.

Returns:



4178
4179
4180
4181
4182
4183
4184
# File 'lib/aws-sdk-route53resolver/types.rb', line 4178

class ListResolverEndpointsResponse < Struct.new(
  :next_token,
  :max_results,
  :resolver_endpoints)
  SENSITIVE = []
  include Aws::Structure
end