Class: Aws::Route53Resolver::Types::ListResolverQueryLogConfigAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListResolverQueryLogConfigAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
An optional specification to return a subset of query logging associations.
-
#max_results ⇒ Integer
The maximum number of query logging associations that you want to return in the response to a
ListResolverQueryLogConfigAssociationsrequest. -
#next_token ⇒ String
For the first
ListResolverQueryLogConfigAssociationsrequest, omit this value. -
#sort_by ⇒ String
The element that you want Resolver to sort query logging associations by.
-
#sort_order ⇒ String
If you specified a value for
SortBy, the order that you want query logging associations to be listed in,ASCENDINGorDESCENDING.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
An optional specification to return a subset of query logging associations.
ListResolverQueryLogConfigAssociations request and specify the
NextToken parameter, you must use the same values for Filters,
if any, as in the previous request.
4284 4285 4286 4287 4288 4289 4290 4291 4292 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4284 class ListResolverQueryLogConfigAssociationsRequest < Struct.new( :max_results, :next_token, :filters, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of query logging associations that you want to
return in the response to a ListResolverQueryLogConfigAssociations
request. If you don't specify a value for MaxResults, Resolver
returns up to 100 query logging associations.
4284 4285 4286 4287 4288 4289 4290 4291 4292 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4284 class ListResolverQueryLogConfigAssociationsRequest < Struct.new( :max_results, :next_token, :filters, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
For the first ListResolverQueryLogConfigAssociations request, omit
this value.
If there are more than MaxResults query logging associations that
match the values that you specify for Filters, you can submit
another ListResolverQueryLogConfigAssociations request to get the
next group of associations. In the next request, specify the value
of NextToken from the previous response.
4284 4285 4286 4287 4288 4289 4290 4291 4292 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4284 class ListResolverQueryLogConfigAssociationsRequest < Struct.new( :max_results, :next_token, :filters, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The element that you want Resolver to sort query logging associations by.
ListResolverQueryLogConfigAssociations request and specify the
NextToken parameter, you must use the same value for SortBy, if
any, as in the previous request.
Valid values include the following elements:
-
CreationTime: The ID of the query logging association. -
Error: If the value ofStatusisFAILED, the value ofErrorindicates the cause: -
DESTINATION_NOT_FOUND: The specified destination (for example, an Amazon S3 bucket) was deleted. -
ACCESS_DENIED: Permissions don't allow sending logs to the destination. IfStatusis a value other thanFAILED,ERRORis null. -
Id: The ID of the query logging association -
ResolverQueryLogConfigId: The ID of the query logging configuration -
ResourceId: The ID of the VPC that is associated with the query logging configuration -
Status: The current status of the configuration. Valid values include the following: -
CREATING: Resolver is creating an association between an Amazon VPC and a query logging configuration. -
CREATED: The association between an Amazon VPC and a query logging configuration was successfully created. Resolver is logging queries that originate in the specified VPC. -
DELETING: Resolver is deleting this query logging association. -
FAILED: Resolver either couldn't create or couldn't delete the query logging association. Here are two common causes:-
The specified destination (for example, an Amazon S3 bucket) was deleted.
-
Permissions don't allow sending logs to the destination.
-
4284 4285 4286 4287 4288 4289 4290 4291 4292 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4284 class ListResolverQueryLogConfigAssociationsRequest < Struct.new( :max_results, :next_token, :filters, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
If you specified a value for SortBy, the order that you want query
logging associations to be listed in, ASCENDING or DESCENDING.
ListResolverQueryLogConfigAssociations request and specify the
NextToken parameter, you must use the same value for SortOrder,
if any, as in the previous request.
4284 4285 4286 4287 4288 4289 4290 4291 4292 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4284 class ListResolverQueryLogConfigAssociationsRequest < Struct.new( :max_results, :next_token, :filters, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |