Class: Aws::Route53Resolver::Types::ListResolverQueryLogConfigAssociationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListResolverQueryLogConfigAssociationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If there are more than
MaxResultsquery logging associations, you can submit anotherListResolverQueryLogConfigAssociationsrequest to get the next group of associations. -
#resolver_query_log_config_associations ⇒ Array<Types::ResolverQueryLogConfigAssociation>
A list that contains one
ResolverQueryLogConfigAssociationselement for each query logging association that matches the values that you specified forFilter. -
#total_count ⇒ Integer
The total number of query logging associations that were created by the current account in the specified Region.
-
#total_filtered_count ⇒ Integer
The total number of query logging associations that were created by the current account in the specified Region and that match the filters that were specified in the
ListResolverQueryLogConfigAssociationsrequest.
Instance Attribute Details
#next_token ⇒ String
If there are more than MaxResults query logging associations, you can submit another ListResolverQueryLogConfigAssociations request to get the next group of associations. In the next request, specify the value of NextToken from the previous response.
3555 3556 3557 3558 3559 3560 3561 3562 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3555 class ListResolverQueryLogConfigAssociationsResponse < Struct.new( :next_token, :total_count, :total_filtered_count, :resolver_query_log_config_associations) SENSITIVE = [] include Aws::Structure end |
#resolver_query_log_config_associations ⇒ Array<Types::ResolverQueryLogConfigAssociation>
A list that contains one ResolverQueryLogConfigAssociations element for each query logging association that matches the values that you specified for Filter.
3555 3556 3557 3558 3559 3560 3561 3562 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3555 class ListResolverQueryLogConfigAssociationsResponse < Struct.new( :next_token, :total_count, :total_filtered_count, :resolver_query_log_config_associations) SENSITIVE = [] include Aws::Structure end |
#total_count ⇒ Integer
The total number of query logging associations that were created by the current account in the specified Region. This count can differ from the number of associations that are returned in a ListResolverQueryLogConfigAssociations response, depending on the values that you specify in the request.
3555 3556 3557 3558 3559 3560 3561 3562 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3555 class ListResolverQueryLogConfigAssociationsResponse < Struct.new( :next_token, :total_count, :total_filtered_count, :resolver_query_log_config_associations) SENSITIVE = [] include Aws::Structure end |
#total_filtered_count ⇒ Integer
The total number of query logging associations that were created by the current account in the specified Region and that match the filters that were specified in the ListResolverQueryLogConfigAssociations request. For the total number of associations that were created by the current account in the specified Region, see TotalCount.
3555 3556 3557 3558 3559 3560 3561 3562 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3555 class ListResolverQueryLogConfigAssociationsResponse < Struct.new( :next_token, :total_count, :total_filtered_count, :resolver_query_log_config_associations) SENSITIVE = [] include Aws::Structure end |