Class: Aws::Route53Resolver::Types::ListResolverQueryLogConfigsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If there are more than MaxResults query logging configurations, you can submit another ListResolverQueryLogConfigs request to get the next group of configurations. In the next request, specify the value of NextToken from the previous response.

Returns:

  • (String)


4478
4479
4480
4481
4482
4483
4484
4485
# File 'lib/aws-sdk-route53resolver/types.rb', line 4478

class ListResolverQueryLogConfigsResponse < Struct.new(
  :next_token,
  :total_count,
  :total_filtered_count,
  :resolver_query_log_configs)
  SENSITIVE = []
  include Aws::Structure
end

#resolver_query_log_configsArray<Types::ResolverQueryLogConfig>

A list that contains one ResolverQueryLogConfig element for each query logging configuration that matches the values that you specified for Filter.

Returns:



4478
4479
4480
4481
4482
4483
4484
4485
# File 'lib/aws-sdk-route53resolver/types.rb', line 4478

class ListResolverQueryLogConfigsResponse < Struct.new(
  :next_token,
  :total_count,
  :total_filtered_count,
  :resolver_query_log_configs)
  SENSITIVE = []
  include Aws::Structure
end

#total_countInteger

The total number of query logging configurations that were created by the current account in the specified Region. This count can differ from the number of query logging configurations that are returned in a ListResolverQueryLogConfigs response, depending on the values that you specify in the request.

Returns:

  • (Integer)


4478
4479
4480
4481
4482
4483
4484
4485
# File 'lib/aws-sdk-route53resolver/types.rb', line 4478

class ListResolverQueryLogConfigsResponse < Struct.new(
  :next_token,
  :total_count,
  :total_filtered_count,
  :resolver_query_log_configs)
  SENSITIVE = []
  include Aws::Structure
end

#total_filtered_countInteger

The total number of query logging configurations that were created by the current account in the specified Region and that match the filters that were specified in the ListResolverQueryLogConfigs request. For the total number of query logging configurations that were created by the current account in the specified Region, see TotalCount.

Returns:

  • (Integer)


4478
4479
4480
4481
4482
4483
4484
4485
# File 'lib/aws-sdk-route53resolver/types.rb', line 4478

class ListResolverQueryLogConfigsResponse < Struct.new(
  :next_token,
  :total_count,
  :total_filtered_count,
  :resolver_query_log_configs)
  SENSITIVE = []
  include Aws::Structure
end