Class: Aws::Route53Resolver::Types::ListResolverRuleAssociationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListResolverRuleAssociationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The value that you specified for
MaxResultsin the request. -
#next_token ⇒ String
If more than
MaxResultsrule associations match the specified criteria, you can submit anotherListResolverRuleAssociationrequest to get the next group of results. -
#resolver_rule_associations ⇒ Array<Types::ResolverRuleAssociation>
The associations that were created between Resolver rules and VPCs using the current Amazon Web Services account, and that match the specified filters, if any.
Instance Attribute Details
#max_results ⇒ Integer
The value that you specified for MaxResults in the request.
4544 4545 4546 4547 4548 4549 4550 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4544 class ListResolverRuleAssociationsResponse < Struct.new( :next_token, :max_results, :resolver_rule_associations) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If more than MaxResults rule associations match the specified
criteria, you can submit another ListResolverRuleAssociation
request to get the next group of results. In the next request,
specify the value of NextToken from the previous response.
4544 4545 4546 4547 4548 4549 4550 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4544 class ListResolverRuleAssociationsResponse < Struct.new( :next_token, :max_results, :resolver_rule_associations) SENSITIVE = [] include Aws::Structure end |
#resolver_rule_associations ⇒ Array<Types::ResolverRuleAssociation>
The associations that were created between Resolver rules and VPCs using the current Amazon Web Services account, and that match the specified filters, if any.
4544 4545 4546 4547 4548 4549 4550 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4544 class ListResolverRuleAssociationsResponse < Struct.new( :next_token, :max_results, :resolver_rule_associations) SENSITIVE = [] include Aws::Structure end |