Class: Aws::Route53Resolver::Types::ListResolverRulesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListResolverRulesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The value that you specified for
MaxResultsin the request. -
#next_token ⇒ String
If more than
MaxResultsResolver rules match the specified criteria, you can submit anotherListResolverRulesrequest to get the next group of results. -
#resolver_rules ⇒ Array<Types::ResolverRule>
The Resolver rules that were created using the current Amazon Web Services account and that match the specified filters, if any.
Instance Attribute Details
#max_results ⇒ Integer
The value that you specified for MaxResults in the request.
3836 3837 3838 3839 3840 3841 3842 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3836 class ListResolverRulesResponse < Struct.new( :next_token, :max_results, :resolver_rules) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If more than MaxResults Resolver rules match the specified criteria, you can submit another ListResolverRules request to get the next group of results. In the next request, specify the value of NextToken from the previous response.
3836 3837 3838 3839 3840 3841 3842 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3836 class ListResolverRulesResponse < Struct.new( :next_token, :max_results, :resolver_rules) SENSITIVE = [] include Aws::Structure end |
#resolver_rules ⇒ Array<Types::ResolverRule>
The Resolver rules that were created using the current Amazon Web Services account and that match the specified filters, if any.
3836 3837 3838 3839 3840 3841 3842 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3836 class ListResolverRulesResponse < Struct.new( :next_token, :max_results, :resolver_rules) SENSITIVE = [] include Aws::Structure end |