Class: Aws::Route53Resolver::Types::ResolverEndpoint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN (Amazon Resource Name) for the Resolver endpoint.

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeString

The date and time that the endpoint was created, in Unix time format and Coordinated Universal Time (UTC).

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#creator_request_idString

A unique string that identifies the request that created the Resolver endpoint. The ‘CreatorRequestId` allows failed requests to be retried without the risk of running the operation twice.

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#directionString

Indicates whether the Resolver endpoint allows inbound or outbound DNS queries:

  • ‘INBOUND`: allows DNS queries to your VPC from your network

  • ‘OUTBOUND`: allows DNS queries from your VPC to your network

  • ‘INBOUND_DELEGATION`: Resolver delegates queries to Route 53 private hosted zones from your network.

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#dns_64_enabledBoolean

Indicates whether DNS64 is enabled for the inbound Resolver endpoint. When ‘true`, Route 53 Resolver synthesizes AAAA (IPv6) records for IPv4-only services by prepending the `64:ff9b::/96` prefix to the IPv4 address.

Returns:

  • (Boolean)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#host_vpc_idString

The ID of the VPC that you want to create the Resolver endpoint in.

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the Resolver endpoint.

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_countInteger

The number of IP addresses that the Resolver endpoint can use for DNS queries.

Returns:

  • (Integer)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_internet_access_enabledBoolean

Indicates whether IPv6 internet access is enabled for the outbound Resolver endpoint. When ‘true`, the endpoint elastic network interfaces (ENIs) can forward DNS queries to public IPv6 targets through an internet gateway.

Returns:

  • (Boolean)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#modification_timeString

The date and time that the endpoint was last modified, in Unix time format and Coordinated Universal Time (UTC).

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name that you assigned to the Resolver endpoint when you submitted a [CreateResolverEndpoint] request.

[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverEndpoint.html

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_arnString

The ARN (Amazon Resource Name) for the Outpost.

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#preferred_instance_typeString

The Amazon EC2 instance type.

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#protocolsArray<String>

Protocols used for the endpoint. DoH-FIPS is applicable for a default inbound endpoints only.

For an inbound endpoint you can apply the protocols as follows:

  • Do53 and DoH in combination.

  • Do53 and DoH-FIPS in combination.

  • Do53 alone.

  • DoH alone.

  • DoH-FIPS alone.

  • None, which is treated as Do53.

For a delegation inbound endpoint you can use Do53 only.

For an outbound endpoint you can apply the protocols as follows:

  • Do53 and DoH in combination.

  • Do53 alone.

  • DoH alone.

  • None, which is treated as Do53.

Returns:

  • (Array<String>)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#resolver_endpoint_typeString

The Resolver endpoint IP address type.

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#rni_enhanced_metrics_enabledBoolean

Indicates whether RNI enhanced metrics are enabled for the Resolver endpoint. When enabled, one-minute granular metrics are published in CloudWatch for each RNI associated with this endpoint. When disabled, these metrics are not published.

Returns:

  • (Boolean)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The ID of one or more security groups that control access to this VPC. The security group must include one or more inbound rules (for inbound endpoints) or outbound rules (for outbound endpoints). Inbound and outbound rules must allow TCP and UDP access. For inbound access, open port 53. For outbound access, open the port that you’re using for DNS queries on your network.

Returns:

  • (Array<String>)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

A code that specifies the current status of the Resolver endpoint. Valid values include the following:

  • ‘CREATING`: Resolver is creating and configuring one or more Amazon VPC network interfaces for this endpoint.

  • ‘OPERATIONAL`: The Amazon VPC network interfaces for this endpoint are correctly configured and able to pass inbound or outbound DNS queries between your network and Resolver.

  • ‘UPDATING`: Resolver is associating or disassociating one or more network interfaces with this endpoint.

  • ‘AUTO_RECOVERING`: Resolver is trying to recover one or more of the network interfaces that are associated with this endpoint. During the recovery process, the endpoint functions with limited capacity because of the limit on the number of DNS queries per IP address (per network interface). For the current limit, see [Limits on Route 53 Resolver].

  • ‘ACTION_NEEDED`: This endpoint is unhealthy, and Resolver can’t automatically recover it. To resolve the problem, we recommend that you check each IP address that you associated with the endpoint. For each IP address that isn’t available, add another IP address and then delete the IP address that isn’t available. (An endpoint must always include at least two IP addresses.) A status of ‘ACTION_NEEDED` can have a variety of causes. Here are two common causes:

    • One or more of the network interfaces that are associated with the endpoint were deleted using Amazon VPC.

    • The network interface couldn’t be created for some reason that’s outside the control of Resolver.

  • ‘DELETING`: Resolver is deleting this endpoint and the associated network interfaces.

[1]: docs.aws.amazon.com/Route53/latest/DeveloperGuide/DNSLimitations.html#limits-api-entities-resolver

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A detailed description of the status of the Resolver endpoint.

Returns:

  • (String)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#target_name_server_metrics_enabledBoolean

Indicates whether target name server metrics are enabled for the outbound Resolver endpoint. When enabled, one-minute granular metrics are published in CloudWatch for each target name server associated with this endpoint. When disabled, these metrics are not published. This feature is not supported for inbound Resolver endpoint.

Returns:

  • (Boolean)


5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
# File 'lib/aws-sdk-route53resolver/types.rb', line 5017

class ResolverEndpoint < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :name,
  :security_group_ids,
  :direction,
  :ip_address_count,
  :host_vpc_id,
  :status,
  :status_message,
  :creation_time,
  :modification_time,
  :outpost_arn,
  :preferred_instance_type,
  :resolver_endpoint_type,
  :protocols,
  :rni_enhanced_metrics_enabled,
  :target_name_server_metrics_enabled,
  :dns_64_enabled,
  :ipv_6_internet_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end