Class: Aws::Route53Resolver::Types::ResolverQueryLogConfigAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ResolverQueryLogConfigAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
In the response to an [AssociateResolverQueryLogConfig], [DisassociateResolverQueryLogConfig], [GetResolverQueryLogConfigAssociation], or [ListResolverQueryLogConfigAssociations], request, a complex type that contains settings for a specified association between an Amazon VPC and a query logging configuration.
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverQueryLogConfig.html [2]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverQueryLogConfig.html [3]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverQueryLogConfigAssociation.html [4]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverQueryLogConfigAssociations.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ String
The date and time that the VPC was associated with the query logging configuration, in Unix time format and Coordinated Universal Time (UTC).
-
#error ⇒ String
If the value of ‘Status` is `FAILED`, the value of `Error` indicates the cause:.
-
#error_message ⇒ String
Contains additional information about the error.
-
#id ⇒ String
The ID of the query logging association.
-
#resolver_query_log_config_id ⇒ String
The ID of the query logging configuration that a VPC is associated with.
-
#resource_id ⇒ String
The ID of the Amazon VPC that is associated with the query logging configuration.
-
#status ⇒ String
The status of the specified query logging association.
Instance Attribute Details
#creation_time ⇒ String
The date and time that the VPC was associated with the query logging configuration, in Unix time format and Coordinated Universal Time (UTC).
4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4602 class ResolverQueryLogConfigAssociation < Struct.new( :id, :resolver_query_log_config_id, :resource_id, :status, :error, :error_message, :creation_time) SENSITIVE = [] include Aws::Structure end |
#error ⇒ String
If the value of ‘Status` is `FAILED`, the value of `Error` indicates the cause:
-
‘DESTINATION_NOT_FOUND`: The specified destination (for example, an Amazon S3 bucket) was deleted.
-
‘ACCESS_DENIED`: Permissions don’t allow sending logs to the destination.
If the value of ‘Status` is a value other than `FAILED`, `Error` is null.
4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4602 class ResolverQueryLogConfigAssociation < Struct.new( :id, :resolver_query_log_config_id, :resource_id, :status, :error, :error_message, :creation_time) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
Contains additional information about the error. If the value or ‘Error` is null, the value of `ErrorMessage` also is null.
4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4602 class ResolverQueryLogConfigAssociation < Struct.new( :id, :resolver_query_log_config_id, :resource_id, :status, :error, :error_message, :creation_time) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the query logging association.
4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4602 class ResolverQueryLogConfigAssociation < Struct.new( :id, :resolver_query_log_config_id, :resource_id, :status, :error, :error_message, :creation_time) SENSITIVE = [] include Aws::Structure end |
#resolver_query_log_config_id ⇒ String
The ID of the query logging configuration that a VPC is associated with.
4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4602 class ResolverQueryLogConfigAssociation < Struct.new( :id, :resolver_query_log_config_id, :resource_id, :status, :error, :error_message, :creation_time) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the Amazon VPC that is associated with the query logging configuration.
4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4602 class ResolverQueryLogConfigAssociation < Struct.new( :id, :resolver_query_log_config_id, :resource_id, :status, :error, :error_message, :creation_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the specified query logging association. Valid values include the following:
-
‘CREATING`: Resolver is creating an association between an Amazon VPC and a query logging configuration.
-
‘ACTIVE`: The association between an Amazon VPC and a query logging configuration was successfully created. Resolver is logging queries that originate in the specified VPC.
-
‘DELETING`: Resolver is deleting this query logging association.
-
‘FAILED`: Resolver either couldn’t create or couldn’t delete the query logging association.
4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4602 class ResolverQueryLogConfigAssociation < Struct.new( :id, :resolver_query_log_config_id, :resource_id, :status, :error, :error_message, :creation_time) SENSITIVE = [] include Aws::Structure end |