Class: Aws::Route53Resolver::Types::ResolverRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN (Amazon Resource Name) for the Resolver rule specified by ‘Id`.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeString

The date and time that the Resolver rule was created, in Unix time format and Coordinated Universal Time (UTC).

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#creator_request_idString

A unique string that you specified when you created the Resolver rule. ‘CreatorRequestId` identifies the request and allows failed requests to be retried without the risk of running the operation twice.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#delegation_recordString

DNS queries with delegation records that point to this domain name are forwarded to resolvers on your network.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

DNS queries for this domain name are forwarded to the IP addresses that are specified in ‘TargetIps`. If a query matches multiple Resolver rules (example.com and www.example.com), the query is routed using the Resolver rule that contains the most specific domain name (www.example.com).

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID that Resolver assigned to the Resolver rule when you created it.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#modification_timeString

The date and time that the Resolver rule was last updated, in Unix time format and Coordinated Universal Time (UTC).

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name for the Resolver rule, which you specified when you created the Resolver rule.

The name can be up to 64 characters long and can contain letters (a-z, A-Z), numbers (0-9), hyphens (-), underscores (_), and spaces. The name cannot consist of only numbers.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

When a rule is shared with another Amazon Web Services account, the account ID of the account that the rule is shared with.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#resolver_endpoint_idString

The ID of the endpoint that the rule is associated with.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#rule_typeString

When you want to forward DNS queries for specified domain name to resolvers on your network, specify ‘FORWARD` or `DELEGATE`. If a query matches multiple Resolver rules (example.com and www.example.com), outbound DNS queries are routed using the Resolver rule that contains the most specific domain name (www.example.com).

When you have a forwarding rule to forward DNS queries for a domain to your network and you want Resolver to process queries for a subdomain of that domain, specify ‘SYSTEM`.

For example, to forward DNS queries for example.com to resolvers on your network, you create a rule and specify ‘FORWARD` for `RuleType`. To then have Resolver process queries for apex.example.com, you create a rule and specify `SYSTEM` for `RuleType`.

Currently, only Resolver can create rules that have a value of ‘RECURSIVE` for `RuleType`.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#share_statusString

Whether the rule is shared and, if so, whether the current account is sharing the rule with another account, or another account is sharing the rule with the current account.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

A code that specifies the current status of the Resolver rule.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A detailed description of the status of a Resolver rule.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end

#target_ipsArray<Types::TargetAddress>

An array that contains the IP addresses and ports that an outbound endpoint forwards DNS queries to. Typically, these are the IP addresses of DNS resolvers on your network.

Returns:



5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
# File 'lib/aws-sdk-route53resolver/types.rb', line 5339

class ResolverRule < Struct.new(
  :id,
  :creator_request_id,
  :arn,
  :domain_name,
  :status,
  :status_message,
  :rule_type,
  :name,
  :target_ips,
  :resolver_endpoint_id,
  :owner_id,
  :share_status,
  :creation_time,
  :modification_time,
  :delegation_record)
  SENSITIVE = []
  include Aws::Structure
end