Class: Aws::Route53Resolver::Types::ResourceInUseException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ResourceInUseException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
The resource that you tried to update or delete is currently in use.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#resource_type ⇒ String
For a ‘ResourceInUseException` error, the type of resource that is currently in use.
Instance Attribute Details
#message ⇒ String
5489 5490 5491 5492 5493 5494 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5489 class ResourceInUseException < Struct.new( :message, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
For a ‘ResourceInUseException` error, the type of resource that is currently in use.
5489 5490 5491 5492 5493 5494 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5489 class ResourceInUseException < Struct.new( :message, :resource_type) SENSITIVE = [] include Aws::Structure end |