Class: Aws::Route53Resolver::Types::TargetAddress
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::TargetAddress
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
In a [CreateResolverRule] request, an array of the IPs that you want to forward DNS queries to.
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverRule.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ip ⇒ String
One IPv4 address that you want to forward DNS queries to.
-
#ipv_6 ⇒ String
One IPv6 address that you want to forward DNS queries to.
-
#port ⇒ Integer
The port at ‘Ip` that you want to forward DNS queries to.
-
#protocol ⇒ String
The protocols for the target address.
-
#server_name_indication ⇒ String
The Server Name Indication of the DoH server that you want to forward queries to.
Instance Attribute Details
#ip ⇒ String
One IPv4 address that you want to forward DNS queries to.
5825 5826 5827 5828 5829 5830 5831 5832 5833 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5825 class TargetAddress < Struct.new( :ip, :port, :ipv_6, :protocol, :server_name_indication) SENSITIVE = [] include Aws::Structure end |
#ipv_6 ⇒ String
One IPv6 address that you want to forward DNS queries to.
5825 5826 5827 5828 5829 5830 5831 5832 5833 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5825 class TargetAddress < Struct.new( :ip, :port, :ipv_6, :protocol, :server_name_indication) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port at ‘Ip` that you want to forward DNS queries to.
5825 5826 5827 5828 5829 5830 5831 5832 5833 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5825 class TargetAddress < Struct.new( :ip, :port, :ipv_6, :protocol, :server_name_indication) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocols for the target address. The protocol you choose needs to be supported by the outbound endpoint of the Resolver rule.
5825 5826 5827 5828 5829 5830 5831 5832 5833 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5825 class TargetAddress < Struct.new( :ip, :port, :ipv_6, :protocol, :server_name_indication) SENSITIVE = [] include Aws::Structure end |
#server_name_indication ⇒ String
The Server Name Indication of the DoH server that you want to forward queries to. This is only used if the Protocol of the ‘TargetAddress` is `DoH`.
5825 5826 5827 5828 5829 5830 5831 5832 5833 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5825 class TargetAddress < Struct.new( :ip, :port, :ipv_6, :protocol, :server_name_indication) SENSITIVE = [] include Aws::Structure end |