Class: Aws::Route53Resolver::Types::UpdateResolverEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::UpdateResolverEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dns_64_enabled ⇒ Boolean
Specifies whether DNS64 is enabled for the inbound Resolver endpoint.
-
#ipv_6_internet_access_enabled ⇒ Boolean
Specifies whether IPv6 internet access is enabled for the outbound Resolver endpoint.
-
#name ⇒ String
The name of the Resolver endpoint that you want to update.
-
#protocols ⇒ Array<String>
The protocols you want to use for the endpoint.
-
#resolver_endpoint_id ⇒ String
The ID of the Resolver endpoint that you want to update.
-
#resolver_endpoint_type ⇒ String
Specifies the endpoint type for what type of IP address the endpoint uses to forward DNS queries.
-
#rni_enhanced_metrics_enabled ⇒ Boolean
Updates whether RNI enhanced metrics are enabled for the Resolver endpoints.
-
#target_name_server_metrics_enabled ⇒ Boolean
Updates whether target name server metrics are enabled for the outbound Resolver endpoints.
-
#update_ip_addresses ⇒ Array<Types::UpdateIpAddress>
Specifies the IPv6 address when you update the Resolver endpoint from IPv4 to dual-stack.
Instance Attribute Details
#dns_64_enabled ⇒ Boolean
Specifies whether DNS64 is enabled for the inbound Resolver endpoint. When set to ‘true`, Route 53 Resolver synthesizes AAAA (IPv6) records for IPv4-only services by prepending the `64:ff9b::/96` prefix to the IPv4 address. This enables IPv6-only clients that send queries through the inbound endpoint to reach IPv4-only services. DNS64 works with NAT64 to provide complete IPv6-to-IPv4 translation.
5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5755 class UpdateResolverEndpointRequest < Struct.new( :resolver_endpoint_id, :name, :resolver_endpoint_type, :update_ip_addresses, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#ipv_6_internet_access_enabled ⇒ Boolean
Specifies whether IPv6 internet access is enabled for the outbound Resolver endpoint. When set to ‘true`, the endpoint elastic network interfaces (ENIs) can forward DNS queries to public IPv6 targets through an internet gateway.
When you enable IPv6 internet access, use network controls like security groups, NACLs, or egress-only internet gateways to protect the endpoint ENIs from unsolicited ingress traffic. Be aware that some network controls can affect DNS query throughput due to connection tracking. For more information, see [Amazon EC2 security group connection tracking] and [Resolver endpoint scaling].
[1]: docs.aws.amazon.com/ec2/latest/userguide/security-group-connection-tracking.html [2]: docs.aws.amazon.com/Route53/latest/DeveloperGuide/best-practices-resolver-endpoint-scaling.html
5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5755 class UpdateResolverEndpointRequest < Struct.new( :resolver_endpoint_id, :name, :resolver_endpoint_type, :update_ip_addresses, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Resolver endpoint that you want to update.
5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5755 class UpdateResolverEndpointRequest < Struct.new( :resolver_endpoint_id, :name, :resolver_endpoint_type, :update_ip_addresses, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#protocols ⇒ Array<String>
The protocols you want to use for the endpoint. DoH-FIPS is applicable for default inbound endpoints only.
For a default inbound endpoint you can apply the protocols as follows:
-
Do53 and DoH in combination.
-
Do53 and DoH-FIPS in combination.
-
Do53 alone.
-
DoH alone.
-
DoH-FIPS alone.
-
None, which is treated as Do53.
For a delegation inbound endpoint you can use Do53 only.
For an outbound endpoint you can apply the protocols as follows:
-
Do53 and DoH in combination.
-
Do53 alone.
-
DoH alone.
-
None, which is treated as Do53.
You can’t change the protocol of an inbound endpoint directly from only Do53 to only DoH, or DoH-FIPS. This is to prevent a sudden disruption to incoming traffic that relies on Do53. To change the protocol from Do53 to DoH, or DoH-FIPS, you must first enable both Do53 and DoH, or Do53 and DoH-FIPS, to make sure that all incoming traffic has transferred to using the DoH protocol, or DoH-FIPS, and then remove the Do53.
5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5755 class UpdateResolverEndpointRequest < Struct.new( :resolver_endpoint_id, :name, :resolver_endpoint_type, :update_ip_addresses, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#resolver_endpoint_id ⇒ String
The ID of the Resolver endpoint that you want to update.
5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5755 class UpdateResolverEndpointRequest < Struct.new( :resolver_endpoint_id, :name, :resolver_endpoint_type, :update_ip_addresses, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#resolver_endpoint_type ⇒ String
Specifies the endpoint type for what type of IP address the endpoint uses to forward DNS queries.
Updating to ‘IPV6` type isn’t currently supported.
5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5755 class UpdateResolverEndpointRequest < Struct.new( :resolver_endpoint_id, :name, :resolver_endpoint_type, :update_ip_addresses, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#rni_enhanced_metrics_enabled ⇒ Boolean
Updates whether RNI enhanced metrics are enabled for the Resolver endpoints. When set to true, one-minute granular metrics are published in CloudWatch for each RNI associated with this endpoint. When set to false, metrics are not published.
<note markdown=“1”> Standard CloudWatch pricing and charges are applied for using the Route 53 Resolver endpoint RNI enhanced metrics. For more information, see [Detailed metrics].
</note>
[1]: docs.aws.amazon.com/Route53/latest/DeveloperGuide/monitoring-resolver-with-cloudwatch.html
5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5755 class UpdateResolverEndpointRequest < Struct.new( :resolver_endpoint_id, :name, :resolver_endpoint_type, :update_ip_addresses, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#target_name_server_metrics_enabled ⇒ Boolean
Updates whether target name server metrics are enabled for the outbound Resolver endpoints. When set to true, one-minute granular metrics are published in CloudWatch for each target name server associated with this endpoint. When set to false, metrics are not published. This setting is not supported for inbound Resolver endpoints.
<note markdown=“1”> Standard CloudWatch pricing and charges are applied for using the Route 53 Resolver endpoint target name server metrics. For more information, see [Detailed metrics].
</note>
[1]: docs.aws.amazon.com/Route53/latest/DeveloperGuide/monitoring-resolver-with-cloudwatch.html
5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5755 class UpdateResolverEndpointRequest < Struct.new( :resolver_endpoint_id, :name, :resolver_endpoint_type, :update_ip_addresses, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#update_ip_addresses ⇒ Array<Types::UpdateIpAddress>
Specifies the IPv6 address when you update the Resolver endpoint from IPv4 to dual-stack. If you don’t specify an IPv6 address, one will be automatically chosen from your subnet.
5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5755 class UpdateResolverEndpointRequest < Struct.new( :resolver_endpoint_id, :name, :resolver_endpoint_type, :update_ip_addresses, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |