Class: Aws::Route53Resolver::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Route53Resolver::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-route53resolver/client.rb
Overview
An API client for Route53Resolver. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Route53Resolver::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_firewall_rule_group(params = {}) ⇒ Types::AssociateFirewallRuleGroupResponse
Associates a FirewallRuleGroup with a VPC, to provide DNS filtering for the VPC.
-
#associate_resolver_endpoint_ip_address(params = {}) ⇒ Types::AssociateResolverEndpointIpAddressResponse
Adds IP addresses to an inbound or an outbound Resolver endpoint.
-
#associate_resolver_query_log_config(params = {}) ⇒ Types::AssociateResolverQueryLogConfigResponse
Associates an Amazon VPC with a specified query logging configuration.
-
#associate_resolver_rule(params = {}) ⇒ Types::AssociateResolverRuleResponse
Associates a Resolver rule with a VPC.
-
#batch_create_firewall_rule(params = {}) ⇒ Types::BatchCreateFirewallRuleResponse
Creates multiple DNS Firewall rules in the specified rule group.
-
#batch_delete_firewall_rule(params = {}) ⇒ Types::BatchDeleteFirewallRuleResponse
Deletes multiple DNS Firewall rules from the specified rule group.
-
#batch_update_firewall_rule(params = {}) ⇒ Types::BatchUpdateFirewallRuleResponse
Updates multiple DNS Firewall rules in the specified rule group.
-
#create_firewall_domain_list(params = {}) ⇒ Types::CreateFirewallDomainListResponse
Creates an empty firewall domain list for use in DNS Firewall rules.
-
#create_firewall_rule(params = {}) ⇒ Types::CreateFirewallRuleResponse
Creates a single DNS Firewall rule in the specified rule group.
-
#create_firewall_rule_group(params = {}) ⇒ Types::CreateFirewallRuleGroupResponse
Creates an empty DNS Firewall rule group for filtering DNS network traffic in a VPC.
-
#create_outpost_resolver(params = {}) ⇒ Types::CreateOutpostResolverResponse
Creates a Route 53 Resolver on an Outpost.
-
#create_resolver_endpoint(params = {}) ⇒ Types::CreateResolverEndpointResponse
Creates a Resolver endpoint.
-
#create_resolver_query_log_config(params = {}) ⇒ Types::CreateResolverQueryLogConfigResponse
Creates a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs.
-
#create_resolver_rule(params = {}) ⇒ Types::CreateResolverRuleResponse
For DNS queries that originate in your VPCs, specifies which Resolver endpoint the queries pass through, one domain name that you want to forward to your network, and the IP addresses of the DNS resolvers in your network.
-
#delete_firewall_domain_list(params = {}) ⇒ Types::DeleteFirewallDomainListResponse
Deletes the specified domain list.
-
#delete_firewall_rule(params = {}) ⇒ Types::DeleteFirewallRuleResponse
Deletes the specified firewall rule.
-
#delete_firewall_rule_group(params = {}) ⇒ Types::DeleteFirewallRuleGroupResponse
Deletes the specified firewall rule group.
-
#delete_outpost_resolver(params = {}) ⇒ Types::DeleteOutpostResolverResponse
Deletes a Resolver on the Outpost.
-
#delete_resolver_endpoint(params = {}) ⇒ Types::DeleteResolverEndpointResponse
Deletes a Resolver endpoint.
-
#delete_resolver_query_log_config(params = {}) ⇒ Types::DeleteResolverQueryLogConfigResponse
Deletes a query logging configuration.
-
#delete_resolver_rule(params = {}) ⇒ Types::DeleteResolverRuleResponse
Deletes a Resolver rule.
-
#disassociate_firewall_rule_group(params = {}) ⇒ Types::DisassociateFirewallRuleGroupResponse
Disassociates a FirewallRuleGroup from a VPC, to remove DNS filtering from the VPC.
-
#disassociate_resolver_endpoint_ip_address(params = {}) ⇒ Types::DisassociateResolverEndpointIpAddressResponse
Removes IP addresses from an inbound or an outbound Resolver endpoint.
-
#disassociate_resolver_query_log_config(params = {}) ⇒ Types::DisassociateResolverQueryLogConfigResponse
Disassociates a VPC from a query logging configuration.
-
#disassociate_resolver_rule(params = {}) ⇒ Types::DisassociateResolverRuleResponse
Removes the association between a specified Resolver rule and a specified VPC.
-
#get_firewall_config(params = {}) ⇒ Types::GetFirewallConfigResponse
Retrieves the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
-
#get_firewall_domain_list(params = {}) ⇒ Types::GetFirewallDomainListResponse
Retrieves the specified firewall domain list.
-
#get_firewall_rule_group(params = {}) ⇒ Types::GetFirewallRuleGroupResponse
Retrieves the specified firewall rule group.
-
#get_firewall_rule_group_association(params = {}) ⇒ Types::GetFirewallRuleGroupAssociationResponse
Retrieves a firewall rule group association, which enables DNS filtering for a VPC with one rule group.
-
#get_firewall_rule_group_policy(params = {}) ⇒ Types::GetFirewallRuleGroupPolicyResponse
Returns the Identity and Access Management (Amazon Web Services IAM) policy for sharing the specified rule group.
-
#get_outpost_resolver(params = {}) ⇒ Types::GetOutpostResolverResponse
Gets information about a specified Resolver on the Outpost, such as its instance count and type, name, and the current status of the Resolver.
-
#get_resolver_config(params = {}) ⇒ Types::GetResolverConfigResponse
Retrieves the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
-
#get_resolver_dnssec_config(params = {}) ⇒ Types::GetResolverDnssecConfigResponse
Gets DNSSEC validation information for a specified resource.
-
#get_resolver_endpoint(params = {}) ⇒ Types::GetResolverEndpointResponse
Gets information about a specified Resolver endpoint, such as whether it’s an inbound or an outbound Resolver endpoint, and the current status of the endpoint.
-
#get_resolver_query_log_config(params = {}) ⇒ Types::GetResolverQueryLogConfigResponse
Gets information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to.
-
#get_resolver_query_log_config_association(params = {}) ⇒ Types::GetResolverQueryLogConfigAssociationResponse
Gets information about a specified association between a Resolver query logging configuration and an Amazon VPC.
-
#get_resolver_query_log_config_policy(params = {}) ⇒ Types::GetResolverQueryLogConfigPolicyResponse
Gets information about a query logging policy.
-
#get_resolver_rule(params = {}) ⇒ Types::GetResolverRuleResponse
Gets information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the ID of the outbound Resolver endpoint that the rule is associated with.
-
#get_resolver_rule_association(params = {}) ⇒ Types::GetResolverRuleAssociationResponse
Gets information about an association between a specified Resolver rule and a VPC.
-
#get_resolver_rule_policy(params = {}) ⇒ Types::GetResolverRulePolicyResponse
Gets information about the Resolver rule policy for a specified rule.
-
#import_firewall_domains(params = {}) ⇒ Types::ImportFirewallDomainsResponse
Imports domain names from a file into a domain list, for use in a DNS firewall rule group.
-
#list_firewall_configs(params = {}) ⇒ Types::ListFirewallConfigsResponse
Retrieves the firewall configurations that you have defined.
-
#list_firewall_domain_lists(params = {}) ⇒ Types::ListFirewallDomainListsResponse
Retrieves the firewall domain lists that you have defined.
-
#list_firewall_domains(params = {}) ⇒ Types::ListFirewallDomainsResponse
Retrieves the domains that you have defined for the specified firewall domain list.
-
#list_firewall_rule_group_associations(params = {}) ⇒ Types::ListFirewallRuleGroupAssociationsResponse
Retrieves the firewall rule group associations that you have defined.
-
#list_firewall_rule_groups(params = {}) ⇒ Types::ListFirewallRuleGroupsResponse
Retrieves the minimal high-level information for the rule groups that you have defined.
-
#list_firewall_rule_types(params = {}) ⇒ Types::ListFirewallRuleTypesResponse
Retrieves the rule-type variants that can be used in the ‘FirewallRuleType` field of CreateFirewallRule and UpdateFirewallRule.
-
#list_firewall_rules(params = {}) ⇒ Types::ListFirewallRulesResponse
Retrieves the firewall rules that you have defined for the specified firewall rule group.
-
#list_outpost_resolvers(params = {}) ⇒ Types::ListOutpostResolversResponse
Lists all the Resolvers on Outposts that were created using the current Amazon Web Services account.
-
#list_resolver_configs(params = {}) ⇒ Types::ListResolverConfigsResponse
Retrieves the Resolver configurations that you have defined.
-
#list_resolver_dnssec_configs(params = {}) ⇒ Types::ListResolverDnssecConfigsResponse
Lists the configurations for DNSSEC validation that are associated with the current Amazon Web Services account.
-
#list_resolver_endpoint_ip_addresses(params = {}) ⇒ Types::ListResolverEndpointIpAddressesResponse
Gets the IP addresses for a specified Resolver endpoint.
-
#list_resolver_endpoints(params = {}) ⇒ Types::ListResolverEndpointsResponse
Lists all the Resolver endpoints that were created using the current Amazon Web Services account.
-
#list_resolver_query_log_config_associations(params = {}) ⇒ Types::ListResolverQueryLogConfigAssociationsResponse
Lists information about associations between Amazon VPCs and query logging configurations.
-
#list_resolver_query_log_configs(params = {}) ⇒ Types::ListResolverQueryLogConfigsResponse
Lists information about the specified query logging configurations.
-
#list_resolver_rule_associations(params = {}) ⇒ Types::ListResolverRuleAssociationsResponse
Lists the associations that were created between Resolver rules and VPCs using the current Amazon Web Services account.
-
#list_resolver_rules(params = {}) ⇒ Types::ListResolverRulesResponse
Lists the Resolver rules that were created using the current Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
-
#put_firewall_rule_group_policy(params = {}) ⇒ Types::PutFirewallRuleGroupPolicyResponse
Attaches an Identity and Access Management (Amazon Web Services IAM) policy for sharing the rule group.
-
#put_resolver_query_log_config_policy(params = {}) ⇒ Types::PutResolverQueryLogConfigPolicyResponse
Specifies an Amazon Web Services account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.
-
#put_resolver_rule_policy(params = {}) ⇒ Types::PutResolverRulePolicyResponse
Specifies an Amazon Web Services rule that you want to share with another account, the account that you want to share the rule with, and the operations that you want the account to be able to perform on the rule.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
-
#update_firewall_config(params = {}) ⇒ Types::UpdateFirewallConfigResponse
Updates the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
-
#update_firewall_domains(params = {}) ⇒ Types::UpdateFirewallDomainsResponse
Updates the firewall domain list from an array of domain specifications.
-
#update_firewall_rule(params = {}) ⇒ Types::UpdateFirewallRuleResponse
Updates the specified firewall rule.
-
#update_firewall_rule_group_association(params = {}) ⇒ Types::UpdateFirewallRuleGroupAssociationResponse
Changes the association of a FirewallRuleGroup with a VPC.
-
#update_outpost_resolver(params = {}) ⇒ Types::UpdateOutpostResolverResponse
You can use ‘UpdateOutpostResolver` to update the instance count, type, or name of a Resolver on an Outpost.
-
#update_resolver_config(params = {}) ⇒ Types::UpdateResolverConfigResponse
Updates the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
-
#update_resolver_dnssec_config(params = {}) ⇒ Types::UpdateResolverDnssecConfigResponse
Updates an existing DNSSEC validation configuration.
-
#update_resolver_endpoint(params = {}) ⇒ Types::UpdateResolverEndpointResponse
Updates the name, or endpoint type for an inbound or an outbound Resolver endpoint.
-
#update_resolver_rule(params = {}) ⇒ Types::UpdateResolverRuleResponse
Updates settings for a specified Resolver rule.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5634 5635 5636 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5634 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5637 5638 5639 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5637 def errors_module Errors end |
Instance Method Details
#associate_firewall_rule_group(params = {}) ⇒ Types::AssociateFirewallRuleGroupResponse
Associates a FirewallRuleGroup with a VPC, to provide DNS filtering for the VPC.
If the rule group contains any rule configured with the ‘PartnerThreatProtection` rule type, the calling account must hold an active AWS Marketplace subscription to the named partner. If the subscription is missing, the association request is rejected.
576 577 578 579 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 576 def associate_firewall_rule_group(params = {}, = {}) req = build_request(:associate_firewall_rule_group, params) req.send_request() end |
#associate_resolver_endpoint_ip_address(params = {}) ⇒ Types::AssociateResolverEndpointIpAddressResponse
Adds IP addresses to an inbound or an outbound Resolver endpoint. If you want to add more than one IP address, submit one ‘AssociateResolverEndpointIpAddress` request for each IP address.
To remove an IP address from an endpoint, see [DisassociateResolverEndpointIpAddress].
646 647 648 649 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 646 def associate_resolver_endpoint_ip_address(params = {}, = {}) req = build_request(:associate_resolver_endpoint_ip_address, params) req.send_request() end |
#associate_resolver_query_log_config(params = {}) ⇒ Types::AssociateResolverQueryLogConfigResponse
Associates an Amazon VPC with a specified query logging configuration. Route 53 Resolver logs DNS queries that originate in all of the Amazon VPCs that are associated with a specified query logging configuration. To associate more than one VPC with a configuration, submit one ‘AssociateResolverQueryLogConfig` request for each VPC.
<note markdown=“1”> The VPCs that you associate with a query logging configuration must be in the same Region as the configuration.
</note>
To remove a VPC from a query logging configuration, see [DisassociateResolverQueryLogConfig].
707 708 709 710 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 707 def associate_resolver_query_log_config(params = {}, = {}) req = build_request(:associate_resolver_query_log_config, params) req.send_request() end |
#associate_resolver_rule(params = {}) ⇒ Types::AssociateResolverRuleResponse
Associates a Resolver rule with a VPC. When you associate a rule with a VPC, Resolver forwards all DNS queries for the domain name that is specified in the rule and that originate in the VPC. The queries are forwarded to the IP addresses for the DNS resolvers that are specified in the rule. For more information about rules, see [CreateResolverRule].
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverRule.html
767 768 769 770 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 767 def associate_resolver_rule(params = {}, = {}) req = build_request(:associate_resolver_rule, params) req.send_request() end |
#batch_create_firewall_rule(params = {}) ⇒ Types::BatchCreateFirewallRuleResponse
Creates multiple DNS Firewall rules in the specified rule group.
874 875 876 877 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 874 def batch_create_firewall_rule(params = {}, = {}) req = build_request(:batch_create_firewall_rule, params) req.send_request() end |
#batch_delete_firewall_rule(params = {}) ⇒ Types::BatchDeleteFirewallRuleResponse
Deletes multiple DNS Firewall rules from the specified rule group.
941 942 943 944 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 941 def batch_delete_firewall_rule(params = {}, = {}) req = build_request(:batch_delete_firewall_rule, params) req.send_request() end |
#batch_update_firewall_rule(params = {}) ⇒ Types::BatchUpdateFirewallRuleResponse
Updates multiple DNS Firewall rules in the specified rule group.
1048 1049 1050 1051 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1048 def batch_update_firewall_rule(params = {}, = {}) req = build_request(:batch_update_firewall_rule, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5607 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Route53Resolver') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-route53resolver' context[:gem_version] = '1.101.0' Seahorse::Client::Request.new(handlers, context) end |
#create_firewall_domain_list(params = {}) ⇒ Types::CreateFirewallDomainListResponse
Creates an empty firewall domain list for use in DNS Firewall rules. You can populate the domains for the new list with a file, using ImportFirewallDomains, or with domain strings, using UpdateFirewallDomains.
1110 1111 1112 1113 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1110 def create_firewall_domain_list(params = {}, = {}) req = build_request(:create_firewall_domain_list, params) req.send_request() end |
#create_firewall_rule(params = {}) ⇒ Types::CreateFirewallRuleResponse
Creates a single DNS Firewall rule in the specified rule group. The rule can use any one of the following match sources, and the chosen source must be supplied through the matching request field — they are mutually exclusive:
-
‘FirewallDomainListId` — match a customer-managed or AWS-managed domain list.
-
‘DnsThreatProtection` — match a built-in DNS Firewall Advanced threat detector (`DGA`, `DNS_TUNNELING`, or `DICTIONARY_DGA`).
-
‘FirewallRuleType` — match one of the rule-type variants returned by ListFirewallRuleTypes: `FirewallAdvancedContentCategory`, `FirewallAdvancedThreatCategory`, `DnsThreatProtection`, or `PartnerThreatProtection`. The `PartnerThreatProtection` variant requires an active AWS Marketplace subscription to the named partner product.
For rules that require asynchronous provisioning (today, the ‘PartnerThreatProtection` rule type), the rule’s ‘Status` begins at `CREATING` and transitions to `COMPLETE` once the rule is provisioned and the marketplace entitlement is verified. If provisioning fails, `Status` becomes `CREATION_FAILED` and `StatusMessage` contains a human-readable reason; the rule is then immutable and must be removed with DeleteFirewallRule.
1396 1397 1398 1399 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1396 def create_firewall_rule(params = {}, = {}) req = build_request(:create_firewall_rule, params) req.send_request() end |
#create_firewall_rule_group(params = {}) ⇒ Types::CreateFirewallRuleGroupResponse
Creates an empty DNS Firewall rule group for filtering DNS network traffic in a VPC. You can add rules to the new rule group by calling CreateFirewallRule.
1455 1456 1457 1458 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1455 def create_firewall_rule_group(params = {}, = {}) req = build_request(:create_firewall_rule_group, params) req.send_request() end |
#create_outpost_resolver(params = {}) ⇒ Types::CreateOutpostResolverResponse
Creates a Route 53 Resolver on an Outpost.
1527 1528 1529 1530 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1527 def create_outpost_resolver(params = {}, = {}) req = build_request(:create_outpost_resolver, params) req.send_request() end |
#create_resolver_endpoint(params = {}) ⇒ Types::CreateResolverEndpointResponse
Creates a Resolver endpoint. There are two types of Resolver endpoints, inbound and outbound:
-
An *inbound Resolver endpoint* forwards DNS queries to the DNS service for a VPC from your network.
-
An *outbound Resolver endpoint* forwards DNS queries from the DNS service for a VPC to your network.
1764 1765 1766 1767 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1764 def create_resolver_endpoint(params = {}, = {}) req = build_request(:create_resolver_endpoint, params) req.send_request() end |
#create_resolver_query_log_config(params = {}) ⇒ Types::CreateResolverQueryLogConfigResponse
Creates a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs. Resolver can log queries only for VPCs that are in the same Region as the query logging configuration.
To specify which VPCs you want to log queries for, you use ‘AssociateResolverQueryLogConfig`. For more information, see [AssociateResolverQueryLogConfig].
You can optionally use Resource Access Manager (RAM) to share a query logging configuration with other Amazon Web Services accounts. The other accounts can then associate VPCs with the configuration. The query logs that Resolver creates for a configuration include all DNS queries that originate in all VPCs that are associated with the configuration.
1862 1863 1864 1865 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1862 def create_resolver_query_log_config(params = {}, = {}) req = build_request(:create_resolver_query_log_config, params) req.send_request() end |
#create_resolver_rule(params = {}) ⇒ Types::CreateResolverRuleResponse
For DNS queries that originate in your VPCs, specifies which Resolver endpoint the queries pass through, one domain name that you want to forward to your network, and the IP addresses of the DNS resolvers in your network.
1995 1996 1997 1998 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1995 def create_resolver_rule(params = {}, = {}) req = build_request(:create_resolver_rule, params) req.send_request() end |
#delete_firewall_domain_list(params = {}) ⇒ Types::DeleteFirewallDomainListResponse
Deletes the specified domain list.
2034 2035 2036 2037 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2034 def delete_firewall_domain_list(params = {}, = {}) req = build_request(:delete_firewall_domain_list, params) req.send_request() end |
#delete_firewall_rule(params = {}) ⇒ Types::DeleteFirewallRuleResponse
Deletes the specified firewall rule. Identify the rule using either ‘FirewallDomainListId` (for domain-list and DNS Firewall Advanced rules) or `FirewallThreatProtectionId` (for partner-managed and DNS Firewall Advanced rules) — together with `FirewallRuleGroupId`.
‘DeleteFirewallRule` is the only operation that succeeds against a rule whose `Status` is `CREATION_FAILED`.
2142 2143 2144 2145 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2142 def delete_firewall_rule(params = {}, = {}) req = build_request(:delete_firewall_rule, params) req.send_request() end |
#delete_firewall_rule_group(params = {}) ⇒ Types::DeleteFirewallRuleGroupResponse
Deletes the specified firewall rule group.
2181 2182 2183 2184 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2181 def delete_firewall_rule_group(params = {}, = {}) req = build_request(:delete_firewall_rule_group, params) req.send_request() end |
#delete_outpost_resolver(params = {}) ⇒ Types::DeleteOutpostResolverResponse
Deletes a Resolver on the Outpost.
2219 2220 2221 2222 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2219 def delete_outpost_resolver(params = {}, = {}) req = build_request(:delete_outpost_resolver, params) req.send_request() end |
#delete_resolver_endpoint(params = {}) ⇒ Types::DeleteResolverEndpointResponse
Deletes a Resolver endpoint. The effect of deleting a Resolver endpoint depends on whether it’s an inbound or an outbound Resolver endpoint:
-
Inbound: DNS queries from your network are no longer routed to the DNS service for the specified VPC.
-
Outbound: DNS queries from a VPC are no longer routed to your network.
2276 2277 2278 2279 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2276 def delete_resolver_endpoint(params = {}, = {}) req = build_request(:delete_resolver_endpoint, params) req.send_request() end |
#delete_resolver_query_log_config(params = {}) ⇒ Types::DeleteResolverQueryLogConfigResponse
Deletes a query logging configuration. When you delete a configuration, Resolver stops logging DNS queries for all of the Amazon VPCs that are associated with the configuration. This also applies if the query logging configuration is shared with other Amazon Web Services accounts, and the other accounts have associated VPCs with the shared configuration.
Before you can delete a query logging configuration, you must first disassociate all VPCs from the configuration. See [DisassociateResolverQueryLogConfig].
If you used Resource Access Manager (RAM) to share a query logging configuration with other accounts, you must stop sharing the configuration before you can delete a configuration. The accounts that you shared the configuration with can first disassociate VPCs that they associated with the configuration, but that’s not necessary. If you stop sharing the configuration, those VPCs are automatically disassociated from the configuration.
2334 2335 2336 2337 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2334 def delete_resolver_query_log_config(params = {}, = {}) req = build_request(:delete_resolver_query_log_config, params) req.send_request() end |
#delete_resolver_rule(params = {}) ⇒ Types::DeleteResolverRuleResponse
Deletes a Resolver rule. Before you can delete a Resolver rule, you must disassociate it from all the VPCs that you associated the Resolver rule with. For more information, see [DisassociateResolverRule].
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverRule.html
2388 2389 2390 2391 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2388 def delete_resolver_rule(params = {}, = {}) req = build_request(:delete_resolver_rule, params) req.send_request() end |
#disassociate_firewall_rule_group(params = {}) ⇒ Types::DisassociateFirewallRuleGroupResponse
Disassociates a FirewallRuleGroup from a VPC, to remove DNS filtering from the VPC.
2429 2430 2431 2432 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2429 def disassociate_firewall_rule_group(params = {}, = {}) req = build_request(:disassociate_firewall_rule_group, params) req.send_request() end |
#disassociate_resolver_endpoint_ip_address(params = {}) ⇒ Types::DisassociateResolverEndpointIpAddressResponse
Removes IP addresses from an inbound or an outbound Resolver endpoint. If you want to remove more than one IP address, submit one ‘DisassociateResolverEndpointIpAddress` request for each IP address.
To add an IP address to an endpoint, see [AssociateResolverEndpointIpAddress].
2497 2498 2499 2500 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2497 def disassociate_resolver_endpoint_ip_address(params = {}, = {}) req = build_request(:disassociate_resolver_endpoint_ip_address, params) req.send_request() end |
#disassociate_resolver_query_log_config(params = {}) ⇒ Types::DisassociateResolverQueryLogConfigResponse
Disassociates a VPC from a query logging configuration.
<note markdown=“1”> Before you can delete a query logging configuration, you must first disassociate all VPCs from the configuration. If you used Resource Access Manager (RAM) to share a query logging configuration with other accounts, VPCs can be disassociated from the configuration in the following ways:
* The accounts that you shared the configuration with can disassociate
VPCs from the configuration.
-
You can stop sharing the configuration.
</note>
2550 2551 2552 2553 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2550 def disassociate_resolver_query_log_config(params = {}, = {}) req = build_request(:disassociate_resolver_query_log_config, params) req.send_request() end |
#disassociate_resolver_rule(params = {}) ⇒ Types::DisassociateResolverRuleResponse
Removes the association between a specified Resolver rule and a specified VPC.
If you disassociate a Resolver rule from a VPC, Resolver stops forwarding DNS queries for the domain name that you specified in the Resolver rule.
2594 2595 2596 2597 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2594 def disassociate_resolver_rule(params = {}, = {}) req = build_request(:disassociate_resolver_rule, params) req.send_request() end |
#get_firewall_config(params = {}) ⇒ Types::GetFirewallConfigResponse
Retrieves the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
2627 2628 2629 2630 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2627 def get_firewall_config(params = {}, = {}) req = build_request(:get_firewall_config, params) req.send_request() end |
#get_firewall_domain_list(params = {}) ⇒ Types::GetFirewallDomainListResponse
Retrieves the specified firewall domain list.
2666 2667 2668 2669 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2666 def get_firewall_domain_list(params = {}, = {}) req = build_request(:get_firewall_domain_list, params) req.send_request() end |
#get_firewall_rule_group(params = {}) ⇒ Types::GetFirewallRuleGroupResponse
Retrieves the specified firewall rule group.
2704 2705 2706 2707 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2704 def get_firewall_rule_group(params = {}, = {}) req = build_request(:get_firewall_rule_group, params) req.send_request() end |
#get_firewall_rule_group_association(params = {}) ⇒ Types::GetFirewallRuleGroupAssociationResponse
Retrieves a firewall rule group association, which enables DNS filtering for a VPC with one rule group. A VPC can have more than one firewall rule group association, and a rule group can be associated with more than one VPC.
2747 2748 2749 2750 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2747 def get_firewall_rule_group_association(params = {}, = {}) req = build_request(:get_firewall_rule_group_association, params) req.send_request() end |
#get_firewall_rule_group_policy(params = {}) ⇒ Types::GetFirewallRuleGroupPolicyResponse
Returns the Identity and Access Management (Amazon Web Services IAM) policy for sharing the specified rule group. You can use the policy to share the rule group using Resource Access Manager (RAM).
2777 2778 2779 2780 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2777 def get_firewall_rule_group_policy(params = {}, = {}) req = build_request(:get_firewall_rule_group_policy, params) req.send_request() end |
#get_outpost_resolver(params = {}) ⇒ Types::GetOutpostResolverResponse
Gets information about a specified Resolver on the Outpost, such as its instance count and type, name, and the current status of the Resolver.
2817 2818 2819 2820 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2817 def get_outpost_resolver(params = {}, = {}) req = build_request(:get_outpost_resolver, params) req.send_request() end |
#get_resolver_config(params = {}) ⇒ Types::GetResolverConfigResponse
Retrieves the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
2849 2850 2851 2852 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2849 def get_resolver_config(params = {}, = {}) req = build_request(:get_resolver_config, params) req.send_request() end |
#get_resolver_dnssec_config(params = {}) ⇒ Types::GetResolverDnssecConfigResponse
Gets DNSSEC validation information for a specified resource.
2881 2882 2883 2884 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2881 def get_resolver_dnssec_config(params = {}, = {}) req = build_request(:get_resolver_dnssec_config, params) req.send_request() end |
#get_resolver_endpoint(params = {}) ⇒ Types::GetResolverEndpointResponse
Gets information about a specified Resolver endpoint, such as whether it’s an inbound or an outbound Resolver endpoint, and the current status of the endpoint.
2933 2934 2935 2936 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2933 def get_resolver_endpoint(params = {}, = {}) req = build_request(:get_resolver_endpoint, params) req.send_request() end |
#get_resolver_query_log_config(params = {}) ⇒ Types::GetResolverQueryLogConfigResponse
Gets information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to.
2973 2974 2975 2976 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2973 def get_resolver_query_log_config(params = {}, = {}) req = build_request(:get_resolver_query_log_config, params) req.send_request() end |
#get_resolver_query_log_config_association(params = {}) ⇒ Types::GetResolverQueryLogConfigAssociationResponse
Gets information about a specified association between a Resolver query logging configuration and an Amazon VPC. When you associate a VPC with a query logging configuration, Resolver logs DNS queries that originate in that VPC.
3011 3012 3013 3014 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3011 def get_resolver_query_log_config_association(params = {}, = {}) req = build_request(:get_resolver_query_log_config_association, params) req.send_request() end |
#get_resolver_query_log_config_policy(params = {}) ⇒ Types::GetResolverQueryLogConfigPolicyResponse
Gets information about a query logging policy. A query logging policy specifies the Resolver query logging operations and resources that you want to allow another Amazon Web Services account to be able to use.
3042 3043 3044 3045 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3042 def get_resolver_query_log_config_policy(params = {}, = {}) req = build_request(:get_resolver_query_log_config_policy, params) req.send_request() end |
#get_resolver_rule(params = {}) ⇒ Types::GetResolverRuleResponse
Gets information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the ID of the outbound Resolver endpoint that the rule is associated with.
3091 3092 3093 3094 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3091 def get_resolver_rule(params = {}, = {}) req = build_request(:get_resolver_rule, params) req.send_request() end |
#get_resolver_rule_association(params = {}) ⇒ Types::GetResolverRuleAssociationResponse
Gets information about an association between a specified Resolver rule and a VPC. You associate a Resolver rule and a VPC using [AssociateResolverRule].
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverRule.html
3131 3132 3133 3134 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3131 def get_resolver_rule_association(params = {}, = {}) req = build_request(:get_resolver_rule_association, params) req.send_request() end |
#get_resolver_rule_policy(params = {}) ⇒ Types::GetResolverRulePolicyResponse
Gets information about the Resolver rule policy for a specified rule. A Resolver rule policy includes the rule that you want to share with another account, the account that you want to share the rule with, and the Resolver operations that you want to allow the account to use.
3163 3164 3165 3166 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3163 def get_resolver_rule_policy(params = {}, = {}) req = build_request(:get_resolver_rule_policy, params) req.send_request() end |
#import_firewall_domains(params = {}) ⇒ Types::ImportFirewallDomainsResponse
Imports domain names from a file into a domain list, for use in a DNS firewall rule group.
Each domain specification in your domain list must satisfy the following requirements:
-
It can optionally start with ‘*` (asterisk).
-
With the exception of the optional starting asterisk, it must only contain the following characters: ‘A-Z`, `a-z`, `0-9`, `-` (hyphen).
-
It must be from 1-255 characters in length.
3225 3226 3227 3228 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3225 def import_firewall_domains(params = {}, = {}) req = build_request(:import_firewall_domains, params) req.send_request() end |
#list_firewall_configs(params = {}) ⇒ Types::ListFirewallConfigsResponse
Retrieves the firewall configurations that you have defined. DNS Firewall uses the configurations to manage firewall behavior for your VPCs.
A single call might return only a partial list of the configurations. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3282 3283 3284 3285 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3282 def list_firewall_configs(params = {}, = {}) req = build_request(:list_firewall_configs, params) req.send_request() end |
#list_firewall_domain_lists(params = {}) ⇒ Types::ListFirewallDomainListsResponse
Retrieves the firewall domain lists that you have defined. For each firewall domain list, you can retrieve the domains that are defined for a list by calling ListFirewallDomains.
A single call to this list operation might return only a partial list of the domain lists. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3342 3343 3344 3345 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3342 def list_firewall_domain_lists(params = {}, = {}) req = build_request(:list_firewall_domain_lists, params) req.send_request() end |
#list_firewall_domains(params = {}) ⇒ Types::ListFirewallDomainsResponse
Retrieves the domains that you have defined for the specified firewall domain list.
A single call might return only a partial list of the domains. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3399 3400 3401 3402 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3399 def list_firewall_domains(params = {}, = {}) req = build_request(:list_firewall_domains, params) req.send_request() end |
#list_firewall_rule_group_associations(params = {}) ⇒ Types::ListFirewallRuleGroupAssociationsResponse
Retrieves the firewall rule group associations that you have defined. Each association enables DNS filtering for a VPC with one rule group.
A single call might return only a partial list of the associations. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3489 3490 3491 3492 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3489 def list_firewall_rule_group_associations(params = {}, = {}) req = build_request(:list_firewall_rule_group_associations, params) req.send_request() end |
#list_firewall_rule_groups(params = {}) ⇒ Types::ListFirewallRuleGroupsResponse
Retrieves the minimal high-level information for the rule groups that you have defined.
A single call might return only a partial list of the rule groups. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3547 3548 3549 3550 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3547 def list_firewall_rule_groups(params = {}, = {}) req = build_request(:list_firewall_rule_groups, params) req.send_request() end |
#list_firewall_rule_types(params = {}) ⇒ Types::ListFirewallRuleTypesResponse
Retrieves the rule-type variants that can be used in the ‘FirewallRuleType` field of CreateFirewallRule and UpdateFirewallRule. Each returned FirewallRuleTypeDefinition identifies one variant + value combination — for example, `FirewallAdvancedContentCategory` + `VIOLENCE_AND_HATE_SPEECH`, or `PartnerThreatProtection` + a partner-managed feed.
The supported ‘RuleType` filter values are `FirewallAdvancedContentCategory`, `FirewallAdvancedThreatCategory`, `DnsThreatProtection`, and `PartnerThreatProtection`. When a returned definition’s variant requires an external subscription (currently only ‘PartnerThreatProtection`), the response also includes a SubscriptionInfo identifying the AWS Marketplace product that backs it; absence of `SubscriptionInfo` means the variant is fully managed by AWS and requires no separate subscription.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3619 3620 3621 3622 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3619 def list_firewall_rule_types(params = {}, = {}) req = build_request(:list_firewall_rule_types, params) req.send_request() end |
#list_firewall_rules(params = {}) ⇒ Types::ListFirewallRulesResponse
Retrieves the firewall rules that you have defined for the specified firewall rule group. DNS Firewall uses the rules in a rule group to filter DNS network traffic for a VPC.
A single call might return only a partial list of the rules. For information, see ‘MaxResults`.
For rules that require asynchronous provisioning, the response includes ‘Status` (see FirewallRuleStatus) and, on failure, `StatusMessage` with the reason.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3731 3732 3733 3734 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3731 def list_firewall_rules(params = {}, = {}) req = build_request(:list_firewall_rules, params) req.send_request() end |
#list_outpost_resolvers(params = {}) ⇒ Types::ListOutpostResolversResponse
Lists all the Resolvers on Outposts that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3786 3787 3788 3789 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3786 def list_outpost_resolvers(params = {}, = {}) req = build_request(:list_outpost_resolvers, params) req.send_request() end |
#list_resolver_configs(params = {}) ⇒ Types::ListResolverConfigsResponse
Retrieves the Resolver configurations that you have defined. Route 53 Resolver uses the configurations to manage DNS resolution behavior for your VPCs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3839 3840 3841 3842 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3839 def list_resolver_configs(params = {}, = {}) req = build_request(:list_resolver_configs, params) req.send_request() end |
#list_resolver_dnssec_configs(params = {}) ⇒ Types::ListResolverDnssecConfigsResponse
Lists the configurations for DNSSEC validation that are associated with the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3900 3901 3902 3903 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3900 def list_resolver_dnssec_configs(params = {}, = {}) req = build_request(:list_resolver_dnssec_configs, params) req.send_request() end |
#list_resolver_endpoint_ip_addresses(params = {}) ⇒ Types::ListResolverEndpointIpAddressesResponse
Gets the IP addresses for a specified Resolver endpoint.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3959 3960 3961 3962 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3959 def list_resolver_endpoint_ip_addresses(params = {}, = {}) req = build_request(:list_resolver_endpoint_ip_addresses, params) req.send_request() end |
#list_resolver_endpoints(params = {}) ⇒ Types::ListResolverEndpointsResponse
Lists all the Resolver endpoints that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4044 4045 4046 4047 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4044 def list_resolver_endpoints(params = {}, = {}) req = build_request(:list_resolver_endpoints, params) req.send_request() end |
#list_resolver_query_log_config_associations(params = {}) ⇒ Types::ListResolverQueryLogConfigAssociationsResponse
Lists information about associations between Amazon VPCs and query logging configurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4185 4186 4187 4188 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4185 def list_resolver_query_log_config_associations(params = {}, = {}) req = build_request(:list_resolver_query_log_config_associations, params) req.send_request() end |
#list_resolver_query_log_configs(params = {}) ⇒ Types::ListResolverQueryLogConfigsResponse
Lists information about the specified query logging configurations. Each configuration defines where you want Resolver to save DNS query logs and specifies the VPCs that you want to log queries for.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4330 4331 4332 4333 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4330 def list_resolver_query_log_configs(params = {}, = {}) req = build_request(:list_resolver_query_log_configs, params) req.send_request() end |
#list_resolver_rule_associations(params = {}) ⇒ Types::ListResolverRuleAssociationsResponse
Lists the associations that were created between Resolver rules and VPCs using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4399 4400 4401 4402 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4399 def list_resolver_rule_associations(params = {}, = {}) req = build_request(:list_resolver_rule_associations, params) req.send_request() end |
#list_resolver_rules(params = {}) ⇒ Types::ListResolverRulesResponse
Lists the Resolver rules that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4482 4483 4484 4485 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4482 def list_resolver_rules(params = {}, = {}) req = build_request(:list_resolver_rules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4532 4533 4534 4535 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4532 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_firewall_rule_group_policy(params = {}) ⇒ Types::PutFirewallRuleGroupPolicyResponse
Attaches an Identity and Access Management (Amazon Web Services IAM) policy for sharing the rule group. You can use the policy to share the rule group using Resource Access Manager (RAM).
4568 4569 4570 4571 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4568 def put_firewall_rule_group_policy(params = {}, = {}) req = build_request(:put_firewall_rule_group_policy, params) req.send_request() end |
#put_resolver_query_log_config_policy(params = {}) ⇒ Types::PutResolverQueryLogConfigPolicyResponse
Specifies an Amazon Web Services account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.
4618 4619 4620 4621 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4618 def put_resolver_query_log_config_policy(params = {}, = {}) req = build_request(:put_resolver_query_log_config_policy, params) req.send_request() end |
#put_resolver_rule_policy(params = {}) ⇒ Types::PutResolverRulePolicyResponse
Specifies an Amazon Web Services rule that you want to share with another account, the account that you want to share the rule with, and the operations that you want the account to be able to perform on the rule.
4672 4673 4674 4675 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4672 def put_resolver_rule_policy(params = {}, = {}) req = build_request(:put_resolver_rule_policy, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
4726 4727 4728 4729 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4726 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
4775 4776 4777 4778 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4775 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_firewall_config(params = {}) ⇒ Types::UpdateFirewallConfigResponse
Updates the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
4825 4826 4827 4828 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4825 def update_firewall_config(params = {}, = {}) req = build_request(:update_firewall_config, params) req.send_request() end |
#update_firewall_domains(params = {}) ⇒ Types::UpdateFirewallDomainsResponse
Updates the firewall domain list from an array of domain specifications.
4890 4891 4892 4893 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4890 def update_firewall_domains(params = {}, = {}) req = build_request(:update_firewall_domains, params) req.send_request() end |
#update_firewall_rule(params = {}) ⇒ Types::UpdateFirewallRuleResponse
Updates the specified firewall rule. The rule’s ‘FirewallRuleType`, `FirewallDomainListId`, and top-level `DnsThreatProtection` match source cannot be changed after creation. Rules whose `Status` is `CREATING` or `CREATION_FAILED` cannot be updated; remove a failed rule with DeleteFirewallRule.
5146 5147 5148 5149 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5146 def update_firewall_rule(params = {}, = {}) req = build_request(:update_firewall_rule, params) req.send_request() end |
#update_firewall_rule_group_association(params = {}) ⇒ Types::UpdateFirewallRuleGroupAssociationResponse
Changes the association of a FirewallRuleGroup with a VPC. The association enables DNS filtering for the VPC.
5210 5211 5212 5213 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5210 def update_firewall_rule_group_association(params = {}, = {}) req = build_request(:update_firewall_rule_group_association, params) req.send_request() end |
#update_outpost_resolver(params = {}) ⇒ Types::UpdateOutpostResolverResponse
You can use ‘UpdateOutpostResolver` to update the instance count, type, or name of a Resolver on an Outpost.
5261 5262 5263 5264 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5261 def update_outpost_resolver(params = {}, = {}) req = build_request(:update_outpost_resolver, params) req.send_request() end |
#update_resolver_config(params = {}) ⇒ Types::UpdateResolverConfigResponse
Updates the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
5318 5319 5320 5321 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5318 def update_resolver_config(params = {}, = {}) req = build_request(:update_resolver_config, params) req.send_request() end |
#update_resolver_dnssec_config(params = {}) ⇒ Types::UpdateResolverDnssecConfigResponse
Updates an existing DNSSEC validation configuration. If there is no existing DNSSEC validation configuration, one is created.
5357 5358 5359 5360 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5357 def update_resolver_dnssec_config(params = {}, = {}) req = build_request(:update_resolver_dnssec_config, params) req.send_request() end |
#update_resolver_endpoint(params = {}) ⇒ Types::UpdateResolverEndpointResponse
Updates the name, or endpoint type for an inbound or an outbound Resolver endpoint. You can only update between IPV4 and DUALSTACK, IPV6 endpoint type can’t be updated to other type.
5533 5534 5535 5536 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5533 def update_resolver_endpoint(params = {}, = {}) req = build_request(:update_resolver_endpoint, params) req.send_request() end |
#update_resolver_rule(params = {}) ⇒ Types::UpdateResolverRuleResponse
Updates settings for a specified Resolver rule. ‘ResolverRuleId` is required, and all other parameters are optional. If you don’t specify a parameter, it retains its current value.
5598 5599 5600 5601 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5598 def update_resolver_rule(params = {}, = {}) req = build_request(:update_resolver_rule, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5627 5628 5629 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5627 def waiter_names [] end |