Class: Aws::Route53Resolver::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Route53Resolver::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-route53resolver/client.rb
Overview
An API client for Route53Resolver. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Route53Resolver::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_firewall_rule_group(params = {}) ⇒ Types::AssociateFirewallRuleGroupResponse
Associates a FirewallRuleGroup with a VPC, to provide DNS filtering for the VPC.
-
#associate_resolver_endpoint_ip_address(params = {}) ⇒ Types::AssociateResolverEndpointIpAddressResponse
Adds IP addresses to an inbound or an outbound Resolver endpoint.
-
#associate_resolver_query_log_config(params = {}) ⇒ Types::AssociateResolverQueryLogConfigResponse
Associates an Amazon VPC with a specified query logging configuration.
-
#associate_resolver_rule(params = {}) ⇒ Types::AssociateResolverRuleResponse
Associates a Resolver rule with a VPC.
-
#batch_create_firewall_rule(params = {}) ⇒ Types::BatchCreateFirewallRuleResponse
Creates multiple DNS Firewall rules in the specified rule group.
-
#batch_delete_firewall_rule(params = {}) ⇒ Types::BatchDeleteFirewallRuleResponse
Deletes multiple DNS Firewall rules from the specified rule group.
-
#batch_update_firewall_rule(params = {}) ⇒ Types::BatchUpdateFirewallRuleResponse
Updates multiple DNS Firewall rules in the specified rule group.
-
#create_firewall_domain_list(params = {}) ⇒ Types::CreateFirewallDomainListResponse
Creates an empty firewall domain list for use in DNS Firewall rules.
-
#create_firewall_rule(params = {}) ⇒ Types::CreateFirewallRuleResponse
Creates a single DNS Firewall rule in the specified rule group, using the specified domain list.
-
#create_firewall_rule_group(params = {}) ⇒ Types::CreateFirewallRuleGroupResponse
Creates an empty DNS Firewall rule group for filtering DNS network traffic in a VPC.
-
#create_outpost_resolver(params = {}) ⇒ Types::CreateOutpostResolverResponse
Creates a Route 53 Resolver on an Outpost.
-
#create_resolver_endpoint(params = {}) ⇒ Types::CreateResolverEndpointResponse
Creates a Resolver endpoint.
-
#create_resolver_query_log_config(params = {}) ⇒ Types::CreateResolverQueryLogConfigResponse
Creates a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs.
-
#create_resolver_rule(params = {}) ⇒ Types::CreateResolverRuleResponse
For DNS queries that originate in your VPCs, specifies which Resolver endpoint the queries pass through, one domain name that you want to forward to your network, and the IP addresses of the DNS resolvers in your network.
-
#delete_firewall_domain_list(params = {}) ⇒ Types::DeleteFirewallDomainListResponse
Deletes the specified domain list.
-
#delete_firewall_rule(params = {}) ⇒ Types::DeleteFirewallRuleResponse
Deletes the specified firewall rule.
-
#delete_firewall_rule_group(params = {}) ⇒ Types::DeleteFirewallRuleGroupResponse
Deletes the specified firewall rule group.
-
#delete_outpost_resolver(params = {}) ⇒ Types::DeleteOutpostResolverResponse
Deletes a Resolver on the Outpost.
-
#delete_resolver_endpoint(params = {}) ⇒ Types::DeleteResolverEndpointResponse
Deletes a Resolver endpoint.
-
#delete_resolver_query_log_config(params = {}) ⇒ Types::DeleteResolverQueryLogConfigResponse
Deletes a query logging configuration.
-
#delete_resolver_rule(params = {}) ⇒ Types::DeleteResolverRuleResponse
Deletes a Resolver rule.
-
#disassociate_firewall_rule_group(params = {}) ⇒ Types::DisassociateFirewallRuleGroupResponse
Disassociates a FirewallRuleGroup from a VPC, to remove DNS filtering from the VPC.
-
#disassociate_resolver_endpoint_ip_address(params = {}) ⇒ Types::DisassociateResolverEndpointIpAddressResponse
Removes IP addresses from an inbound or an outbound Resolver endpoint.
-
#disassociate_resolver_query_log_config(params = {}) ⇒ Types::DisassociateResolverQueryLogConfigResponse
Disassociates a VPC from a query logging configuration.
-
#disassociate_resolver_rule(params = {}) ⇒ Types::DisassociateResolverRuleResponse
Removes the association between a specified Resolver rule and a specified VPC.
-
#get_firewall_config(params = {}) ⇒ Types::GetFirewallConfigResponse
Retrieves the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
-
#get_firewall_domain_list(params = {}) ⇒ Types::GetFirewallDomainListResponse
Retrieves the specified firewall domain list.
-
#get_firewall_rule_group(params = {}) ⇒ Types::GetFirewallRuleGroupResponse
Retrieves the specified firewall rule group.
-
#get_firewall_rule_group_association(params = {}) ⇒ Types::GetFirewallRuleGroupAssociationResponse
Retrieves a firewall rule group association, which enables DNS filtering for a VPC with one rule group.
-
#get_firewall_rule_group_policy(params = {}) ⇒ Types::GetFirewallRuleGroupPolicyResponse
Returns the Identity and Access Management (Amazon Web Services IAM) policy for sharing the specified rule group.
-
#get_outpost_resolver(params = {}) ⇒ Types::GetOutpostResolverResponse
Gets information about a specified Resolver on the Outpost, such as its instance count and type, name, and the current status of the Resolver.
-
#get_resolver_config(params = {}) ⇒ Types::GetResolverConfigResponse
Retrieves the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
-
#get_resolver_dnssec_config(params = {}) ⇒ Types::GetResolverDnssecConfigResponse
Gets DNSSEC validation information for a specified resource.
-
#get_resolver_endpoint(params = {}) ⇒ Types::GetResolverEndpointResponse
Gets information about a specified Resolver endpoint, such as whether it’s an inbound or an outbound Resolver endpoint, and the current status of the endpoint.
-
#get_resolver_query_log_config(params = {}) ⇒ Types::GetResolverQueryLogConfigResponse
Gets information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to.
-
#get_resolver_query_log_config_association(params = {}) ⇒ Types::GetResolverQueryLogConfigAssociationResponse
Gets information about a specified association between a Resolver query logging configuration and an Amazon VPC.
-
#get_resolver_query_log_config_policy(params = {}) ⇒ Types::GetResolverQueryLogConfigPolicyResponse
Gets information about a query logging policy.
-
#get_resolver_rule(params = {}) ⇒ Types::GetResolverRuleResponse
Gets information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the ID of the outbound Resolver endpoint that the rule is associated with.
-
#get_resolver_rule_association(params = {}) ⇒ Types::GetResolverRuleAssociationResponse
Gets information about an association between a specified Resolver rule and a VPC.
-
#get_resolver_rule_policy(params = {}) ⇒ Types::GetResolverRulePolicyResponse
Gets information about the Resolver rule policy for a specified rule.
-
#import_firewall_domains(params = {}) ⇒ Types::ImportFirewallDomainsResponse
Imports domain names from a file into a domain list, for use in a DNS firewall rule group.
-
#list_firewall_configs(params = {}) ⇒ Types::ListFirewallConfigsResponse
Retrieves the firewall configurations that you have defined.
-
#list_firewall_domain_lists(params = {}) ⇒ Types::ListFirewallDomainListsResponse
Retrieves the firewall domain lists that you have defined.
-
#list_firewall_domains(params = {}) ⇒ Types::ListFirewallDomainsResponse
Retrieves the domains that you have defined for the specified firewall domain list.
-
#list_firewall_rule_group_associations(params = {}) ⇒ Types::ListFirewallRuleGroupAssociationsResponse
Retrieves the firewall rule group associations that you have defined.
-
#list_firewall_rule_groups(params = {}) ⇒ Types::ListFirewallRuleGroupsResponse
Retrieves the minimal high-level information for the rule groups that you have defined.
-
#list_firewall_rule_types(params = {}) ⇒ Types::ListFirewallRuleTypesResponse
Retrieves the available rule types that can be used in DNS Firewall rules.
-
#list_firewall_rules(params = {}) ⇒ Types::ListFirewallRulesResponse
Retrieves the firewall rules that you have defined for the specified firewall rule group.
-
#list_outpost_resolvers(params = {}) ⇒ Types::ListOutpostResolversResponse
Lists all the Resolvers on Outposts that were created using the current Amazon Web Services account.
-
#list_resolver_configs(params = {}) ⇒ Types::ListResolverConfigsResponse
Retrieves the Resolver configurations that you have defined.
-
#list_resolver_dnssec_configs(params = {}) ⇒ Types::ListResolverDnssecConfigsResponse
Lists the configurations for DNSSEC validation that are associated with the current Amazon Web Services account.
-
#list_resolver_endpoint_ip_addresses(params = {}) ⇒ Types::ListResolverEndpointIpAddressesResponse
Gets the IP addresses for a specified Resolver endpoint.
-
#list_resolver_endpoints(params = {}) ⇒ Types::ListResolverEndpointsResponse
Lists all the Resolver endpoints that were created using the current Amazon Web Services account.
-
#list_resolver_query_log_config_associations(params = {}) ⇒ Types::ListResolverQueryLogConfigAssociationsResponse
Lists information about associations between Amazon VPCs and query logging configurations.
-
#list_resolver_query_log_configs(params = {}) ⇒ Types::ListResolverQueryLogConfigsResponse
Lists information about the specified query logging configurations.
-
#list_resolver_rule_associations(params = {}) ⇒ Types::ListResolverRuleAssociationsResponse
Lists the associations that were created between Resolver rules and VPCs using the current Amazon Web Services account.
-
#list_resolver_rules(params = {}) ⇒ Types::ListResolverRulesResponse
Lists the Resolver rules that were created using the current Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
-
#put_firewall_rule_group_policy(params = {}) ⇒ Types::PutFirewallRuleGroupPolicyResponse
Attaches an Identity and Access Management (Amazon Web Services IAM) policy for sharing the rule group.
-
#put_resolver_query_log_config_policy(params = {}) ⇒ Types::PutResolverQueryLogConfigPolicyResponse
Specifies an Amazon Web Services account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.
-
#put_resolver_rule_policy(params = {}) ⇒ Types::PutResolverRulePolicyResponse
Specifies an Amazon Web Services rule that you want to share with another account, the account that you want to share the rule with, and the operations that you want the account to be able to perform on the rule.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
-
#update_firewall_config(params = {}) ⇒ Types::UpdateFirewallConfigResponse
Updates the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
-
#update_firewall_domains(params = {}) ⇒ Types::UpdateFirewallDomainsResponse
Updates the firewall domain list from an array of domain specifications.
-
#update_firewall_rule(params = {}) ⇒ Types::UpdateFirewallRuleResponse
Updates the specified firewall rule.
-
#update_firewall_rule_group_association(params = {}) ⇒ Types::UpdateFirewallRuleGroupAssociationResponse
Changes the association of a FirewallRuleGroup with a VPC.
-
#update_outpost_resolver(params = {}) ⇒ Types::UpdateOutpostResolverResponse
You can use ‘UpdateOutpostResolver` to update the instance count, type, or name of a Resolver on an Outpost.
-
#update_resolver_config(params = {}) ⇒ Types::UpdateResolverConfigResponse
Updates the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
-
#update_resolver_dnssec_config(params = {}) ⇒ Types::UpdateResolverDnssecConfigResponse
Updates an existing DNSSEC validation configuration.
-
#update_resolver_endpoint(params = {}) ⇒ Types::UpdateResolverEndpointResponse
Updates the name, or endpoint type for an inbound or an outbound Resolver endpoint.
-
#update_resolver_rule(params = {}) ⇒ Types::UpdateResolverRuleResponse
Updates settings for a specified Resolver rule.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5483 5484 5485 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5483 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5486 5487 5488 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5486 def errors_module Errors end |
Instance Method Details
#associate_firewall_rule_group(params = {}) ⇒ Types::AssociateFirewallRuleGroupResponse
Associates a FirewallRuleGroup with a VPC, to provide DNS filtering for the VPC.
571 572 573 574 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 571 def associate_firewall_rule_group(params = {}, = {}) req = build_request(:associate_firewall_rule_group, params) req.send_request() end |
#associate_resolver_endpoint_ip_address(params = {}) ⇒ Types::AssociateResolverEndpointIpAddressResponse
Adds IP addresses to an inbound or an outbound Resolver endpoint. If you want to add more than one IP address, submit one ‘AssociateResolverEndpointIpAddress` request for each IP address.
To remove an IP address from an endpoint, see [DisassociateResolverEndpointIpAddress].
641 642 643 644 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 641 def associate_resolver_endpoint_ip_address(params = {}, = {}) req = build_request(:associate_resolver_endpoint_ip_address, params) req.send_request() end |
#associate_resolver_query_log_config(params = {}) ⇒ Types::AssociateResolverQueryLogConfigResponse
Associates an Amazon VPC with a specified query logging configuration. Route 53 Resolver logs DNS queries that originate in all of the Amazon VPCs that are associated with a specified query logging configuration. To associate more than one VPC with a configuration, submit one ‘AssociateResolverQueryLogConfig` request for each VPC.
<note markdown=“1”> The VPCs that you associate with a query logging configuration must be in the same Region as the configuration.
</note>
To remove a VPC from a query logging configuration, see [DisassociateResolverQueryLogConfig].
702 703 704 705 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 702 def associate_resolver_query_log_config(params = {}, = {}) req = build_request(:associate_resolver_query_log_config, params) req.send_request() end |
#associate_resolver_rule(params = {}) ⇒ Types::AssociateResolverRuleResponse
Associates a Resolver rule with a VPC. When you associate a rule with a VPC, Resolver forwards all DNS queries for the domain name that is specified in the rule and that originate in the VPC. The queries are forwarded to the IP addresses for the DNS resolvers that are specified in the rule. For more information about rules, see [CreateResolverRule].
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverRule.html
762 763 764 765 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 762 def associate_resolver_rule(params = {}, = {}) req = build_request(:associate_resolver_rule, params) req.send_request() end |
#batch_create_firewall_rule(params = {}) ⇒ Types::BatchCreateFirewallRuleResponse
Creates multiple DNS Firewall rules in the specified rule group.
862 863 864 865 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 862 def batch_create_firewall_rule(params = {}, = {}) req = build_request(:batch_create_firewall_rule, params) req.send_request() end |
#batch_delete_firewall_rule(params = {}) ⇒ Types::BatchDeleteFirewallRuleResponse
Deletes multiple DNS Firewall rules from the specified rule group.
926 927 928 929 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 926 def batch_delete_firewall_rule(params = {}, = {}) req = build_request(:batch_delete_firewall_rule, params) req.send_request() end |
#batch_update_firewall_rule(params = {}) ⇒ Types::BatchUpdateFirewallRuleResponse
Updates multiple DNS Firewall rules in the specified rule group.
1026 1027 1028 1029 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1026 def batch_update_firewall_rule(params = {}, = {}) req = build_request(:batch_update_firewall_rule, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5456 5457 5458 5459 5460 5461 5462 5463 5464 5465 5466 5467 5468 5469 5470 5471 5472 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5456 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Route53Resolver') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-route53resolver' context[:gem_version] = '1.100.0' Seahorse::Client::Request.new(handlers, context) end |
#create_firewall_domain_list(params = {}) ⇒ Types::CreateFirewallDomainListResponse
Creates an empty firewall domain list for use in DNS Firewall rules. You can populate the domains for the new list with a file, using ImportFirewallDomains, or with domain strings, using UpdateFirewallDomains.
1088 1089 1090 1091 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1088 def create_firewall_domain_list(params = {}, = {}) req = build_request(:create_firewall_domain_list, params) req.send_request() end |
#create_firewall_rule(params = {}) ⇒ Types::CreateFirewallRuleResponse
Creates a single DNS Firewall rule in the specified rule group, using the specified domain list.
1313 1314 1315 1316 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1313 def create_firewall_rule(params = {}, = {}) req = build_request(:create_firewall_rule, params) req.send_request() end |
#create_firewall_rule_group(params = {}) ⇒ Types::CreateFirewallRuleGroupResponse
Creates an empty DNS Firewall rule group for filtering DNS network traffic in a VPC. You can add rules to the new rule group by calling CreateFirewallRule.
1372 1373 1374 1375 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1372 def create_firewall_rule_group(params = {}, = {}) req = build_request(:create_firewall_rule_group, params) req.send_request() end |
#create_outpost_resolver(params = {}) ⇒ Types::CreateOutpostResolverResponse
Creates a Route 53 Resolver on an Outpost.
1444 1445 1446 1447 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1444 def create_outpost_resolver(params = {}, = {}) req = build_request(:create_outpost_resolver, params) req.send_request() end |
#create_resolver_endpoint(params = {}) ⇒ Types::CreateResolverEndpointResponse
Creates a Resolver endpoint. There are two types of Resolver endpoints, inbound and outbound:
-
An *inbound Resolver endpoint* forwards DNS queries to the DNS service for a VPC from your network.
-
An *outbound Resolver endpoint* forwards DNS queries from the DNS service for a VPC to your network.
1681 1682 1683 1684 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1681 def create_resolver_endpoint(params = {}, = {}) req = build_request(:create_resolver_endpoint, params) req.send_request() end |
#create_resolver_query_log_config(params = {}) ⇒ Types::CreateResolverQueryLogConfigResponse
Creates a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs. Resolver can log queries only for VPCs that are in the same Region as the query logging configuration.
To specify which VPCs you want to log queries for, you use ‘AssociateResolverQueryLogConfig`. For more information, see [AssociateResolverQueryLogConfig].
You can optionally use Resource Access Manager (RAM) to share a query logging configuration with other Amazon Web Services accounts. The other accounts can then associate VPCs with the configuration. The query logs that Resolver creates for a configuration include all DNS queries that originate in all VPCs that are associated with the configuration.
1779 1780 1781 1782 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1779 def create_resolver_query_log_config(params = {}, = {}) req = build_request(:create_resolver_query_log_config, params) req.send_request() end |
#create_resolver_rule(params = {}) ⇒ Types::CreateResolverRuleResponse
For DNS queries that originate in your VPCs, specifies which Resolver endpoint the queries pass through, one domain name that you want to forward to your network, and the IP addresses of the DNS resolvers in your network.
1912 1913 1914 1915 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1912 def create_resolver_rule(params = {}, = {}) req = build_request(:create_resolver_rule, params) req.send_request() end |
#delete_firewall_domain_list(params = {}) ⇒ Types::DeleteFirewallDomainListResponse
Deletes the specified domain list.
1951 1952 1953 1954 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1951 def delete_firewall_domain_list(params = {}, = {}) req = build_request(:delete_firewall_domain_list, params) req.send_request() end |
#delete_firewall_rule(params = {}) ⇒ Types::DeleteFirewallRuleResponse
Deletes the specified firewall rule.
2050 2051 2052 2053 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2050 def delete_firewall_rule(params = {}, = {}) req = build_request(:delete_firewall_rule, params) req.send_request() end |
#delete_firewall_rule_group(params = {}) ⇒ Types::DeleteFirewallRuleGroupResponse
Deletes the specified firewall rule group.
2089 2090 2091 2092 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2089 def delete_firewall_rule_group(params = {}, = {}) req = build_request(:delete_firewall_rule_group, params) req.send_request() end |
#delete_outpost_resolver(params = {}) ⇒ Types::DeleteOutpostResolverResponse
Deletes a Resolver on the Outpost.
2127 2128 2129 2130 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2127 def delete_outpost_resolver(params = {}, = {}) req = build_request(:delete_outpost_resolver, params) req.send_request() end |
#delete_resolver_endpoint(params = {}) ⇒ Types::DeleteResolverEndpointResponse
Deletes a Resolver endpoint. The effect of deleting a Resolver endpoint depends on whether it’s an inbound or an outbound Resolver endpoint:
-
Inbound: DNS queries from your network are no longer routed to the DNS service for the specified VPC.
-
Outbound: DNS queries from a VPC are no longer routed to your network.
2184 2185 2186 2187 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2184 def delete_resolver_endpoint(params = {}, = {}) req = build_request(:delete_resolver_endpoint, params) req.send_request() end |
#delete_resolver_query_log_config(params = {}) ⇒ Types::DeleteResolverQueryLogConfigResponse
Deletes a query logging configuration. When you delete a configuration, Resolver stops logging DNS queries for all of the Amazon VPCs that are associated with the configuration. This also applies if the query logging configuration is shared with other Amazon Web Services accounts, and the other accounts have associated VPCs with the shared configuration.
Before you can delete a query logging configuration, you must first disassociate all VPCs from the configuration. See [DisassociateResolverQueryLogConfig].
If you used Resource Access Manager (RAM) to share a query logging configuration with other accounts, you must stop sharing the configuration before you can delete a configuration. The accounts that you shared the configuration with can first disassociate VPCs that they associated with the configuration, but that’s not necessary. If you stop sharing the configuration, those VPCs are automatically disassociated from the configuration.
2242 2243 2244 2245 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2242 def delete_resolver_query_log_config(params = {}, = {}) req = build_request(:delete_resolver_query_log_config, params) req.send_request() end |
#delete_resolver_rule(params = {}) ⇒ Types::DeleteResolverRuleResponse
Deletes a Resolver rule. Before you can delete a Resolver rule, you must disassociate it from all the VPCs that you associated the Resolver rule with. For more information, see [DisassociateResolverRule].
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverRule.html
2296 2297 2298 2299 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2296 def delete_resolver_rule(params = {}, = {}) req = build_request(:delete_resolver_rule, params) req.send_request() end |
#disassociate_firewall_rule_group(params = {}) ⇒ Types::DisassociateFirewallRuleGroupResponse
Disassociates a FirewallRuleGroup from a VPC, to remove DNS filtering from the VPC.
2337 2338 2339 2340 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2337 def disassociate_firewall_rule_group(params = {}, = {}) req = build_request(:disassociate_firewall_rule_group, params) req.send_request() end |
#disassociate_resolver_endpoint_ip_address(params = {}) ⇒ Types::DisassociateResolverEndpointIpAddressResponse
Removes IP addresses from an inbound or an outbound Resolver endpoint. If you want to remove more than one IP address, submit one ‘DisassociateResolverEndpointIpAddress` request for each IP address.
To add an IP address to an endpoint, see [AssociateResolverEndpointIpAddress].
2405 2406 2407 2408 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2405 def disassociate_resolver_endpoint_ip_address(params = {}, = {}) req = build_request(:disassociate_resolver_endpoint_ip_address, params) req.send_request() end |
#disassociate_resolver_query_log_config(params = {}) ⇒ Types::DisassociateResolverQueryLogConfigResponse
Disassociates a VPC from a query logging configuration.
<note markdown=“1”> Before you can delete a query logging configuration, you must first disassociate all VPCs from the configuration. If you used Resource Access Manager (RAM) to share a query logging configuration with other accounts, VPCs can be disassociated from the configuration in the following ways:
* The accounts that you shared the configuration with can disassociate
VPCs from the configuration.
-
You can stop sharing the configuration.
</note>
2458 2459 2460 2461 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2458 def disassociate_resolver_query_log_config(params = {}, = {}) req = build_request(:disassociate_resolver_query_log_config, params) req.send_request() end |
#disassociate_resolver_rule(params = {}) ⇒ Types::DisassociateResolverRuleResponse
Removes the association between a specified Resolver rule and a specified VPC.
If you disassociate a Resolver rule from a VPC, Resolver stops forwarding DNS queries for the domain name that you specified in the Resolver rule.
2502 2503 2504 2505 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2502 def disassociate_resolver_rule(params = {}, = {}) req = build_request(:disassociate_resolver_rule, params) req.send_request() end |
#get_firewall_config(params = {}) ⇒ Types::GetFirewallConfigResponse
Retrieves the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
2535 2536 2537 2538 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2535 def get_firewall_config(params = {}, = {}) req = build_request(:get_firewall_config, params) req.send_request() end |
#get_firewall_domain_list(params = {}) ⇒ Types::GetFirewallDomainListResponse
Retrieves the specified firewall domain list.
2574 2575 2576 2577 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2574 def get_firewall_domain_list(params = {}, = {}) req = build_request(:get_firewall_domain_list, params) req.send_request() end |
#get_firewall_rule_group(params = {}) ⇒ Types::GetFirewallRuleGroupResponse
Retrieves the specified firewall rule group.
2612 2613 2614 2615 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2612 def get_firewall_rule_group(params = {}, = {}) req = build_request(:get_firewall_rule_group, params) req.send_request() end |
#get_firewall_rule_group_association(params = {}) ⇒ Types::GetFirewallRuleGroupAssociationResponse
Retrieves a firewall rule group association, which enables DNS filtering for a VPC with one rule group. A VPC can have more than one firewall rule group association, and a rule group can be associated with more than one VPC.
2655 2656 2657 2658 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2655 def get_firewall_rule_group_association(params = {}, = {}) req = build_request(:get_firewall_rule_group_association, params) req.send_request() end |
#get_firewall_rule_group_policy(params = {}) ⇒ Types::GetFirewallRuleGroupPolicyResponse
Returns the Identity and Access Management (Amazon Web Services IAM) policy for sharing the specified rule group. You can use the policy to share the rule group using Resource Access Manager (RAM).
2685 2686 2687 2688 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2685 def get_firewall_rule_group_policy(params = {}, = {}) req = build_request(:get_firewall_rule_group_policy, params) req.send_request() end |
#get_outpost_resolver(params = {}) ⇒ Types::GetOutpostResolverResponse
Gets information about a specified Resolver on the Outpost, such as its instance count and type, name, and the current status of the Resolver.
2725 2726 2727 2728 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2725 def get_outpost_resolver(params = {}, = {}) req = build_request(:get_outpost_resolver, params) req.send_request() end |
#get_resolver_config(params = {}) ⇒ Types::GetResolverConfigResponse
Retrieves the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
2757 2758 2759 2760 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2757 def get_resolver_config(params = {}, = {}) req = build_request(:get_resolver_config, params) req.send_request() end |
#get_resolver_dnssec_config(params = {}) ⇒ Types::GetResolverDnssecConfigResponse
Gets DNSSEC validation information for a specified resource.
2789 2790 2791 2792 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2789 def get_resolver_dnssec_config(params = {}, = {}) req = build_request(:get_resolver_dnssec_config, params) req.send_request() end |
#get_resolver_endpoint(params = {}) ⇒ Types::GetResolverEndpointResponse
Gets information about a specified Resolver endpoint, such as whether it’s an inbound or an outbound Resolver endpoint, and the current status of the endpoint.
2841 2842 2843 2844 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2841 def get_resolver_endpoint(params = {}, = {}) req = build_request(:get_resolver_endpoint, params) req.send_request() end |
#get_resolver_query_log_config(params = {}) ⇒ Types::GetResolverQueryLogConfigResponse
Gets information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to.
2881 2882 2883 2884 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2881 def get_resolver_query_log_config(params = {}, = {}) req = build_request(:get_resolver_query_log_config, params) req.send_request() end |
#get_resolver_query_log_config_association(params = {}) ⇒ Types::GetResolverQueryLogConfigAssociationResponse
Gets information about a specified association between a Resolver query logging configuration and an Amazon VPC. When you associate a VPC with a query logging configuration, Resolver logs DNS queries that originate in that VPC.
2919 2920 2921 2922 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2919 def get_resolver_query_log_config_association(params = {}, = {}) req = build_request(:get_resolver_query_log_config_association, params) req.send_request() end |
#get_resolver_query_log_config_policy(params = {}) ⇒ Types::GetResolverQueryLogConfigPolicyResponse
Gets information about a query logging policy. A query logging policy specifies the Resolver query logging operations and resources that you want to allow another Amazon Web Services account to be able to use.
2950 2951 2952 2953 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2950 def get_resolver_query_log_config_policy(params = {}, = {}) req = build_request(:get_resolver_query_log_config_policy, params) req.send_request() end |
#get_resolver_rule(params = {}) ⇒ Types::GetResolverRuleResponse
Gets information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the ID of the outbound Resolver endpoint that the rule is associated with.
2999 3000 3001 3002 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2999 def get_resolver_rule(params = {}, = {}) req = build_request(:get_resolver_rule, params) req.send_request() end |
#get_resolver_rule_association(params = {}) ⇒ Types::GetResolverRuleAssociationResponse
Gets information about an association between a specified Resolver rule and a VPC. You associate a Resolver rule and a VPC using [AssociateResolverRule].
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverRule.html
3039 3040 3041 3042 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3039 def get_resolver_rule_association(params = {}, = {}) req = build_request(:get_resolver_rule_association, params) req.send_request() end |
#get_resolver_rule_policy(params = {}) ⇒ Types::GetResolverRulePolicyResponse
Gets information about the Resolver rule policy for a specified rule. A Resolver rule policy includes the rule that you want to share with another account, the account that you want to share the rule with, and the Resolver operations that you want to allow the account to use.
3071 3072 3073 3074 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3071 def get_resolver_rule_policy(params = {}, = {}) req = build_request(:get_resolver_rule_policy, params) req.send_request() end |
#import_firewall_domains(params = {}) ⇒ Types::ImportFirewallDomainsResponse
Imports domain names from a file into a domain list, for use in a DNS firewall rule group.
Each domain specification in your domain list must satisfy the following requirements:
-
It can optionally start with ‘*` (asterisk).
-
With the exception of the optional starting asterisk, it must only contain the following characters: ‘A-Z`, `a-z`, `0-9`, `-` (hyphen).
-
It must be from 1-255 characters in length.
3133 3134 3135 3136 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3133 def import_firewall_domains(params = {}, = {}) req = build_request(:import_firewall_domains, params) req.send_request() end |
#list_firewall_configs(params = {}) ⇒ Types::ListFirewallConfigsResponse
Retrieves the firewall configurations that you have defined. DNS Firewall uses the configurations to manage firewall behavior for your VPCs.
A single call might return only a partial list of the configurations. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3190 3191 3192 3193 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3190 def list_firewall_configs(params = {}, = {}) req = build_request(:list_firewall_configs, params) req.send_request() end |
#list_firewall_domain_lists(params = {}) ⇒ Types::ListFirewallDomainListsResponse
Retrieves the firewall domain lists that you have defined. For each firewall domain list, you can retrieve the domains that are defined for a list by calling ListFirewallDomains.
A single call to this list operation might return only a partial list of the domain lists. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3250 3251 3252 3253 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3250 def list_firewall_domain_lists(params = {}, = {}) req = build_request(:list_firewall_domain_lists, params) req.send_request() end |
#list_firewall_domains(params = {}) ⇒ Types::ListFirewallDomainsResponse
Retrieves the domains that you have defined for the specified firewall domain list.
A single call might return only a partial list of the domains. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3307 3308 3309 3310 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3307 def list_firewall_domains(params = {}, = {}) req = build_request(:list_firewall_domains, params) req.send_request() end |
#list_firewall_rule_group_associations(params = {}) ⇒ Types::ListFirewallRuleGroupAssociationsResponse
Retrieves the firewall rule group associations that you have defined. Each association enables DNS filtering for a VPC with one rule group.
A single call might return only a partial list of the associations. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3397 3398 3399 3400 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3397 def list_firewall_rule_group_associations(params = {}, = {}) req = build_request(:list_firewall_rule_group_associations, params) req.send_request() end |
#list_firewall_rule_groups(params = {}) ⇒ Types::ListFirewallRuleGroupsResponse
Retrieves the minimal high-level information for the rule groups that you have defined.
A single call might return only a partial list of the rule groups. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3455 3456 3457 3458 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3455 def list_firewall_rule_groups(params = {}, = {}) req = build_request(:list_firewall_rule_groups, params) req.send_request() end |
#list_firewall_rule_types(params = {}) ⇒ Types::ListFirewallRuleTypesResponse
Retrieves the available rule types that can be used in DNS Firewall rules.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3509 3510 3511 3512 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3509 def list_firewall_rule_types(params = {}, = {}) req = build_request(:list_firewall_rule_types, params) req.send_request() end |
#list_firewall_rules(params = {}) ⇒ Types::ListFirewallRulesResponse
Retrieves the firewall rules that you have defined for the specified firewall rule group. DNS Firewall uses the rules in a rule group to filter DNS network traffic for a VPC.
A single call might return only a partial list of the rules. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3614 3615 3616 3617 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3614 def list_firewall_rules(params = {}, = {}) req = build_request(:list_firewall_rules, params) req.send_request() end |
#list_outpost_resolvers(params = {}) ⇒ Types::ListOutpostResolversResponse
Lists all the Resolvers on Outposts that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3669 3670 3671 3672 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3669 def list_outpost_resolvers(params = {}, = {}) req = build_request(:list_outpost_resolvers, params) req.send_request() end |
#list_resolver_configs(params = {}) ⇒ Types::ListResolverConfigsResponse
Retrieves the Resolver configurations that you have defined. Route 53 Resolver uses the configurations to manage DNS resolution behavior for your VPCs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3722 3723 3724 3725 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3722 def list_resolver_configs(params = {}, = {}) req = build_request(:list_resolver_configs, params) req.send_request() end |
#list_resolver_dnssec_configs(params = {}) ⇒ Types::ListResolverDnssecConfigsResponse
Lists the configurations for DNSSEC validation that are associated with the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3783 3784 3785 3786 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3783 def list_resolver_dnssec_configs(params = {}, = {}) req = build_request(:list_resolver_dnssec_configs, params) req.send_request() end |
#list_resolver_endpoint_ip_addresses(params = {}) ⇒ Types::ListResolverEndpointIpAddressesResponse
Gets the IP addresses for a specified Resolver endpoint.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3842 3843 3844 3845 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3842 def list_resolver_endpoint_ip_addresses(params = {}, = {}) req = build_request(:list_resolver_endpoint_ip_addresses, params) req.send_request() end |
#list_resolver_endpoints(params = {}) ⇒ Types::ListResolverEndpointsResponse
Lists all the Resolver endpoints that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3927 3928 3929 3930 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3927 def list_resolver_endpoints(params = {}, = {}) req = build_request(:list_resolver_endpoints, params) req.send_request() end |
#list_resolver_query_log_config_associations(params = {}) ⇒ Types::ListResolverQueryLogConfigAssociationsResponse
Lists information about associations between Amazon VPCs and query logging configurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4068 4069 4070 4071 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4068 def list_resolver_query_log_config_associations(params = {}, = {}) req = build_request(:list_resolver_query_log_config_associations, params) req.send_request() end |
#list_resolver_query_log_configs(params = {}) ⇒ Types::ListResolverQueryLogConfigsResponse
Lists information about the specified query logging configurations. Each configuration defines where you want Resolver to save DNS query logs and specifies the VPCs that you want to log queries for.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4213 4214 4215 4216 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4213 def list_resolver_query_log_configs(params = {}, = {}) req = build_request(:list_resolver_query_log_configs, params) req.send_request() end |
#list_resolver_rule_associations(params = {}) ⇒ Types::ListResolverRuleAssociationsResponse
Lists the associations that were created between Resolver rules and VPCs using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4282 4283 4284 4285 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4282 def list_resolver_rule_associations(params = {}, = {}) req = build_request(:list_resolver_rule_associations, params) req.send_request() end |
#list_resolver_rules(params = {}) ⇒ Types::ListResolverRulesResponse
Lists the Resolver rules that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4365 def list_resolver_rules(params = {}, = {}) req = build_request(:list_resolver_rules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4415 4416 4417 4418 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4415 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_firewall_rule_group_policy(params = {}) ⇒ Types::PutFirewallRuleGroupPolicyResponse
Attaches an Identity and Access Management (Amazon Web Services IAM) policy for sharing the rule group. You can use the policy to share the rule group using Resource Access Manager (RAM).
4451 4452 4453 4454 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4451 def put_firewall_rule_group_policy(params = {}, = {}) req = build_request(:put_firewall_rule_group_policy, params) req.send_request() end |
#put_resolver_query_log_config_policy(params = {}) ⇒ Types::PutResolverQueryLogConfigPolicyResponse
Specifies an Amazon Web Services account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.
4501 4502 4503 4504 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4501 def put_resolver_query_log_config_policy(params = {}, = {}) req = build_request(:put_resolver_query_log_config_policy, params) req.send_request() end |
#put_resolver_rule_policy(params = {}) ⇒ Types::PutResolverRulePolicyResponse
Specifies an Amazon Web Services rule that you want to share with another account, the account that you want to share the rule with, and the operations that you want the account to be able to perform on the rule.
4555 4556 4557 4558 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4555 def put_resolver_rule_policy(params = {}, = {}) req = build_request(:put_resolver_rule_policy, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
4609 4610 4611 4612 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4609 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
4658 4659 4660 4661 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4658 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_firewall_config(params = {}) ⇒ Types::UpdateFirewallConfigResponse
Updates the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
4708 4709 4710 4711 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4708 def update_firewall_config(params = {}, = {}) req = build_request(:update_firewall_config, params) req.send_request() end |
#update_firewall_domains(params = {}) ⇒ Types::UpdateFirewallDomainsResponse
Updates the firewall domain list from an array of domain specifications.
4773 4774 4775 4776 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4773 def update_firewall_domains(params = {}, = {}) req = build_request(:update_firewall_domains, params) req.send_request() end |
#update_firewall_rule(params = {}) ⇒ Types::UpdateFirewallRuleResponse
Updates the specified firewall rule.
4995 4996 4997 4998 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4995 def update_firewall_rule(params = {}, = {}) req = build_request(:update_firewall_rule, params) req.send_request() end |
#update_firewall_rule_group_association(params = {}) ⇒ Types::UpdateFirewallRuleGroupAssociationResponse
Changes the association of a FirewallRuleGroup with a VPC. The association enables DNS filtering for the VPC.
5059 5060 5061 5062 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5059 def update_firewall_rule_group_association(params = {}, = {}) req = build_request(:update_firewall_rule_group_association, params) req.send_request() end |
#update_outpost_resolver(params = {}) ⇒ Types::UpdateOutpostResolverResponse
You can use ‘UpdateOutpostResolver` to update the instance count, type, or name of a Resolver on an Outpost.
5110 5111 5112 5113 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5110 def update_outpost_resolver(params = {}, = {}) req = build_request(:update_outpost_resolver, params) req.send_request() end |
#update_resolver_config(params = {}) ⇒ Types::UpdateResolverConfigResponse
Updates the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
5167 5168 5169 5170 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5167 def update_resolver_config(params = {}, = {}) req = build_request(:update_resolver_config, params) req.send_request() end |
#update_resolver_dnssec_config(params = {}) ⇒ Types::UpdateResolverDnssecConfigResponse
Updates an existing DNSSEC validation configuration. If there is no existing DNSSEC validation configuration, one is created.
5206 5207 5208 5209 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5206 def update_resolver_dnssec_config(params = {}, = {}) req = build_request(:update_resolver_dnssec_config, params) req.send_request() end |
#update_resolver_endpoint(params = {}) ⇒ Types::UpdateResolverEndpointResponse
Updates the name, or endpoint type for an inbound or an outbound Resolver endpoint. You can only update between IPV4 and DUALSTACK, IPV6 endpoint type can’t be updated to other type.
5382 5383 5384 5385 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5382 def update_resolver_endpoint(params = {}, = {}) req = build_request(:update_resolver_endpoint, params) req.send_request() end |
#update_resolver_rule(params = {}) ⇒ Types::UpdateResolverRuleResponse
Updates settings for a specified Resolver rule. ‘ResolverRuleId` is required, and all other parameters are optional. If you don’t specify a parameter, it retains its current value.
5447 5448 5449 5450 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5447 def update_resolver_rule(params = {}, = {}) req = build_request(:update_resolver_rule, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5476 5477 5478 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5476 def waiter_names [] end |