Class: Aws::Route53Resolver::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Route53Resolver::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-route53resolver/client.rb
Overview
An API client for Route53Resolver. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Route53Resolver::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_firewall_rule_group(params = {}) ⇒ Types::AssociateFirewallRuleGroupResponse
Associates a FirewallRuleGroup with a VPC, to provide DNS filtering for the VPC.
-
#associate_resolver_endpoint_ip_address(params = {}) ⇒ Types::AssociateResolverEndpointIpAddressResponse
Adds IP addresses to an inbound or an outbound Resolver endpoint.
-
#associate_resolver_query_log_config(params = {}) ⇒ Types::AssociateResolverQueryLogConfigResponse
Associates an Amazon VPC with a specified query logging configuration.
-
#associate_resolver_rule(params = {}) ⇒ Types::AssociateResolverRuleResponse
Associates a Resolver rule with a VPC.
-
#create_firewall_domain_list(params = {}) ⇒ Types::CreateFirewallDomainListResponse
Creates an empty firewall domain list for use in DNS Firewall rules.
-
#create_firewall_rule(params = {}) ⇒ Types::CreateFirewallRuleResponse
Creates a single DNS Firewall rule in the specified rule group, using the specified domain list.
-
#create_firewall_rule_group(params = {}) ⇒ Types::CreateFirewallRuleGroupResponse
Creates an empty DNS Firewall rule group for filtering DNS network traffic in a VPC.
-
#create_outpost_resolver(params = {}) ⇒ Types::CreateOutpostResolverResponse
Creates a Route 53 Resolver on an Outpost.
-
#create_resolver_endpoint(params = {}) ⇒ Types::CreateResolverEndpointResponse
Creates a Resolver endpoint.
-
#create_resolver_query_log_config(params = {}) ⇒ Types::CreateResolverQueryLogConfigResponse
Creates a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs.
-
#create_resolver_rule(params = {}) ⇒ Types::CreateResolverRuleResponse
For DNS queries that originate in your VPCs, specifies which Resolver endpoint the queries pass through, one domain name that you want to forward to your network, and the IP addresses of the DNS resolvers in your network.
-
#delete_firewall_domain_list(params = {}) ⇒ Types::DeleteFirewallDomainListResponse
Deletes the specified domain list.
-
#delete_firewall_rule(params = {}) ⇒ Types::DeleteFirewallRuleResponse
Deletes the specified firewall rule.
-
#delete_firewall_rule_group(params = {}) ⇒ Types::DeleteFirewallRuleGroupResponse
Deletes the specified firewall rule group.
-
#delete_outpost_resolver(params = {}) ⇒ Types::DeleteOutpostResolverResponse
Deletes a Resolver on the Outpost.
-
#delete_resolver_endpoint(params = {}) ⇒ Types::DeleteResolverEndpointResponse
Deletes a Resolver endpoint.
-
#delete_resolver_query_log_config(params = {}) ⇒ Types::DeleteResolverQueryLogConfigResponse
Deletes a query logging configuration.
-
#delete_resolver_rule(params = {}) ⇒ Types::DeleteResolverRuleResponse
Deletes a Resolver rule.
-
#disassociate_firewall_rule_group(params = {}) ⇒ Types::DisassociateFirewallRuleGroupResponse
Disassociates a FirewallRuleGroup from a VPC, to remove DNS filtering from the VPC.
-
#disassociate_resolver_endpoint_ip_address(params = {}) ⇒ Types::DisassociateResolverEndpointIpAddressResponse
Removes IP addresses from an inbound or an outbound Resolver endpoint.
-
#disassociate_resolver_query_log_config(params = {}) ⇒ Types::DisassociateResolverQueryLogConfigResponse
Disassociates a VPC from a query logging configuration.
-
#disassociate_resolver_rule(params = {}) ⇒ Types::DisassociateResolverRuleResponse
Removes the association between a specified Resolver rule and a specified VPC.
-
#get_firewall_config(params = {}) ⇒ Types::GetFirewallConfigResponse
Retrieves the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
-
#get_firewall_domain_list(params = {}) ⇒ Types::GetFirewallDomainListResponse
Retrieves the specified firewall domain list.
-
#get_firewall_rule_group(params = {}) ⇒ Types::GetFirewallRuleGroupResponse
Retrieves the specified firewall rule group.
-
#get_firewall_rule_group_association(params = {}) ⇒ Types::GetFirewallRuleGroupAssociationResponse
Retrieves a firewall rule group association, which enables DNS filtering for a VPC with one rule group.
-
#get_firewall_rule_group_policy(params = {}) ⇒ Types::GetFirewallRuleGroupPolicyResponse
Returns the Identity and Access Management (Amazon Web Services IAM) policy for sharing the specified rule group.
-
#get_outpost_resolver(params = {}) ⇒ Types::GetOutpostResolverResponse
Gets information about a specified Resolver on the Outpost, such as its instance count and type, name, and the current status of the Resolver.
-
#get_resolver_config(params = {}) ⇒ Types::GetResolverConfigResponse
Retrieves the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
-
#get_resolver_dnssec_config(params = {}) ⇒ Types::GetResolverDnssecConfigResponse
Gets DNSSEC validation information for a specified resource.
-
#get_resolver_endpoint(params = {}) ⇒ Types::GetResolverEndpointResponse
Gets information about a specified Resolver endpoint, such as whether it’s an inbound or an outbound Resolver endpoint, and the current status of the endpoint.
-
#get_resolver_query_log_config(params = {}) ⇒ Types::GetResolverQueryLogConfigResponse
Gets information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to.
-
#get_resolver_query_log_config_association(params = {}) ⇒ Types::GetResolverQueryLogConfigAssociationResponse
Gets information about a specified association between a Resolver query logging configuration and an Amazon VPC.
-
#get_resolver_query_log_config_policy(params = {}) ⇒ Types::GetResolverQueryLogConfigPolicyResponse
Gets information about a query logging policy.
-
#get_resolver_rule(params = {}) ⇒ Types::GetResolverRuleResponse
Gets information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the ID of the outbound Resolver endpoint that the rule is associated with.
-
#get_resolver_rule_association(params = {}) ⇒ Types::GetResolverRuleAssociationResponse
Gets information about an association between a specified Resolver rule and a VPC.
-
#get_resolver_rule_policy(params = {}) ⇒ Types::GetResolverRulePolicyResponse
Gets information about the Resolver rule policy for a specified rule.
-
#import_firewall_domains(params = {}) ⇒ Types::ImportFirewallDomainsResponse
Imports domain names from a file into a domain list, for use in a DNS firewall rule group.
-
#list_firewall_configs(params = {}) ⇒ Types::ListFirewallConfigsResponse
Retrieves the firewall configurations that you have defined.
-
#list_firewall_domain_lists(params = {}) ⇒ Types::ListFirewallDomainListsResponse
Retrieves the firewall domain lists that you have defined.
-
#list_firewall_domains(params = {}) ⇒ Types::ListFirewallDomainsResponse
Retrieves the domains that you have defined for the specified firewall domain list.
-
#list_firewall_rule_group_associations(params = {}) ⇒ Types::ListFirewallRuleGroupAssociationsResponse
Retrieves the firewall rule group associations that you have defined.
-
#list_firewall_rule_groups(params = {}) ⇒ Types::ListFirewallRuleGroupsResponse
Retrieves the minimal high-level information for the rule groups that you have defined.
-
#list_firewall_rules(params = {}) ⇒ Types::ListFirewallRulesResponse
Retrieves the firewall rules that you have defined for the specified firewall rule group.
-
#list_outpost_resolvers(params = {}) ⇒ Types::ListOutpostResolversResponse
Lists all the Resolvers on Outposts that were created using the current Amazon Web Services account.
-
#list_resolver_configs(params = {}) ⇒ Types::ListResolverConfigsResponse
Retrieves the Resolver configurations that you have defined.
-
#list_resolver_dnssec_configs(params = {}) ⇒ Types::ListResolverDnssecConfigsResponse
Lists the configurations for DNSSEC validation that are associated with the current Amazon Web Services account.
-
#list_resolver_endpoint_ip_addresses(params = {}) ⇒ Types::ListResolverEndpointIpAddressesResponse
Gets the IP addresses for a specified Resolver endpoint.
-
#list_resolver_endpoints(params = {}) ⇒ Types::ListResolverEndpointsResponse
Lists all the Resolver endpoints that were created using the current Amazon Web Services account.
-
#list_resolver_query_log_config_associations(params = {}) ⇒ Types::ListResolverQueryLogConfigAssociationsResponse
Lists information about associations between Amazon VPCs and query logging configurations.
-
#list_resolver_query_log_configs(params = {}) ⇒ Types::ListResolverQueryLogConfigsResponse
Lists information about the specified query logging configurations.
-
#list_resolver_rule_associations(params = {}) ⇒ Types::ListResolverRuleAssociationsResponse
Lists the associations that were created between Resolver rules and VPCs using the current Amazon Web Services account.
-
#list_resolver_rules(params = {}) ⇒ Types::ListResolverRulesResponse
Lists the Resolver rules that were created using the current Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
-
#put_firewall_rule_group_policy(params = {}) ⇒ Types::PutFirewallRuleGroupPolicyResponse
Attaches an Identity and Access Management (Amazon Web Services IAM) policy for sharing the rule group.
-
#put_resolver_query_log_config_policy(params = {}) ⇒ Types::PutResolverQueryLogConfigPolicyResponse
Specifies an Amazon Web Services account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.
-
#put_resolver_rule_policy(params = {}) ⇒ Types::PutResolverRulePolicyResponse
Specifies an Amazon Web Services rule that you want to share with another account, the account that you want to share the rule with, and the operations that you want the account to be able to perform on the rule.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
-
#update_firewall_config(params = {}) ⇒ Types::UpdateFirewallConfigResponse
Updates the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
-
#update_firewall_domains(params = {}) ⇒ Types::UpdateFirewallDomainsResponse
Updates the firewall domain list from an array of domain specifications.
-
#update_firewall_rule(params = {}) ⇒ Types::UpdateFirewallRuleResponse
Updates the specified firewall rule.
-
#update_firewall_rule_group_association(params = {}) ⇒ Types::UpdateFirewallRuleGroupAssociationResponse
Changes the association of a FirewallRuleGroup with a VPC.
-
#update_outpost_resolver(params = {}) ⇒ Types::UpdateOutpostResolverResponse
You can use ‘UpdateOutpostResolver` to update the instance count, type, or name of a Resolver on an Outpost.
-
#update_resolver_config(params = {}) ⇒ Types::UpdateResolverConfigResponse
Updates the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
-
#update_resolver_dnssec_config(params = {}) ⇒ Types::UpdateResolverDnssecConfigResponse
Updates an existing DNSSEC validation configuration.
-
#update_resolver_endpoint(params = {}) ⇒ Types::UpdateResolverEndpointResponse
Updates the name, or endpoint type for an inbound or an outbound Resolver endpoint.
-
#update_resolver_rule(params = {}) ⇒ Types::UpdateResolverRuleResponse
Updates settings for a specified Resolver rule.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5109 5110 5111 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5109 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5112 5113 5114 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5112 def errors_module Errors end |
Instance Method Details
#associate_firewall_rule_group(params = {}) ⇒ Types::AssociateFirewallRuleGroupResponse
Associates a FirewallRuleGroup with a VPC, to provide DNS filtering for the VPC.
573 574 575 576 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 573 def associate_firewall_rule_group(params = {}, = {}) req = build_request(:associate_firewall_rule_group, params) req.send_request() end |
#associate_resolver_endpoint_ip_address(params = {}) ⇒ Types::AssociateResolverEndpointIpAddressResponse
Adds IP addresses to an inbound or an outbound Resolver endpoint. If you want to add more than one IP address, submit one ‘AssociateResolverEndpointIpAddress` request for each IP address.
To remove an IP address from an endpoint, see [DisassociateResolverEndpointIpAddress].
643 644 645 646 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 643 def associate_resolver_endpoint_ip_address(params = {}, = {}) req = build_request(:associate_resolver_endpoint_ip_address, params) req.send_request() end |
#associate_resolver_query_log_config(params = {}) ⇒ Types::AssociateResolverQueryLogConfigResponse
Associates an Amazon VPC with a specified query logging configuration. Route 53 Resolver logs DNS queries that originate in all of the Amazon VPCs that are associated with a specified query logging configuration. To associate more than one VPC with a configuration, submit one ‘AssociateResolverQueryLogConfig` request for each VPC.
<note markdown=“1”> The VPCs that you associate with a query logging configuration must be in the same Region as the configuration.
</note>
To remove a VPC from a query logging configuration, see [DisassociateResolverQueryLogConfig].
704 705 706 707 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 704 def associate_resolver_query_log_config(params = {}, = {}) req = build_request(:associate_resolver_query_log_config, params) req.send_request() end |
#associate_resolver_rule(params = {}) ⇒ Types::AssociateResolverRuleResponse
Associates a Resolver rule with a VPC. When you associate a rule with a VPC, Resolver forwards all DNS queries for the domain name that is specified in the rule and that originate in the VPC. The queries are forwarded to the IP addresses for the DNS resolvers that are specified in the rule. For more information about rules, see [CreateResolverRule].
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverRule.html
764 765 766 767 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 764 def associate_resolver_rule(params = {}, = {}) req = build_request(:associate_resolver_rule, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5082 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Route53Resolver') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-route53resolver' context[:gem_version] = '1.96.0' Seahorse::Client::Request.new(handlers, context) end |
#create_firewall_domain_list(params = {}) ⇒ Types::CreateFirewallDomainListResponse
Creates an empty firewall domain list for use in DNS Firewall rules. You can populate the domains for the new list with a file, using ImportFirewallDomains, or with domain strings, using UpdateFirewallDomains.
824 825 826 827 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 824 def create_firewall_domain_list(params = {}, = {}) req = build_request(:create_firewall_domain_list, params) req.send_request() end |
#create_firewall_rule(params = {}) ⇒ Types::CreateFirewallRuleResponse
Creates a single DNS Firewall rule in the specified rule group, using the specified domain list.
1028 1029 1030 1031 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1028 def create_firewall_rule(params = {}, = {}) req = build_request(:create_firewall_rule, params) req.send_request() end |
#create_firewall_rule_group(params = {}) ⇒ Types::CreateFirewallRuleGroupResponse
Creates an empty DNS Firewall rule group for filtering DNS network traffic in a VPC. You can add rules to the new rule group by calling CreateFirewallRule.
1087 1088 1089 1090 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1087 def create_firewall_rule_group(params = {}, = {}) req = build_request(:create_firewall_rule_group, params) req.send_request() end |
#create_outpost_resolver(params = {}) ⇒ Types::CreateOutpostResolverResponse
Creates a Route 53 Resolver on an Outpost.
1159 1160 1161 1162 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1159 def create_outpost_resolver(params = {}, = {}) req = build_request(:create_outpost_resolver, params) req.send_request() end |
#create_resolver_endpoint(params = {}) ⇒ Types::CreateResolverEndpointResponse
Creates a Resolver endpoint. There are two types of Resolver endpoints, inbound and outbound:
-
An *inbound Resolver endpoint* forwards DNS queries to the DNS service for a VPC from your network.
-
An *outbound Resolver endpoint* forwards DNS queries from the DNS service for a VPC to your network.
1396 1397 1398 1399 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1396 def create_resolver_endpoint(params = {}, = {}) req = build_request(:create_resolver_endpoint, params) req.send_request() end |
#create_resolver_query_log_config(params = {}) ⇒ Types::CreateResolverQueryLogConfigResponse
Creates a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs. Resolver can log queries only for VPCs that are in the same Region as the query logging configuration.
To specify which VPCs you want to log queries for, you use ‘AssociateResolverQueryLogConfig`. For more information, see [AssociateResolverQueryLogConfig].
You can optionally use Resource Access Manager (RAM) to share a query logging configuration with other Amazon Web Services accounts. The other accounts can then associate VPCs with the configuration. The query logs that Resolver creates for a configuration include all DNS queries that originate in all VPCs that are associated with the configuration.
1494 1495 1496 1497 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1494 def create_resolver_query_log_config(params = {}, = {}) req = build_request(:create_resolver_query_log_config, params) req.send_request() end |
#create_resolver_rule(params = {}) ⇒ Types::CreateResolverRuleResponse
For DNS queries that originate in your VPCs, specifies which Resolver endpoint the queries pass through, one domain name that you want to forward to your network, and the IP addresses of the DNS resolvers in your network.
1627 1628 1629 1630 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1627 def create_resolver_rule(params = {}, = {}) req = build_request(:create_resolver_rule, params) req.send_request() end |
#delete_firewall_domain_list(params = {}) ⇒ Types::DeleteFirewallDomainListResponse
Deletes the specified domain list.
1664 1665 1666 1667 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1664 def delete_firewall_domain_list(params = {}, = {}) req = build_request(:delete_firewall_domain_list, params) req.send_request() end |
#delete_firewall_rule(params = {}) ⇒ Types::DeleteFirewallRuleResponse
Deletes the specified firewall rule.
1759 1760 1761 1762 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1759 def delete_firewall_rule(params = {}, = {}) req = build_request(:delete_firewall_rule, params) req.send_request() end |
#delete_firewall_rule_group(params = {}) ⇒ Types::DeleteFirewallRuleGroupResponse
Deletes the specified firewall rule group.
1798 1799 1800 1801 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1798 def delete_firewall_rule_group(params = {}, = {}) req = build_request(:delete_firewall_rule_group, params) req.send_request() end |
#delete_outpost_resolver(params = {}) ⇒ Types::DeleteOutpostResolverResponse
Deletes a Resolver on the Outpost.
1836 1837 1838 1839 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1836 def delete_outpost_resolver(params = {}, = {}) req = build_request(:delete_outpost_resolver, params) req.send_request() end |
#delete_resolver_endpoint(params = {}) ⇒ Types::DeleteResolverEndpointResponse
Deletes a Resolver endpoint. The effect of deleting a Resolver endpoint depends on whether it’s an inbound or an outbound Resolver endpoint:
-
Inbound: DNS queries from your network are no longer routed to the DNS service for the specified VPC.
-
Outbound: DNS queries from a VPC are no longer routed to your network.
1893 1894 1895 1896 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1893 def delete_resolver_endpoint(params = {}, = {}) req = build_request(:delete_resolver_endpoint, params) req.send_request() end |
#delete_resolver_query_log_config(params = {}) ⇒ Types::DeleteResolverQueryLogConfigResponse
Deletes a query logging configuration. When you delete a configuration, Resolver stops logging DNS queries for all of the Amazon VPCs that are associated with the configuration. This also applies if the query logging configuration is shared with other Amazon Web Services accounts, and the other accounts have associated VPCs with the shared configuration.
Before you can delete a query logging configuration, you must first disassociate all VPCs from the configuration. See [DisassociateResolverQueryLogConfig].
If you used Resource Access Manager (RAM) to share a query logging configuration with other accounts, you must stop sharing the configuration before you can delete a configuration. The accounts that you shared the configuration with can first disassociate VPCs that they associated with the configuration, but that’s not necessary. If you stop sharing the configuration, those VPCs are automatically disassociated from the configuration.
1951 1952 1953 1954 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 1951 def delete_resolver_query_log_config(params = {}, = {}) req = build_request(:delete_resolver_query_log_config, params) req.send_request() end |
#delete_resolver_rule(params = {}) ⇒ Types::DeleteResolverRuleResponse
Deletes a Resolver rule. Before you can delete a Resolver rule, you must disassociate it from all the VPCs that you associated the Resolver rule with. For more information, see [DisassociateResolverRule].
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverRule.html
2005 2006 2007 2008 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2005 def delete_resolver_rule(params = {}, = {}) req = build_request(:delete_resolver_rule, params) req.send_request() end |
#disassociate_firewall_rule_group(params = {}) ⇒ Types::DisassociateFirewallRuleGroupResponse
Disassociates a FirewallRuleGroup from a VPC, to remove DNS filtering from the VPC.
2046 2047 2048 2049 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2046 def disassociate_firewall_rule_group(params = {}, = {}) req = build_request(:disassociate_firewall_rule_group, params) req.send_request() end |
#disassociate_resolver_endpoint_ip_address(params = {}) ⇒ Types::DisassociateResolverEndpointIpAddressResponse
Removes IP addresses from an inbound or an outbound Resolver endpoint. If you want to remove more than one IP address, submit one ‘DisassociateResolverEndpointIpAddress` request for each IP address.
To add an IP address to an endpoint, see [AssociateResolverEndpointIpAddress].
2114 2115 2116 2117 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2114 def disassociate_resolver_endpoint_ip_address(params = {}, = {}) req = build_request(:disassociate_resolver_endpoint_ip_address, params) req.send_request() end |
#disassociate_resolver_query_log_config(params = {}) ⇒ Types::DisassociateResolverQueryLogConfigResponse
Disassociates a VPC from a query logging configuration.
<note markdown=“1”> Before you can delete a query logging configuration, you must first disassociate all VPCs from the configuration. If you used Resource Access Manager (RAM) to share a query logging configuration with other accounts, VPCs can be disassociated from the configuration in the following ways:
* The accounts that you shared the configuration with can disassociate
VPCs from the configuration.
-
You can stop sharing the configuration.
</note>
2167 2168 2169 2170 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2167 def disassociate_resolver_query_log_config(params = {}, = {}) req = build_request(:disassociate_resolver_query_log_config, params) req.send_request() end |
#disassociate_resolver_rule(params = {}) ⇒ Types::DisassociateResolverRuleResponse
Removes the association between a specified Resolver rule and a specified VPC.
If you disassociate a Resolver rule from a VPC, Resolver stops forwarding DNS queries for the domain name that you specified in the Resolver rule.
2211 2212 2213 2214 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2211 def disassociate_resolver_rule(params = {}, = {}) req = build_request(:disassociate_resolver_rule, params) req.send_request() end |
#get_firewall_config(params = {}) ⇒ Types::GetFirewallConfigResponse
Retrieves the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
2244 2245 2246 2247 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2244 def get_firewall_config(params = {}, = {}) req = build_request(:get_firewall_config, params) req.send_request() end |
#get_firewall_domain_list(params = {}) ⇒ Types::GetFirewallDomainListResponse
Retrieves the specified firewall domain list.
2281 2282 2283 2284 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2281 def get_firewall_domain_list(params = {}, = {}) req = build_request(:get_firewall_domain_list, params) req.send_request() end |
#get_firewall_rule_group(params = {}) ⇒ Types::GetFirewallRuleGroupResponse
Retrieves the specified firewall rule group.
2319 2320 2321 2322 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2319 def get_firewall_rule_group(params = {}, = {}) req = build_request(:get_firewall_rule_group, params) req.send_request() end |
#get_firewall_rule_group_association(params = {}) ⇒ Types::GetFirewallRuleGroupAssociationResponse
Retrieves a firewall rule group association, which enables DNS filtering for a VPC with one rule group. A VPC can have more than one firewall rule group association, and a rule group can be associated with more than one VPC.
2362 2363 2364 2365 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2362 def get_firewall_rule_group_association(params = {}, = {}) req = build_request(:get_firewall_rule_group_association, params) req.send_request() end |
#get_firewall_rule_group_policy(params = {}) ⇒ Types::GetFirewallRuleGroupPolicyResponse
Returns the Identity and Access Management (Amazon Web Services IAM) policy for sharing the specified rule group. You can use the policy to share the rule group using Resource Access Manager (RAM).
2392 2393 2394 2395 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2392 def get_firewall_rule_group_policy(params = {}, = {}) req = build_request(:get_firewall_rule_group_policy, params) req.send_request() end |
#get_outpost_resolver(params = {}) ⇒ Types::GetOutpostResolverResponse
Gets information about a specified Resolver on the Outpost, such as its instance count and type, name, and the current status of the Resolver.
2432 2433 2434 2435 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2432 def get_outpost_resolver(params = {}, = {}) req = build_request(:get_outpost_resolver, params) req.send_request() end |
#get_resolver_config(params = {}) ⇒ Types::GetResolverConfigResponse
Retrieves the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
2464 2465 2466 2467 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2464 def get_resolver_config(params = {}, = {}) req = build_request(:get_resolver_config, params) req.send_request() end |
#get_resolver_dnssec_config(params = {}) ⇒ Types::GetResolverDnssecConfigResponse
Gets DNSSEC validation information for a specified resource.
2496 2497 2498 2499 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2496 def get_resolver_dnssec_config(params = {}, = {}) req = build_request(:get_resolver_dnssec_config, params) req.send_request() end |
#get_resolver_endpoint(params = {}) ⇒ Types::GetResolverEndpointResponse
Gets information about a specified Resolver endpoint, such as whether it’s an inbound or an outbound Resolver endpoint, and the current status of the endpoint.
2548 2549 2550 2551 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2548 def get_resolver_endpoint(params = {}, = {}) req = build_request(:get_resolver_endpoint, params) req.send_request() end |
#get_resolver_query_log_config(params = {}) ⇒ Types::GetResolverQueryLogConfigResponse
Gets information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to.
2588 2589 2590 2591 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2588 def get_resolver_query_log_config(params = {}, = {}) req = build_request(:get_resolver_query_log_config, params) req.send_request() end |
#get_resolver_query_log_config_association(params = {}) ⇒ Types::GetResolverQueryLogConfigAssociationResponse
Gets information about a specified association between a Resolver query logging configuration and an Amazon VPC. When you associate a VPC with a query logging configuration, Resolver logs DNS queries that originate in that VPC.
2626 2627 2628 2629 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2626 def get_resolver_query_log_config_association(params = {}, = {}) req = build_request(:get_resolver_query_log_config_association, params) req.send_request() end |
#get_resolver_query_log_config_policy(params = {}) ⇒ Types::GetResolverQueryLogConfigPolicyResponse
Gets information about a query logging policy. A query logging policy specifies the Resolver query logging operations and resources that you want to allow another Amazon Web Services account to be able to use.
2657 2658 2659 2660 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2657 def get_resolver_query_log_config_policy(params = {}, = {}) req = build_request(:get_resolver_query_log_config_policy, params) req.send_request() end |
#get_resolver_rule(params = {}) ⇒ Types::GetResolverRuleResponse
Gets information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the ID of the outbound Resolver endpoint that the rule is associated with.
2706 2707 2708 2709 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2706 def get_resolver_rule(params = {}, = {}) req = build_request(:get_resolver_rule, params) req.send_request() end |
#get_resolver_rule_association(params = {}) ⇒ Types::GetResolverRuleAssociationResponse
Gets information about an association between a specified Resolver rule and a VPC. You associate a Resolver rule and a VPC using [AssociateResolverRule].
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverRule.html
2746 2747 2748 2749 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2746 def get_resolver_rule_association(params = {}, = {}) req = build_request(:get_resolver_rule_association, params) req.send_request() end |
#get_resolver_rule_policy(params = {}) ⇒ Types::GetResolverRulePolicyResponse
Gets information about the Resolver rule policy for a specified rule. A Resolver rule policy includes the rule that you want to share with another account, the account that you want to share the rule with, and the Resolver operations that you want to allow the account to use.
2778 2779 2780 2781 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2778 def get_resolver_rule_policy(params = {}, = {}) req = build_request(:get_resolver_rule_policy, params) req.send_request() end |
#import_firewall_domains(params = {}) ⇒ Types::ImportFirewallDomainsResponse
Imports domain names from a file into a domain list, for use in a DNS firewall rule group.
Each domain specification in your domain list must satisfy the following requirements:
-
It can optionally start with ‘*` (asterisk).
-
With the exception of the optional starting asterisk, it must only contain the following characters: ‘A-Z`, `a-z`, `0-9`, `-` (hyphen).
-
It must be from 1-255 characters in length.
2840 2841 2842 2843 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2840 def import_firewall_domains(params = {}, = {}) req = build_request(:import_firewall_domains, params) req.send_request() end |
#list_firewall_configs(params = {}) ⇒ Types::ListFirewallConfigsResponse
Retrieves the firewall configurations that you have defined. DNS Firewall uses the configurations to manage firewall behavior for your VPCs.
A single call might return only a partial list of the configurations. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2897 2898 2899 2900 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2897 def list_firewall_configs(params = {}, = {}) req = build_request(:list_firewall_configs, params) req.send_request() end |
#list_firewall_domain_lists(params = {}) ⇒ Types::ListFirewallDomainListsResponse
Retrieves the firewall domain lists that you have defined. For each firewall domain list, you can retrieve the domains that are defined for a list by calling ListFirewallDomains.
A single call to this list operation might return only a partial list of the domain lists. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2955 2956 2957 2958 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 2955 def list_firewall_domain_lists(params = {}, = {}) req = build_request(:list_firewall_domain_lists, params) req.send_request() end |
#list_firewall_domains(params = {}) ⇒ Types::ListFirewallDomainsResponse
Retrieves the domains that you have defined for the specified firewall domain list.
A single call might return only a partial list of the domains. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3012 3013 3014 3015 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3012 def list_firewall_domains(params = {}, = {}) req = build_request(:list_firewall_domains, params) req.send_request() end |
#list_firewall_rule_group_associations(params = {}) ⇒ Types::ListFirewallRuleGroupAssociationsResponse
Retrieves the firewall rule group associations that you have defined. Each association enables DNS filtering for a VPC with one rule group.
A single call might return only a partial list of the associations. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3102 3103 3104 3105 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3102 def list_firewall_rule_group_associations(params = {}, = {}) req = build_request(:list_firewall_rule_group_associations, params) req.send_request() end |
#list_firewall_rule_groups(params = {}) ⇒ Types::ListFirewallRuleGroupsResponse
Retrieves the minimal high-level information for the rule groups that you have defined.
A single call might return only a partial list of the rule groups. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3160 3161 3162 3163 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3160 def list_firewall_rule_groups(params = {}, = {}) req = build_request(:list_firewall_rule_groups, params) req.send_request() end |
#list_firewall_rules(params = {}) ⇒ Types::ListFirewallRulesResponse
Retrieves the firewall rules that you have defined for the specified firewall rule group. DNS Firewall uses the rules in a rule group to filter DNS network traffic for a VPC.
A single call might return only a partial list of the rules. For information, see ‘MaxResults`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3261 3262 3263 3264 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3261 def list_firewall_rules(params = {}, = {}) req = build_request(:list_firewall_rules, params) req.send_request() end |
#list_outpost_resolvers(params = {}) ⇒ Types::ListOutpostResolversResponse
Lists all the Resolvers on Outposts that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3316 3317 3318 3319 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3316 def list_outpost_resolvers(params = {}, = {}) req = build_request(:list_outpost_resolvers, params) req.send_request() end |
#list_resolver_configs(params = {}) ⇒ Types::ListResolverConfigsResponse
Retrieves the Resolver configurations that you have defined. Route 53 Resolver uses the configurations to manage DNS resolution behavior for your VPCs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3369 3370 3371 3372 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3369 def list_resolver_configs(params = {}, = {}) req = build_request(:list_resolver_configs, params) req.send_request() end |
#list_resolver_dnssec_configs(params = {}) ⇒ Types::ListResolverDnssecConfigsResponse
Lists the configurations for DNSSEC validation that are associated with the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3430 3431 3432 3433 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3430 def list_resolver_dnssec_configs(params = {}, = {}) req = build_request(:list_resolver_dnssec_configs, params) req.send_request() end |
#list_resolver_endpoint_ip_addresses(params = {}) ⇒ Types::ListResolverEndpointIpAddressesResponse
Gets the IP addresses for a specified Resolver endpoint.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3489 3490 3491 3492 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3489 def list_resolver_endpoint_ip_addresses(params = {}, = {}) req = build_request(:list_resolver_endpoint_ip_addresses, params) req.send_request() end |
#list_resolver_endpoints(params = {}) ⇒ Types::ListResolverEndpointsResponse
Lists all the Resolver endpoints that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3574 3575 3576 3577 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3574 def list_resolver_endpoints(params = {}, = {}) req = build_request(:list_resolver_endpoints, params) req.send_request() end |
#list_resolver_query_log_config_associations(params = {}) ⇒ Types::ListResolverQueryLogConfigAssociationsResponse
Lists information about associations between Amazon VPCs and query logging configurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3715 3716 3717 3718 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3715 def list_resolver_query_log_config_associations(params = {}, = {}) req = build_request(:list_resolver_query_log_config_associations, params) req.send_request() end |
#list_resolver_query_log_configs(params = {}) ⇒ Types::ListResolverQueryLogConfigsResponse
Lists information about the specified query logging configurations. Each configuration defines where you want Resolver to save DNS query logs and specifies the VPCs that you want to log queries for.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3860 3861 3862 3863 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3860 def list_resolver_query_log_configs(params = {}, = {}) req = build_request(:list_resolver_query_log_configs, params) req.send_request() end |
#list_resolver_rule_associations(params = {}) ⇒ Types::ListResolverRuleAssociationsResponse
Lists the associations that were created between Resolver rules and VPCs using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3929 3930 3931 3932 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 3929 def list_resolver_rule_associations(params = {}, = {}) req = build_request(:list_resolver_rule_associations, params) req.send_request() end |
#list_resolver_rules(params = {}) ⇒ Types::ListResolverRulesResponse
Lists the Resolver rules that were created using the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4012 4013 4014 4015 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4012 def list_resolver_rules(params = {}, = {}) req = build_request(:list_resolver_rules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4062 4063 4064 4065 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4062 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_firewall_rule_group_policy(params = {}) ⇒ Types::PutFirewallRuleGroupPolicyResponse
Attaches an Identity and Access Management (Amazon Web Services IAM) policy for sharing the rule group. You can use the policy to share the rule group using Resource Access Manager (RAM).
4098 4099 4100 4101 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4098 def put_firewall_rule_group_policy(params = {}, = {}) req = build_request(:put_firewall_rule_group_policy, params) req.send_request() end |
#put_resolver_query_log_config_policy(params = {}) ⇒ Types::PutResolverQueryLogConfigPolicyResponse
Specifies an Amazon Web Services account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.
4148 4149 4150 4151 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4148 def put_resolver_query_log_config_policy(params = {}, = {}) req = build_request(:put_resolver_query_log_config_policy, params) req.send_request() end |
#put_resolver_rule_policy(params = {}) ⇒ Types::PutResolverRulePolicyResponse
Specifies an Amazon Web Services rule that you want to share with another account, the account that you want to share the rule with, and the operations that you want the account to be able to perform on the rule.
4202 4203 4204 4205 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4202 def put_resolver_rule_policy(params = {}, = {}) req = build_request(:put_resolver_rule_policy, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
4256 4257 4258 4259 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4256 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
4305 4306 4307 4308 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4305 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_firewall_config(params = {}) ⇒ Types::UpdateFirewallConfigResponse
Updates the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).
4355 4356 4357 4358 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4355 def update_firewall_config(params = {}, = {}) req = build_request(:update_firewall_config, params) req.send_request() end |
#update_firewall_domains(params = {}) ⇒ Types::UpdateFirewallDomainsResponse
Updates the firewall domain list from an array of domain specifications.
4420 4421 4422 4423 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4420 def update_firewall_domains(params = {}, = {}) req = build_request(:update_firewall_domains, params) req.send_request() end |
#update_firewall_rule(params = {}) ⇒ Types::UpdateFirewallRuleResponse
Updates the specified firewall rule.
4621 4622 4623 4624 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4621 def update_firewall_rule(params = {}, = {}) req = build_request(:update_firewall_rule, params) req.send_request() end |
#update_firewall_rule_group_association(params = {}) ⇒ Types::UpdateFirewallRuleGroupAssociationResponse
Changes the association of a FirewallRuleGroup with a VPC. The association enables DNS filtering for the VPC.
4685 4686 4687 4688 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4685 def update_firewall_rule_group_association(params = {}, = {}) req = build_request(:update_firewall_rule_group_association, params) req.send_request() end |
#update_outpost_resolver(params = {}) ⇒ Types::UpdateOutpostResolverResponse
You can use ‘UpdateOutpostResolver` to update the instance count, type, or name of a Resolver on an Outpost.
4736 4737 4738 4739 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4736 def update_outpost_resolver(params = {}, = {}) req = build_request(:update_outpost_resolver, params) req.send_request() end |
#update_resolver_config(params = {}) ⇒ Types::UpdateResolverConfigResponse
Updates the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud.
4793 4794 4795 4796 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4793 def update_resolver_config(params = {}, = {}) req = build_request(:update_resolver_config, params) req.send_request() end |
#update_resolver_dnssec_config(params = {}) ⇒ Types::UpdateResolverDnssecConfigResponse
Updates an existing DNSSEC validation configuration. If there is no existing DNSSEC validation configuration, one is created.
4832 4833 4834 4835 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 4832 def update_resolver_dnssec_config(params = {}, = {}) req = build_request(:update_resolver_dnssec_config, params) req.send_request() end |
#update_resolver_endpoint(params = {}) ⇒ Types::UpdateResolverEndpointResponse
Updates the name, or endpoint type for an inbound or an outbound Resolver endpoint. You can only update between IPV4 and DUALSTACK, IPV6 endpoint type can’t be updated to other type.
5008 5009 5010 5011 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5008 def update_resolver_endpoint(params = {}, = {}) req = build_request(:update_resolver_endpoint, params) req.send_request() end |
#update_resolver_rule(params = {}) ⇒ Types::UpdateResolverRuleResponse
Updates settings for a specified Resolver rule. ‘ResolverRuleId` is required, and all other parameters are optional. If you don’t specify a parameter, it retains its current value.
5073 5074 5075 5076 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5073 def update_resolver_rule(params = {}, = {}) req = build_request(:update_resolver_rule, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5102 5103 5104 |
# File 'lib/aws-sdk-route53resolver/client.rb', line 5102 def waiter_names [] end |