Class: Aws::Route53Resolver::Types::CreateFirewallRuleGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::CreateFirewallRuleGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creator_request_id ⇒ String
A unique string defined by you to identify the request.
-
#name ⇒ String
A name that lets you identify the rule group, to manage and use it.
-
#tags ⇒ Array<Types::Tag>
A list of the tag keys and values that you want to associate with the rule group.
Instance Attribute Details
#creator_request_id ⇒ String
A unique string defined by you to identify the request. This allows you to retry failed requests without the risk of running the operation twice. This can be any unique string, for example, a timestamp.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
660 661 662 663 664 665 666 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 660 class CreateFirewallRuleGroupRequest < Struct.new( :creator_request_id, :name, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name that lets you identify the rule group, to manage and use it.
660 661 662 663 664 665 666 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 660 class CreateFirewallRuleGroupRequest < Struct.new( :creator_request_id, :name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of the tag keys and values that you want to associate with the rule group.
660 661 662 663 664 665 666 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 660 class CreateFirewallRuleGroupRequest < Struct.new( :creator_request_id, :name, :tags) SENSITIVE = [] include Aws::Structure end |