Class: Aws::Route53Resolver::Types::CreateResolverEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::CreateResolverEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creator_request_id ⇒ String
A unique string that identifies the request and that allows failed requests to be retried without the risk of running the operation twice.
-
#direction ⇒ String
Specify the applicable value:.
-
#dns_64_enabled ⇒ Boolean
Specifies whether DNS64 is enabled for the inbound Resolver endpoint.
-
#ip_addresses ⇒ Array<Types::IpAddressRequest>
The subnets and IP addresses in your VPC that DNS queries originate from (for outbound endpoints) or that you forward DNS queries to (for inbound endpoints).
-
#ipv_6_internet_access_enabled ⇒ Boolean
Specifies whether IPv6 internet access is enabled for the outbound Resolver endpoint.
-
#name ⇒ String
A friendly name that lets you easily find a configuration in the Resolver dashboard in the Route 53 console.
-
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost.
-
#preferred_instance_type ⇒ String
The instance type.
-
#protocols ⇒ Array<String>
The protocols you want to use for the endpoint.
-
#resolver_endpoint_type ⇒ String
For the endpoint type you can choose either IPv4, IPv6, or dual-stack.
-
#rni_enhanced_metrics_enabled ⇒ Boolean
Specifies whether RNI enhanced metrics are enabled for the Resolver endpoints.
-
#security_group_ids ⇒ Array<String>
The ID of one or more security groups that you want to use to control access to this VPC.
-
#tags ⇒ Array<Types::Tag>
A list of the tag keys and values that you want to associate with the endpoint.
-
#target_name_server_metrics_enabled ⇒ Boolean
Specifies whether target name server metrics are enabled for the outbound Resolver endpoints.
Instance Attribute Details
#creator_request_id ⇒ String
A unique string that identifies the request and that allows failed requests to be retried without the risk of running the operation twice. ‘CreatorRequestId` can be any unique string, for example, a date/time stamp.
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#direction ⇒ String
Specify the applicable value:
-
‘INBOUND`: Resolver forwards DNS queries to the DNS service for a VPC from your network.
-
‘OUTBOUND`: Resolver forwards DNS queries from the DNS service for a VPC to your network.
-
‘INBOUND_DELEGATION`: Resolver delegates queries to Route 53 private hosted zones from your network.
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#dns_64_enabled ⇒ Boolean
Specifies whether DNS64 is enabled for the inbound Resolver endpoint. When set to ‘true`, Route 53 Resolver synthesizes AAAA (IPv6) records for IPv4-only services by prepending the `64:ff9b::/96` prefix to the IPv4 address. This enables IPv6-only clients that send queries through the inbound endpoint to reach IPv4-only services. DNS64 works with NAT64 to provide complete IPv6-to-IPv4 translation. Default is false.
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#ip_addresses ⇒ Array<Types::IpAddressRequest>
The subnets and IP addresses in your VPC that DNS queries originate from (for outbound endpoints) or that you forward DNS queries to (for inbound endpoints). The subnet ID uniquely identifies a VPC.
<note markdown=“1”> Even though the minimum is 1, Route 53 requires that you create at least two.
</note>
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#ipv_6_internet_access_enabled ⇒ Boolean
Specifies whether IPv6 internet access is enabled for the outbound Resolver endpoint. When set to ‘true`, the endpoint elastic network interfaces (ENIs) can forward DNS queries to public IPv6 targets through an internet gateway. Default is false.
When you enable IPv6 internet access, use network controls like security groups, NACLs, or egress-only internet gateways to protect the endpoint ENIs from unsolicited ingress traffic. Be aware that some network controls can affect DNS query throughput due to connection tracking. For more information, see [Amazon EC2 security group connection tracking] and [Resolver endpoint scaling].
[1]: docs.aws.amazon.com/ec2/latest/userguide/security-group-connection-tracking.html [2]: docs.aws.amazon.com/Route53/latest/DeveloperGuide/best-practices-resolver-endpoint-scaling.html
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A friendly name that lets you easily find a configuration in the Resolver dashboard in the Route 53 console.
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost. If you specify this, you must also specify a value for the ‘PreferredInstanceType`.
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#preferred_instance_type ⇒ String
The instance type. If you specify this, you must also specify a value for the ‘OutpostArn`.
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#protocols ⇒ Array<String>
The protocols you want to use for the endpoint. DoH-FIPS is applicable for default inbound endpoints only.
For a default inbound endpoint you can apply the protocols as follows:
-
Do53 and DoH in combination.
-
Do53 and DoH-FIPS in combination.
-
Do53 alone.
-
DoH alone.
-
DoH-FIPS alone.
-
None, which is treated as Do53.
For a delegation inbound endpoint you can use Do53 only.
For an outbound endpoint you can apply the protocols as follows:
-
Do53 and DoH in combination.
-
Do53 alone.
-
DoH alone.
-
None, which is treated as Do53.
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#resolver_endpoint_type ⇒ String
For the endpoint type you can choose either IPv4, IPv6, or dual-stack. A dual-stack endpoint means that it will resolve via both IPv4 and IPv6. This endpoint type is applied to all IP addresses.
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#rni_enhanced_metrics_enabled ⇒ Boolean
Specifies whether RNI enhanced metrics are enabled for the Resolver endpoints. When set to true, one-minute granular metrics are published in CloudWatch for each RNI associated with this endpoint. When set to false, metrics are not published. Default is false.
<note markdown=“1”> Standard CloudWatch pricing and charges are applied for using the Route 53 Resolver endpoint RNI enhanced metrics. For more information, see [Detailed metrics].
</note>
[1]: docs.aws.amazon.com/Route53/latest/DeveloperGuide/monitoring-resolver-with-cloudwatch.html
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The ID of one or more security groups that you want to use to control access to this VPC. The security group that you specify must include one or more inbound rules (for inbound Resolver endpoints) or outbound rules (for outbound Resolver endpoints). Inbound and outbound rules must allow TCP and UDP access. For inbound access, open port 53. For outbound access, open the port that you’re using for DNS queries on your network.
Some security group rules will cause your connection to be tracked. For outbound resolver endpoint, it can potentially impact the maximum queries per second from outbound endpoint to your target name server. For inbound resolver endpoint, it can bring down the overall maximum queries per second per IP address to as low as 1500. To avoid connection tracking caused by security group, see [Untracked connections].
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of the tag keys and values that you want to associate with the endpoint.
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |
#target_name_server_metrics_enabled ⇒ Boolean
Specifies whether target name server metrics are enabled for the outbound Resolver endpoints. When set to true, one-minute granular metrics are published in CloudWatch for each target name server associated with this endpoint. When set to false, metrics are not published. Default is false. This is not supported for inbound Resolver endpoints.
<note markdown=“1”> Standard CloudWatch pricing and charges are applied for using the Route 53 Resolver endpoint target name server metrics. For more information, see [Detailed metrics].
</note>
[1]: docs.aws.amazon.com/Route53/latest/DeveloperGuide/monitoring-resolver-with-cloudwatch.html
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 759 class CreateResolverEndpointRequest < Struct.new( :creator_request_id, :name, :security_group_ids, :direction, :ip_addresses, :outpost_arn, :preferred_instance_type, :tags, :resolver_endpoint_type, :protocols, :rni_enhanced_metrics_enabled, :target_name_server_metrics_enabled, :dns_64_enabled, :ipv_6_internet_access_enabled) SENSITIVE = [] include Aws::Structure end |