Class: Aws::Route53Resolver::Types::FirewallDomainList
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::FirewallDomainList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
High-level information about a list of firewall domains for use in a FirewallRule. This is returned by GetFirewallDomainList.
To retrieve the domains that are defined for this domain list, call ListFirewallDomains.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the firewall domain list.
-
#category ⇒ String
The category of the domain list.
-
#creation_time ⇒ String
The date and time that the domain list was created, in Unix time format and Coordinated Universal Time (UTC).
-
#creator_request_id ⇒ String
A unique string defined by you to identify the request.
-
#domain_count ⇒ Integer
The number of domain names that are specified in the domain list.
-
#id ⇒ String
The ID of the domain list.
-
#managed_list_type ⇒ String
The type of the managed domain list, for example
THREAT. -
#managed_owner_name ⇒ String
The owner of the list, used only for lists that are not managed by you.
-
#modification_time ⇒ String
The date and time that the domain list was last modified, in Unix time format and Coordinated Universal Time (UTC).
-
#name ⇒ String
The name of the domain list.
-
#status ⇒ String
The status of the domain list.
-
#status_message ⇒ String
Additional information about the status of the list, if available.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the firewall domain list.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
The category of the domain list.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ String
The date and time that the domain list was created, in Unix time format and Coordinated Universal Time (UTC).
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |
#creator_request_id ⇒ String
A unique string defined by you to identify the request. This allows you to retry failed requests without the risk of running the operation twice. This can be any unique string, for example, a timestamp.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |
#domain_count ⇒ Integer
The number of domain names that are specified in the domain list.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the domain list.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |
#managed_list_type ⇒ String
The type of the managed domain list, for example THREAT.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |
#managed_owner_name ⇒ String
The owner of the list, used only for lists that are not managed by
you. For example, the managed domain list
AWSManagedDomainsMalwareDomainList has the managed owner name
Route 53 Resolver DNS Firewall.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |
#modification_time ⇒ String
The date and time that the domain list was last modified, in Unix time format and Coordinated Universal Time (UTC).
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the domain list.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the domain list.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
Additional information about the status of the list, if available.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2159 class FirewallDomainList < Struct.new( :id, :arn, :name, :domain_count, :status, :status_message, :managed_owner_name, :creator_request_id, :creation_time, :modification_time, :category, :managed_list_type) SENSITIVE = [] include Aws::Structure end |