Class: Aws::Route53Resolver::Types::FirewallDomainListMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::FirewallDomainListMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Minimal high-level information for a firewall domain list. The action ListFirewallDomainLists returns an array of these objects.
To retrieve full information for a firewall domain list, call GetFirewallDomainList and ListFirewallDomains.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the firewall domain list metadata.
-
#category ⇒ String
The category of the domain list.
-
#creator_request_id ⇒ String
A unique string defined by you to identify the request.
-
#id ⇒ String
The ID of the domain list.
-
#managed_list_type ⇒ String
The type of the managed domain list, for example
THREAT. -
#managed_owner_name ⇒ String
The owner of the list, used only for lists that are not managed by you.
-
#name ⇒ String
The name of the domain list.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the firewall domain list metadata.
2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218 class FirewallDomainListMetadata < Struct.new( :id, :arn, :name, :creator_request_id, :managed_owner_name, :managed_list_type, :category) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
The category of the domain list.
2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218 class FirewallDomainListMetadata < Struct.new( :id, :arn, :name, :creator_request_id, :managed_owner_name, :managed_list_type, :category) SENSITIVE = [] include Aws::Structure end |
#creator_request_id ⇒ String
A unique string defined by you to identify the request. This allows you to retry failed requests without the risk of running the operation twice. This can be any unique string, for example, a timestamp.
2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218 class FirewallDomainListMetadata < Struct.new( :id, :arn, :name, :creator_request_id, :managed_owner_name, :managed_list_type, :category) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the domain list.
2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218 class FirewallDomainListMetadata < Struct.new( :id, :arn, :name, :creator_request_id, :managed_owner_name, :managed_list_type, :category) SENSITIVE = [] include Aws::Structure end |
#managed_list_type ⇒ String
The type of the managed domain list, for example THREAT.
2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218 class FirewallDomainListMetadata < Struct.new( :id, :arn, :name, :creator_request_id, :managed_owner_name, :managed_list_type, :category) SENSITIVE = [] include Aws::Structure end |
#managed_owner_name ⇒ String
The owner of the list, used only for lists that are not managed by
you. For example, the managed domain list
AWSManagedDomainsMalwareDomainList has the managed owner name
Route 53 Resolver DNS Firewall.
2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218 class FirewallDomainListMetadata < Struct.new( :id, :arn, :name, :creator_request_id, :managed_owner_name, :managed_list_type, :category) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the domain list.
2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2218 class FirewallDomainListMetadata < Struct.new( :id, :arn, :name, :creator_request_id, :managed_owner_name, :managed_list_type, :category) SENSITIVE = [] include Aws::Structure end |