Class: Aws::Route53Resolver::Types::FirewallRuleTypeDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::FirewallRuleTypeDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
The definition of an available rule type that can be used in DNS Firewall rules. This is returned by ListFirewallRuleTypes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the rule type.
-
#display_name ⇒ String
The display name of the rule type.
-
#rule_type ⇒ String
The category or class of the rule type, such as ‘FirewallAdvancedContentCategory` or `FirewallAdvancedThreatCategory`.
-
#subscription_info ⇒ Types::SubscriptionInfo
For rule types that require an external subscription (today, only the ‘PartnerThreatProtection` variant), describes the AWS Marketplace product that backs the rule type.
-
#value ⇒ String
The specific identifier within the rule type category, such as ‘VIOLENCE_AND_HATE_SPEECH` or `PHISHING`.
Instance Attribute Details
#description ⇒ String
A description of the rule type.
2779 2780 2781 2782 2783 2784 2785 2786 2787 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2779 class FirewallRuleTypeDefinition < Struct.new( :rule_type, :value, :display_name, :description, :subscription_info) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the rule type.
2779 2780 2781 2782 2783 2784 2785 2786 2787 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2779 class FirewallRuleTypeDefinition < Struct.new( :rule_type, :value, :display_name, :description, :subscription_info) SENSITIVE = [] include Aws::Structure end |
#rule_type ⇒ String
The category or class of the rule type, such as ‘FirewallAdvancedContentCategory` or `FirewallAdvancedThreatCategory`.
2779 2780 2781 2782 2783 2784 2785 2786 2787 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2779 class FirewallRuleTypeDefinition < Struct.new( :rule_type, :value, :display_name, :description, :subscription_info) SENSITIVE = [] include Aws::Structure end |
#subscription_info ⇒ Types::SubscriptionInfo
For rule types that require an external subscription (today, only the ‘PartnerThreatProtection` variant), describes the AWS Marketplace product that backs the rule type. Absent for rule types that are managed by AWS and do not require a separate subscription. See SubscriptionInfo.
2779 2780 2781 2782 2783 2784 2785 2786 2787 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2779 class FirewallRuleTypeDefinition < Struct.new( :rule_type, :value, :display_name, :description, :subscription_info) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The specific identifier within the rule type category, such as ‘VIOLENCE_AND_HATE_SPEECH` or `PHISHING`.
2779 2780 2781 2782 2783 2784 2785 2786 2787 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2779 class FirewallRuleTypeDefinition < Struct.new( :rule_type, :value, :display_name, :description, :subscription_info) SENSITIVE = [] include Aws::Structure end |