Class: Aws::Route53Resolver::Types::FirewallRuleTypeDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

The definition of an available rule type that can be used in DNS Firewall rules. This is returned by ListFirewallRuleTypes.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the rule type.

Returns:

  • (String)


2652
2653
2654
2655
2656
2657
2658
2659
# File 'lib/aws-sdk-route53resolver/types.rb', line 2652

class FirewallRuleTypeDefinition < Struct.new(
  :rule_type,
  :value,
  :display_name,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The display name of the rule type.

Returns:

  • (String)


2652
2653
2654
2655
2656
2657
2658
2659
# File 'lib/aws-sdk-route53resolver/types.rb', line 2652

class FirewallRuleTypeDefinition < Struct.new(
  :rule_type,
  :value,
  :display_name,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#rule_typeString

The category or class of the rule type, such as ‘FirewallAdvancedContentCategory` or `FirewallAdvancedThreatCategory`.

Returns:

  • (String)


2652
2653
2654
2655
2656
2657
2658
2659
# File 'lib/aws-sdk-route53resolver/types.rb', line 2652

class FirewallRuleTypeDefinition < Struct.new(
  :rule_type,
  :value,
  :display_name,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The specific identifier within the rule type category, such as ‘VIOLENCE_AND_HATE_SPEECH` or `PHISHING`.

Returns:

  • (String)


2652
2653
2654
2655
2656
2657
2658
2659
# File 'lib/aws-sdk-route53resolver/types.rb', line 2652

class FirewallRuleTypeDefinition < Struct.new(
  :rule_type,
  :value,
  :display_name,
  :description)
  SENSITIVE = []
  include Aws::Structure
end