Class: Aws::Route53Resolver::Types::FirewallRuleTypeDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::FirewallRuleTypeDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
The definition of an available rule type that can be used in DNS Firewall rules. This is returned by ListFirewallRuleTypes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the rule type.
-
#display_name ⇒ String
The display name of the rule type.
-
#rule_type ⇒ String
The category or class of the rule type, such as ‘FirewallAdvancedContentCategory` or `FirewallAdvancedThreatCategory`.
-
#value ⇒ String
The specific identifier within the rule type category, such as ‘VIOLENCE_AND_HATE_SPEECH` or `PHISHING`.
Instance Attribute Details
#description ⇒ String
A description of the rule type.
2652 2653 2654 2655 2656 2657 2658 2659 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2652 class FirewallRuleTypeDefinition < Struct.new( :rule_type, :value, :display_name, :description) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the rule type.
2652 2653 2654 2655 2656 2657 2658 2659 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2652 class FirewallRuleTypeDefinition < Struct.new( :rule_type, :value, :display_name, :description) SENSITIVE = [] include Aws::Structure end |
#rule_type ⇒ String
The category or class of the rule type, such as ‘FirewallAdvancedContentCategory` or `FirewallAdvancedThreatCategory`.
2652 2653 2654 2655 2656 2657 2658 2659 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2652 class FirewallRuleTypeDefinition < Struct.new( :rule_type, :value, :display_name, :description) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The specific identifier within the rule type category, such as ‘VIOLENCE_AND_HATE_SPEECH` or `PHISHING`.
2652 2653 2654 2655 2656 2657 2658 2659 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2652 class FirewallRuleTypeDefinition < Struct.new( :rule_type, :value, :display_name, :description) SENSITIVE = [] include Aws::Structure end |