Class: Aws::Route53Resolver::Types::ImportFirewallDomainsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_file_urlString

The fully qualified URL or URI of the file stored in Amazon Simple Storage Service (Amazon S3) that contains the list of domains to import.

The file must be in an S3 bucket that’s in the same Region as your DNS Firewall. The file must be a text file and must contain a single domain per line.

Returns:

  • (String)


2508
2509
2510
2511
2512
2513
2514
# File 'lib/aws-sdk-route53resolver/types.rb', line 2508

class ImportFirewallDomainsRequest < Struct.new(
  :firewall_domain_list_id,
  :operation,
  :domain_file_url)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_domain_list_idString

The ID of the domain list that you want to modify with the import operation.

Returns:

  • (String)


2508
2509
2510
2511
2512
2513
2514
# File 'lib/aws-sdk-route53resolver/types.rb', line 2508

class ImportFirewallDomainsRequest < Struct.new(
  :firewall_domain_list_id,
  :operation,
  :domain_file_url)
  SENSITIVE = []
  include Aws::Structure
end

#operationString

What you want DNS Firewall to do with the domains that are listed in the file. This must be set to ‘REPLACE`, which updates the domain list to exactly match the list in the file.

Returns:

  • (String)


2508
2509
2510
2511
2512
2513
2514
# File 'lib/aws-sdk-route53resolver/types.rb', line 2508

class ImportFirewallDomainsRequest < Struct.new(
  :firewall_domain_list_id,
  :operation,
  :domain_file_url)
  SENSITIVE = []
  include Aws::Structure
end