Class: Aws::Route53Resolver::Types::IpAddressResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::IpAddressResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
In the response to a [GetResolverEndpoint] request, information about the IP addresses that the Resolver endpoint uses for DNS queries.
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverEndpoint.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ String
The date and time that the IP address was created, in Unix time format and Coordinated Universal Time (UTC).
-
#ip ⇒ String
One IPv4 address that the Resolver endpoint uses for DNS queries.
-
#ip_id ⇒ String
The ID of one IP address.
-
#ipv_6 ⇒ String
One IPv6 address that the Resolver endpoint uses for DNS queries.
-
#modification_time ⇒ String
The date and time that the IP address was last modified, in Unix time format and Coordinated Universal Time (UTC).
-
#status ⇒ String
A status code that gives the current status of the request.
-
#status_message ⇒ String
A message that provides additional information about the status of the request.
-
#subnet_id ⇒ String
The ID of one subnet.
Instance Attribute Details
#creation_time ⇒ String
The date and time that the IP address was created, in Unix time format and Coordinated Universal Time (UTC).
3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3391 class IpAddressResponse < Struct.new( :ip_id, :subnet_id, :ip, :ipv_6, :status, :status_message, :creation_time, :modification_time) SENSITIVE = [] include Aws::Structure end |
#ip ⇒ String
One IPv4 address that the Resolver endpoint uses for DNS queries.
3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3391 class IpAddressResponse < Struct.new( :ip_id, :subnet_id, :ip, :ipv_6, :status, :status_message, :creation_time, :modification_time) SENSITIVE = [] include Aws::Structure end |
#ip_id ⇒ String
The ID of one IP address.
3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3391 class IpAddressResponse < Struct.new( :ip_id, :subnet_id, :ip, :ipv_6, :status, :status_message, :creation_time, :modification_time) SENSITIVE = [] include Aws::Structure end |
#ipv_6 ⇒ String
One IPv6 address that the Resolver endpoint uses for DNS queries.
3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3391 class IpAddressResponse < Struct.new( :ip_id, :subnet_id, :ip, :ipv_6, :status, :status_message, :creation_time, :modification_time) SENSITIVE = [] include Aws::Structure end |
#modification_time ⇒ String
The date and time that the IP address was last modified, in Unix time format and Coordinated Universal Time (UTC).
3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3391 class IpAddressResponse < Struct.new( :ip_id, :subnet_id, :ip, :ipv_6, :status, :status_message, :creation_time, :modification_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
A status code that gives the current status of the request.
3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3391 class IpAddressResponse < Struct.new( :ip_id, :subnet_id, :ip, :ipv_6, :status, :status_message, :creation_time, :modification_time) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A message that provides additional information about the status of the request.
3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3391 class IpAddressResponse < Struct.new( :ip_id, :subnet_id, :ip, :ipv_6, :status, :status_message, :creation_time, :modification_time) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of one subnet.
3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3391 class IpAddressResponse < Struct.new( :ip_id, :subnet_id, :ip, :ipv_6, :status, :status_message, :creation_time, :modification_time) SENSITIVE = [] include Aws::Structure end |