Class: Aws::Route53Resolver::Types::ListFirewallConfigsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListFirewallConfigsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_configs ⇒ Array<Types::FirewallConfig>
The configurations for the firewall behavior provided by DNS Firewall for VPCs from Amazon Virtual Private Cloud (Amazon VPC).
-
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response.
Instance Attribute Details
#firewall_configs ⇒ Array<Types::FirewallConfig>
The configurations for the firewall behavior provided by DNS Firewall for VPCs from Amazon Virtual Private Cloud (Amazon VPC).
2792 2793 2794 2795 2796 2797 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2792 class ListFirewallConfigsResponse < Struct.new( :next_token, :firewall_configs) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response. To retrieve the next batch of objects, provide this token in your next request.
2792 2793 2794 2795 2796 2797 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2792 class ListFirewallConfigsResponse < Struct.new( :next_token, :firewall_configs) SENSITIVE = [] include Aws::Structure end |