Class: Aws::Route53Resolver::Types::ListFirewallDomainListsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListFirewallDomainListsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_domain_lists ⇒ Array<Types::FirewallDomainListMetadata>
A list of the domain lists that you have defined.
-
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response.
Instance Attribute Details
#firewall_domain_lists ⇒ Array<Types::FirewallDomainListMetadata>
A list of the domain lists that you have defined.
This might be a partial list of the domain lists that you’ve defined. For information, see MaxResults.
2843 2844 2845 2846 2847 2848 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2843 class ListFirewallDomainListsResponse < Struct.new( :next_token, :firewall_domain_lists) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response. To retrieve the next batch of objects, provide this token in your next request.
2843 2844 2845 2846 2847 2848 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2843 class ListFirewallDomainListsResponse < Struct.new( :next_token, :firewall_domain_lists) SENSITIVE = [] include Aws::Structure end |