Class: Aws::Route53Resolver::Types::ListFirewallDomainsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListFirewallDomainsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_domain_list_id ⇒ String
The ID of the domain list whose domains you want to retrieve.
-
#max_results ⇒ Integer
The maximum number of objects that you want Resolver to return for this request.
-
#next_token ⇒ String
For the first call to this list request, omit this value.
Instance Attribute Details
#firewall_domain_list_id ⇒ String
The ID of the domain list whose domains you want to retrieve.
2876 2877 2878 2879 2880 2881 2882 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2876 class ListFirewallDomainsRequest < Struct.new( :firewall_domain_list_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of objects that you want Resolver to return for this request. If more objects are available, in the response, Resolver provides a NextToken value that you can use in a subsequent call to get the next batch of objects.
If you don’t specify a value for MaxResults, Resolver returns up to 100 objects.
2876 2877 2878 2879 2880 2881 2882 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2876 class ListFirewallDomainsRequest < Struct.new( :firewall_domain_list_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
For the first call to this list request, omit this value.
When you request a list of objects, Resolver returns at most the number of objects specified in MaxResults. If more objects are available for retrieval, Resolver returns a NextToken value in the response. To retrieve the next batch of objects, use the token that was returned for the prior request in your next request.
2876 2877 2878 2879 2880 2881 2882 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 2876 class ListFirewallDomainsRequest < Struct.new( :firewall_domain_list_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |