Class: Aws::Route53Resolver::Types::ListFirewallRuleGroupAssociationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListFirewallRuleGroupAssociationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_rule_group_associations ⇒ Array<Types::FirewallRuleGroupAssociation>
A list of your firewall rule group associations.
-
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response.
Instance Attribute Details
#firewall_rule_group_associations ⇒ Array<Types::FirewallRuleGroupAssociation>
A list of your firewall rule group associations.
This might be a partial list of the associations that you have
defined. For information, see MaxResults.
3697 3698 3699 3700 3701 3702 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3697 class ListFirewallRuleGroupAssociationsResponse < Struct.new( :next_token, :firewall_rule_group_associations) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If objects are still available for retrieval, Resolver returns this token in the response. To retrieve the next batch of objects, provide this token in your next request.
3697 3698 3699 3700 3701 3702 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3697 class ListFirewallRuleGroupAssociationsResponse < Struct.new( :next_token, :firewall_rule_group_associations) SENSITIVE = [] include Aws::Structure end |