Class: Aws::Route53Resolver::Types::ListOutpostResolversRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListOutpostResolversRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of Resolvers on the Outpost that you want to return in the response to a
ListOutpostResolverrequest. -
#next_token ⇒ String
For the first
ListOutpostResolverrequest, omit this value. -
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of Resolvers on the Outpost that you want to return in the response to a ListOutpostResolver request. If you don’t specify a value for MaxResults, the request returns up to 100 Resolvers.
3139 3140 3141 3142 3143 3144 3145 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3139 class ListOutpostResolversRequest < Struct.new( :outpost_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
For the first ListOutpostResolver request, omit this value.
3139 3140 3141 3142 3143 3144 3145 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3139 class ListOutpostResolversRequest < Struct.new( :outpost_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost.
3139 3140 3141 3142 3143 3144 3145 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3139 class ListOutpostResolversRequest < Struct.new( :outpost_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |