Class: Aws::Route53Resolver::Types::ListResolverConfigsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of Resolver configurations that you want to return in the response to a ListResolverConfigs request. If you don’t specify a value for MaxResults, up to 100 Resolver configurations are returned.

Returns:

  • (Integer)


3190
3191
3192
3193
3194
3195
# File 'lib/aws-sdk-route53resolver/types.rb', line 3190

class ListResolverConfigsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

(Optional) If the current Amazon Web Services account has more than MaxResults Resolver configurations, use NextToken to get the second and subsequent pages of results.

For the first ListResolverConfigs request, omit this value.

For the second and subsequent requests, get the value of NextToken from the previous response and specify that value for NextToken in the request.

Returns:

  • (String)


3190
3191
3192
3193
3194
3195
# File 'lib/aws-sdk-route53resolver/types.rb', line 3190

class ListResolverConfigsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end