Class: Aws::Route53Resolver::Types::ListResolverEndpointsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53resolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::Filter>

An optional specification to return a subset of Resolver endpoints, such as all inbound Resolver endpoints.

<note markdown=“1”> If you submit a second or subsequent ListResolverEndpoints request and specify the NextToken parameter, you must use the same values for Filters, if any, as in the previous request.

</note>


3381
3382
3383
3384
3385
3386
3387
# File 'lib/aws-sdk-route53resolver/types.rb', line 3381

class ListResolverEndpointsRequest < Struct.new(
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of Resolver endpoints that you want to return in the response to a ListResolverEndpoints request. If you don’t specify a value for MaxResults, Resolver returns up to 100 Resolver endpoints.



3381
3382
3383
3384
3385
3386
3387
# File 'lib/aws-sdk-route53resolver/types.rb', line 3381

class ListResolverEndpointsRequest < Struct.new(
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

For the first ListResolverEndpoints request, omit this value.

If you have more than MaxResults Resolver endpoints, you can submit another ListResolverEndpoints request to get the next group of Resolver endpoints. In the next request, specify the value of NextToken from the previous response.



3381
3382
3383
3384
3385
3386
3387
# File 'lib/aws-sdk-route53resolver/types.rb', line 3381

class ListResolverEndpointsRequest < Struct.new(
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end