Class: Aws::Route53Resolver::Types::ListResolverEndpointsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListResolverEndpointsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The value that you specified for
MaxResultsin the request. -
#next_token ⇒ String
If more than
MaxResultsIP addresses match the specified criteria, you can submit anotherListResolverEndpointrequest to get the next group of results. -
#resolver_endpoints ⇒ Array<Types::ResolverEndpoint>
The Resolver endpoints that were created by using the current Amazon Web Services account, and that match the specified filters, if any.
Instance Attribute Details
#max_results ⇒ Integer
The value that you specified for MaxResults in the request.
3407 3408 3409 3410 3411 3412 3413 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3407 class ListResolverEndpointsResponse < Struct.new( :next_token, :max_results, :resolver_endpoints) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If more than MaxResults IP addresses match the specified criteria, you can submit another ListResolverEndpoint request to get the next group of results. In the next request, specify the value of NextToken from the previous response.
3407 3408 3409 3410 3411 3412 3413 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3407 class ListResolverEndpointsResponse < Struct.new( :next_token, :max_results, :resolver_endpoints) SENSITIVE = [] include Aws::Structure end |
#resolver_endpoints ⇒ Array<Types::ResolverEndpoint>
The Resolver endpoints that were created by using the current Amazon Web Services account, and that match the specified filters, if any.
3407 3408 3409 3410 3411 3412 3413 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3407 class ListResolverEndpointsResponse < Struct.new( :next_token, :max_results, :resolver_endpoints) SENSITIVE = [] include Aws::Structure end |