Class: Aws::Route53Resolver::Types::ListResolverQueryLogConfigsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ListResolverQueryLogConfigsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If there are more than
MaxResultsquery logging configurations, you can submit anotherListResolverQueryLogConfigsrequest to get the next group of configurations. -
#resolver_query_log_configs ⇒ Array<Types::ResolverQueryLogConfig>
A list that contains one
ResolverQueryLogConfigelement for each query logging configuration that matches the values that you specified forFilter. -
#total_count ⇒ Integer
The total number of query logging configurations that were created by the current account in the specified Region.
-
#total_filtered_count ⇒ Integer
The total number of query logging configurations that were created by the current account in the specified Region and that match the filters that were specified in the
ListResolverQueryLogConfigsrequest.
Instance Attribute Details
#next_token ⇒ String
If there are more than MaxResults query logging configurations, you can submit another ListResolverQueryLogConfigs request to get the next group of configurations. In the next request, specify the value of NextToken from the previous response.
3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3707 class ListResolverQueryLogConfigsResponse < Struct.new( :next_token, :total_count, :total_filtered_count, :resolver_query_log_configs) SENSITIVE = [] include Aws::Structure end |
#resolver_query_log_configs ⇒ Array<Types::ResolverQueryLogConfig>
A list that contains one ResolverQueryLogConfig element for each query logging configuration that matches the values that you specified for Filter.
3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3707 class ListResolverQueryLogConfigsResponse < Struct.new( :next_token, :total_count, :total_filtered_count, :resolver_query_log_configs) SENSITIVE = [] include Aws::Structure end |
#total_count ⇒ Integer
The total number of query logging configurations that were created by the current account in the specified Region. This count can differ from the number of query logging configurations that are returned in a ListResolverQueryLogConfigs response, depending on the values that you specify in the request.
3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3707 class ListResolverQueryLogConfigsResponse < Struct.new( :next_token, :total_count, :total_filtered_count, :resolver_query_log_configs) SENSITIVE = [] include Aws::Structure end |
#total_filtered_count ⇒ Integer
The total number of query logging configurations that were created by the current account in the specified Region and that match the filters that were specified in the ListResolverQueryLogConfigs request. For the total number of query logging configurations that were created by the current account in the specified Region, see TotalCount.
3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3707 class ListResolverQueryLogConfigsResponse < Struct.new( :next_token, :total_count, :total_filtered_count, :resolver_query_log_configs) SENSITIVE = [] include Aws::Structure end |