Class: Aws::Route53Resolver::Types::OutpostResolver
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::OutpostResolver
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
A complex type that contains settings for an existing Resolver on an Outpost.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN (Amazon Resource Name) for the Resolver on an Outpost.
-
#creation_time ⇒ String
The date and time that the Outpost Resolver was created, in Unix time format and Coordinated Universal Time (UTC).
-
#creator_request_id ⇒ String
A unique string that identifies the request that created the Resolver endpoint.
-
#id ⇒ String
The ID of the Resolver on Outpost.
-
#instance_count ⇒ Integer
Amazon EC2 instance count for the Resolver on the Outpost.
-
#modification_time ⇒ String
The date and time that the Outpost Resolver was modified, in Unix time format and Coordinated Universal Time (UTC).
-
#name ⇒ String
Name of the Resolver.
-
#outpost_arn ⇒ String
The ARN (Amazon Resource Name) for the Outpost.
-
#preferred_instance_type ⇒ String
The Amazon EC2 instance type.
-
#status ⇒ String
Status of the Resolver.
-
#status_message ⇒ String
A detailed description of the Resolver.
Instance Attribute Details
#arn ⇒ String
The ARN (Amazon Resource Name) for the Resolver on an Outpost.
3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3979 class OutpostResolver < Struct.new( :arn, :creation_time, :modification_time, :creator_request_id, :id, :instance_count, :preferred_instance_type, :name, :status, :status_message, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ String
The date and time that the Outpost Resolver was created, in Unix time format and Coordinated Universal Time (UTC).
3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3979 class OutpostResolver < Struct.new( :arn, :creation_time, :modification_time, :creator_request_id, :id, :instance_count, :preferred_instance_type, :name, :status, :status_message, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#creator_request_id ⇒ String
A unique string that identifies the request that created the Resolver endpoint. The ‘CreatorRequestId` allows failed requests to be retried without the risk of running the operation twice.
3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3979 class OutpostResolver < Struct.new( :arn, :creation_time, :modification_time, :creator_request_id, :id, :instance_count, :preferred_instance_type, :name, :status, :status_message, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the Resolver on Outpost.
3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3979 class OutpostResolver < Struct.new( :arn, :creation_time, :modification_time, :creator_request_id, :id, :instance_count, :preferred_instance_type, :name, :status, :status_message, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
Amazon EC2 instance count for the Resolver on the Outpost.
3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3979 class OutpostResolver < Struct.new( :arn, :creation_time, :modification_time, :creator_request_id, :id, :instance_count, :preferred_instance_type, :name, :status, :status_message, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#modification_time ⇒ String
The date and time that the Outpost Resolver was modified, in Unix time format and Coordinated Universal Time (UTC).
3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3979 class OutpostResolver < Struct.new( :arn, :creation_time, :modification_time, :creator_request_id, :id, :instance_count, :preferred_instance_type, :name, :status, :status_message, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of the Resolver.
3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3979 class OutpostResolver < Struct.new( :arn, :creation_time, :modification_time, :creator_request_id, :id, :instance_count, :preferred_instance_type, :name, :status, :status_message, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The ARN (Amazon Resource Name) for the Outpost.
3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3979 class OutpostResolver < Struct.new( :arn, :creation_time, :modification_time, :creator_request_id, :id, :instance_count, :preferred_instance_type, :name, :status, :status_message, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#preferred_instance_type ⇒ String
The Amazon EC2 instance type.
3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3979 class OutpostResolver < Struct.new( :arn, :creation_time, :modification_time, :creator_request_id, :id, :instance_count, :preferred_instance_type, :name, :status, :status_message, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Status of the Resolver.
3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3979 class OutpostResolver < Struct.new( :arn, :creation_time, :modification_time, :creator_request_id, :id, :instance_count, :preferred_instance_type, :name, :status, :status_message, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A detailed description of the Resolver.
3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 3979 class OutpostResolver < Struct.new( :arn, :creation_time, :modification_time, :creator_request_id, :id, :instance_count, :preferred_instance_type, :name, :status, :status_message, :outpost_arn) SENSITIVE = [] include Aws::Structure end |