Class: Aws::Route53Resolver::Types::PutResolverRulePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::PutResolverRulePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the rule that you want to share with another account.
-
#resolver_rule_policy ⇒ String
An Identity and Access Management policy statement that lists the rules that you want to share with another Amazon Web Services account and the operations that you want the account to be able to perform.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the rule that you want to share with another account.
4101 4102 4103 4104 4105 4106 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4101 class PutResolverRulePolicyRequest < Struct.new( :arn, :resolver_rule_policy) SENSITIVE = [] include Aws::Structure end |
#resolver_rule_policy ⇒ String
An Identity and Access Management policy statement that lists the rules that you want to share with another Amazon Web Services account and the operations that you want the account to be able to perform. You can specify the following operations in the ‘Action` section of the statement:
-
‘route53resolver:GetResolverRule`
-
‘route53resolver:AssociateResolverRule`
-
‘route53resolver:DisassociateResolverRule`
-
‘route53resolver:ListResolverRules`
-
‘route53resolver:ListResolverRuleAssociations`
In the ‘Resource` section of the statement, specify the ARN for the rule that you want to share with another account. Specify the same ARN that you specified in `Arn`.
4101 4102 4103 4104 4105 4106 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4101 class PutResolverRulePolicyRequest < Struct.new( :arn, :resolver_rule_policy) SENSITIVE = [] include Aws::Structure end |