Class: Aws::Route53Resolver::Types::ResolverRuleConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::ResolverRuleConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
In an [UpdateResolverRule] request, information about the changes that you want to make.
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UpdateResolverRule.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The new name for the Resolver rule.
-
#resolver_endpoint_id ⇒ String
The ID of the new outbound Resolver endpoint that you want to use to route DNS queries to the IP addresses that you specify in ‘TargetIps`.
-
#target_ips ⇒ Array<Types::TargetAddress>
For DNS queries that originate in your VPC, the new IP addresses that you want to route outbound DNS queries to.
Instance Attribute Details
#name ⇒ String
The new name for the Resolver rule. The name that you specify appears in the Resolver dashboard in the Route 53 console.
The name can be up to 64 characters long and can contain letters (a-z, A-Z), numbers (0-9), hyphens (-), underscores (_), and spaces. The name cannot consist of only numbers.
4841 4842 4843 4844 4845 4846 4847 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4841 class ResolverRuleConfig < Struct.new( :name, :target_ips, :resolver_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#resolver_endpoint_id ⇒ String
The ID of the new outbound Resolver endpoint that you want to use to route DNS queries to the IP addresses that you specify in ‘TargetIps`.
4841 4842 4843 4844 4845 4846 4847 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4841 class ResolverRuleConfig < Struct.new( :name, :target_ips, :resolver_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#target_ips ⇒ Array<Types::TargetAddress>
For DNS queries that originate in your VPC, the new IP addresses that you want to route outbound DNS queries to.
4841 4842 4843 4844 4845 4846 4847 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 4841 class ResolverRuleConfig < Struct.new( :name, :target_ips, :resolver_endpoint_id) SENSITIVE = [] include Aws::Structure end |