Class: Aws::Route53Resolver::Types::SubscriptionInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::SubscriptionInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Identifies the AWS Marketplace product that backs a partner-managed rule type. Returned as part of FirewallRuleTypeDefinition when the rule type variant requires an active customer subscription to the named product.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#product_id ⇒ String
The AWS Marketplace product identifier of the partner threat-protection product.
-
#vendor_name ⇒ String
The name of the AWS Marketplace seller (vendor) that publishes the partner threat-protection product (for example, ‘Palo Alto Networks`).
Instance Attribute Details
#product_id ⇒ String
The AWS Marketplace product identifier of the partner threat-protection product. Use this value to verify or manage the calling account’s subscription in AWS Marketplace.
5718 5719 5720 5721 5722 5723 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5718 class SubscriptionInfo < Struct.new( :vendor_name, :product_id) SENSITIVE = [] include Aws::Structure end |
#vendor_name ⇒ String
The name of the AWS Marketplace seller (vendor) that publishes the partner threat-protection product (for example, ‘Palo Alto Networks`).
5718 5719 5720 5721 5722 5723 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 5718 class SubscriptionInfo < Struct.new( :vendor_name, :product_id) SENSITIVE = [] include Aws::Structure end |