Class: Aws::Route53Resolver::Types::UpdateFirewallRuleGroupAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Resolver::Types::UpdateFirewallRuleGroupAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53resolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_rule_group_association_id ⇒ String
The identifier of the FirewallRuleGroupAssociation.
-
#mutation_protection ⇒ String
If enabled, this setting disallows modification or removal of the association, to help prevent against accidentally altering DNS firewall protections.
-
#name ⇒ String
The name of the rule group association.
-
#priority ⇒ Integer
The setting that determines the processing order of the rule group among the rule groups that you associate with the specified VPC.
Instance Attribute Details
#firewall_rule_group_association_id ⇒ String
The identifier of the FirewallRuleGroupAssociation.
6065 6066 6067 6068 6069 6070 6071 6072 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 6065 class UpdateFirewallRuleGroupAssociationRequest < Struct.new( :firewall_rule_group_association_id, :priority, :mutation_protection, :name) SENSITIVE = [] include Aws::Structure end |
#mutation_protection ⇒ String
If enabled, this setting disallows modification or removal of the association, to help prevent against accidentally altering DNS firewall protections.
6065 6066 6067 6068 6069 6070 6071 6072 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 6065 class UpdateFirewallRuleGroupAssociationRequest < Struct.new( :firewall_rule_group_association_id, :priority, :mutation_protection, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule group association.
6065 6066 6067 6068 6069 6070 6071 6072 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 6065 class UpdateFirewallRuleGroupAssociationRequest < Struct.new( :firewall_rule_group_association_id, :priority, :mutation_protection, :name) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The setting that determines the processing order of the rule group among the rule groups that you associate with the specified VPC. DNS Firewall filters VPC traffic starting from the rule group with the lowest numeric priority setting.
You must specify a unique priority for each rule group that you associate with a single VPC. To make it easier to insert rule groups later, leave space between the numbers, for example, use 100, 200, and so on. You can change the priority setting for a rule group association after you create it.
6065 6066 6067 6068 6069 6070 6071 6072 |
# File 'lib/aws-sdk-route53resolver/types.rb', line 6065 class UpdateFirewallRuleGroupAssociationRequest < Struct.new( :firewall_rule_group_association_id, :priority, :mutation_protection, :name) SENSITIVE = [] include Aws::Structure end |